function [residual, g1, g2, g3] = BKK3C_GHH2_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(54, 1);
T16 = (params(4)-1)/params(4);
T32 = params(25)*y(25)^T16+params(26)*(params(21)*y(28))^T16+params(27)*(params(23)*y(31))^T16;
T33 = params(4)/(params(4)-1);
T37 = params(37)/2;
T43 = y(28)/y(25)*y(4)/y(7)-1;
T48 = params(38)/2;
T53 = y(28)/y(31)*y(10)/y(7)-1;
T58 = params(39)/2;
T62 = y(4)*y(31)/y(25)/y(10)-1;
T88 = params(28)*(params(19)*y(26))^T16+params(29)*y(29)^T16+params(30)*(params(24)*y(32))^T16;
T92 = params(40)/2;
T98 = y(26)/y(29)*y(8)/y(5)-1;
T103 = params(41)/2;
T108 = y(8)*y(32)/y(29)/y(11)-1;
T113 = params(42)/2;
T117 = y(11)*y(26)/y(32)/y(5)-1;
T143 = params(31)*(params(20)*y(27))^T16+params(32)*(params(22)*y(30))^T16+params(33)*y(33)^T16;
T147 = params(43)/2;
T153 = y(27)/y(30)*y(9)/y(6)-1;
T158 = params(44)/2;
T163 = y(30)/y(33)*y(12)/y(9)-1;
T168 = params(45)/2;
T172 = y(12)*y(27)/y(33)/y(6)-1;
T189 = (y(67)/y(1)-params(3))^2;
T202 = (y(68)/y(2)-params(3))^2;
T215 = (y(69)/y(3)-params(3))^2;
T228 = y(70)+params(46)*y(73)^(1+params(6))/(1+params(6));
T232 = params(5)*T228^(-params(2));
T237 = 1-params(47)*(y(88)/y(19)-params(3));
T238 = T232/T237;
T242 = params(47)/2;
T243 = params(3)^2;
T247 = 1+y(85)-params(3)-T242*(T243-(y(88)/y(19))^2);
T253 = y(16)+params(46)*y(22)^(1+params(6))/(1+params(6));
T254 = T253^(-params(2));
T256 = 1-params(47)*(y(67)/y(1)-params(3));
T265 = y(71)+params(46)*y(74)^(1+params(6))/(1+params(6));
T267 = params(5)*T265^(-params(2));
T272 = 1-params(47)*(y(89)/y(20)-params(3));
T273 = T267/T272;
T280 = 1+y(86)-params(3)-T242*(T243-(y(89)/y(20))^2);
T286 = y(17)+params(46)*y(23)^(1+params(6))/(1+params(6));
T287 = T286^(-params(2));
T289 = 1-params(47)*(y(68)/y(2)-params(3));
T298 = y(72)+params(46)*y(75)^(1+params(6))/(1+params(6));
T300 = params(5)*T298^(-params(2));
T305 = 1-params(47)*(y(90)/y(21)-params(3));
T306 = T300/T305;
T313 = 1+y(87)-params(3)-T242*(T243-(y(90)/y(21))^2);
T319 = y(18)+params(46)*y(24)^(1+params(6))/(1+params(6));
T320 = T319^(-params(2));
T322 = 1-params(47)*(y(69)/y(3)-params(3));
T366 = y(25)^2;
T367 = (-y(28))/T366;
T378 = y(25)*y(79)/y(76)/y(28)-1;
T379 = params(37)*y(61)*T378;
T380 = y(79)/y(76)/y(28);
T387 = y(4)*(-y(31))/T366/y(10);
T395 = y(25)*y(82)/y(76)/y(31)-1;
T396 = params(39)*y(61)*T395;
T401 = (-1)/params(4);
T403 = params(25)*y(25)^T401;
T404 = 1/(params(4)-1);
T405 = T32^T404;
T418 = y(31)*y(79)/y(82)/y(28)-1;
T419 = params(38)*y(61)*T418;
T423 = y(28)^2;
T424 = y(31)*(-y(79))/y(82)/T423;
T428 = y(4)/y(7)/y(25);
T433 = y(25)*(-y(79))/y(76)/T423;
T437 = params(26)*(params(21)*y(28))^T401;
T448 = y(31)^2;
T449 = y(25)*(-y(82))/y(76)/T448;
T454 = y(10)*(-y(28))/T448/y(7);
T462 = params(27)*(params(23)*y(31))^T401;
T477 = y(29)*y(77)/y(80)/y(26)-1;
T478 = params(40)*y(62)*T477;
T482 = y(26)^2;
T483 = y(29)*(-y(77))/y(80)/T482;
T488 = y(11)/y(5)/y(32);
T496 = y(32)*y(77)/y(83)/y(26)-1;
T497 = params(42)*y(62)*T496;
T501 = y(77)*(-y(32))/T482/y(83);
T505 = params(28)*(params(19)*y(26))^T401;
T506 = T88^T404;
T511 = y(29)^2;
T514 = y(8)*(-y(32))/T511/y(11);
T521 = y(29)*y(83)/y(80)/y(32)-1;
T522 = params(41)*y(62)*T521;
T523 = y(83)/y(80)/y(32);
T529 = y(8)*(-y(26))/T511/y(5);
T537 = params(29)*y(29)^T401;
T544 = y(32)^2;
T545 = y(26)*(-y(11))/y(5)/T544;
T553 = y(8)/y(11)/y(29);
T559 = y(29)*(-y(83))/y(80)/T544;
T563 = params(30)*(params(24)*y(32))^T401;
T578 = y(30)*y(78)/y(81)/y(27)-1;
T579 = params(43)*y(62)*T578;
T583 = y(27)^2;
T584 = y(30)*(-y(78))/y(81)/T583;
T589 = y(6)/y(12)/y(33);
T597 = y(33)*y(78)/y(84)/y(27)-1;
T598 = params(45)*y(62)*T597;
T601 = y(33)*(-y(78))/y(84)/T583;
T605 = params(31)*(params(20)*y(27))^T401;
T606 = T143^T404;
T619 = y(33)*y(81)/y(84)/y(30)-1;
T620 = params(44)*y(62)*T619;
T624 = y(30)^2;
T625 = y(33)*(-y(81))/y(84)/T624;
T631 = y(9)*(-y(27))/T624/y(6);
T639 = params(32)*(params(22)*y(30))^T401;
T646 = y(33)^2;
T647 = y(27)*(-y(12))/y(6)/T646;
T650 = y(78)/y(84)/y(27);
T656 = y(12)*(-y(30))/T646/y(9);
T664 = params(33)*y(33)^T401;
T674 = y(19)^(params(1)-1);
T675 = y(64)*y(52)*params(1)*T674;
T677 = y(22)^(1-params(1));
T681 = y(19)^params(1);
T684 = y(22)^(-params(1));
T692 = y(20)^(params(1)-1);
T693 = params(1)*y(65)*y(56)*T692;
T694 = y(23)^(1-params(1));
T698 = y(20)^params(1);
T700 = y(23)^(-params(1));
T708 = y(21)^(params(1)-1);
T709 = params(1)*y(66)*y(60)*T708;
T710 = y(24)^(1-params(1));
T714 = y(21)^params(1);
T716 = y(24)^(-params(1));
residual(1) = (-y(16))-y(67)+T32^T33-T37*T43^2-T48*T53^2-T58*T62^2;
residual(2) = (-y(17))-y(68)+T88^T33-T92*T98^2-T103*T108^2-T113*T117^2;
residual(3) = (-y(18))-y(69)+T143^T33-T147*T153^2-T158*T163^2-T168*T172^2;
residual(4) = y(67)+(-y(19))+(1-params(3))*y(1)-y(1)*params(47)*T189;
residual(5) = y(68)+(-y(20))+(1-params(3))*y(2)-params(47)*y(2)*T202;
residual(6) = y(69)+(-y(21))+(1-params(3))*y(3)-params(47)*y(3)*T215;
residual(7) = T238*T247-T254/T256;
residual(8) = T273*T280-T287/T289;
residual(9) = T306*T313-T320/T322;
residual(10) = y(37)-params(46)*y(22)^params(6);
residual(11) = y(38)-params(46)*y(23)^params(6);
residual(12) = y(39)-params(46)*y(24)^params(6);
lhs =y(40);
rhs =T287/T254*params(35);
residual(13)= lhs-rhs;
lhs =y(41);
rhs =T320/T254*params(36);
residual(14)= lhs-rhs;
lhs =y(42);
rhs =y(41)/y(40);
residual(15)= lhs-rhs;
lhs =y(61);
rhs =T232/T254;
residual(16)= lhs-rhs;
lhs =y(62);
rhs =T267/T287;
residual(17)= lhs-rhs;
lhs =y(63);
rhs =T300/T320;
residual(18)= lhs-rhs;
lhs =y(43)+y(4)*params(37)*T43*T367/y(7)+T379*T380+params(39)*T62*T387+y(82)*T396/y(76)/y(31);
rhs =T403*T405;
residual(19)= lhs-rhs;
lhs =y(46)+y(10)*params(38)*T53/y(31)/y(7)+T419*T424+params(37)*T43*T428+T379*T433;
rhs =T405*T437;
residual(20)= lhs-rhs;
lhs =y(49)+y(4)*params(39)*T62/y(25)/y(10)+T396*T449+params(38)*T53*T454+y(79)*T419/y(82)/y(28);
rhs =T405*T462;
residual(21)= lhs-rhs;
lhs =y(44)+y(8)*params(40)*T98/y(29)/y(5)+T478*T483+params(42)*T117*T488+T497*T501;
rhs =T505*T506;
residual(22)= lhs-rhs;
lhs =y(47)+params(41)*T108*T514+T522*T523+params(40)*T98*T529+y(77)*T478/y(80)/y(26);
rhs =T506*T537;
residual(23)= lhs-rhs;
lhs =y(50)+params(42)*T117*T545+y(32)*y(77)*T497/y(83)+params(41)*T108*T553+T522*T559;
rhs =T506*T563;
residual(24)= lhs-rhs;
lhs =y(45)+y(9)*params(43)*T153/y(30)/y(6)+T579*T584+params(45)*T172*T589+T598*T601;
rhs =T605*T606;
residual(25)= lhs-rhs;
lhs =y(48)+y(12)*params(44)*T163/y(33)/y(9)+T620*T625+params(43)*T153*T631+y(78)*T579/y(81)/y(27);
rhs =T606*T639;
residual(26)= lhs-rhs;
lhs =y(51)+params(45)*T172*T647+T598*T650+params(44)*T163*T656+y(81)*T620/y(84)/y(30);
rhs =T606*T664;
residual(27)= lhs-rhs;
lhs =y(34);
rhs =T675*T677;
residual(28)= lhs-rhs;
lhs =y(37);
rhs =y(64)*y(52)*(1-params(1))*T681*T684;
residual(29)= lhs-rhs;
lhs =y(35);
rhs =T693*T694;
residual(30)= lhs-rhs;
lhs =y(38);
rhs =(1-params(1))*y(65)*y(56)*T698*T700;
residual(31)= lhs-rhs;
lhs =y(36);
rhs =T709*T710;
residual(32)= lhs-rhs;
lhs =y(39);
rhs =(1-params(1))*y(66)*y(60)*T714*T716;
residual(33)= lhs-rhs;
lhs =y(52);
rhs =y(43);
residual(34)= lhs-rhs;
lhs =y(44);
rhs =(1+params(13))*y(53)/params(19);
residual(35)= lhs-rhs;
lhs =y(45);
rhs =(1+params(14))*y(54)/params(20);
residual(36)= lhs-rhs;
lhs =y(46);
rhs =(1+params(15))*y(55)/params(21);
residual(37)= lhs-rhs;
lhs =y(56);
rhs =y(47);
residual(38)= lhs-rhs;
lhs =y(48);
rhs =(1+params(16))*y(57)/params(22);
residual(39)= lhs-rhs;
lhs =y(49);
rhs =(1+params(17))*y(58)/params(23);
residual(40)= lhs-rhs;
lhs =y(50);
rhs =(1+params(16))*y(59)/params(22);
residual(41)= lhs-rhs;
lhs =y(60);
rhs =y(51);
residual(42)= lhs-rhs;
lhs =y(52);
rhs =y(40)*y(53);
residual(43)= lhs-rhs;
lhs =y(55);
rhs =y(40)*y(56);
residual(44)= lhs-rhs;
lhs =y(58);
rhs =y(40)*y(59);
residual(45)= lhs-rhs;
lhs =y(52);
rhs =y(41)*y(54);
residual(46)= lhs-rhs;
lhs =y(55);
rhs =y(41)*y(57);
residual(47)= lhs-rhs;
lhs =y(58);
rhs =y(41)*y(60);
residual(48)= lhs-rhs;
lhs =y(25)*params(7)+y(26)*params(8)+y(27)*params(9);
rhs =y(64)*params(7)*T677*T681;
residual(49)= lhs-rhs;
lhs =y(28)*params(7)+y(29)*params(8)+y(30)*params(9);
rhs =y(65)*params(8)*T694*T698;
residual(50)= lhs-rhs;
lhs =y(31)*params(7)+y(32)*params(8)+y(33)*params(9);
rhs =y(66)*params(9)*T710*T714;
residual(51)= lhs-rhs;
lhs =log(y(64));
rhs =params(10)*log(y(13))+x(it_, 1);
residual(52)= lhs-rhs;
lhs =log(y(65));
rhs =params(11)*log(y(14))+x(it_, 2);
residual(53)= lhs-rhs;
lhs =log(y(66));
rhs =params(12)*log(y(15))+x(it_, 3);
residual(54)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(54, 93);

  %
  % Jacobian matrix
  %

T822 = getPowerDeriv(T253,(-params(2)),1);
T840 = getPowerDeriv(T228,(-params(2)),1);
T846 = getPowerDeriv(T286,(-params(2)),1);
T857 = getPowerDeriv(T265,(-params(2)),1);
T863 = getPowerDeriv(T319,(-params(2)),1);
T874 = getPowerDeriv(T298,(-params(2)),1);
T917 = getPowerDeriv(y(19),params(1),1);
T961 = getPowerDeriv(y(20),params(1),1);
T1005 = getPowerDeriv(y(21),params(1),1);
T1015 = T822*params(46)*getPowerDeriv(y(22),1+params(6),1)/(1+params(6));
T1035 = getPowerDeriv(y(22),1-params(1),1);
T1048 = params(5)*T840*params(46)*getPowerDeriv(y(73),1+params(6),1)/(1+params(6));
T1056 = T846*params(46)*getPowerDeriv(y(23),1+params(6),1)/(1+params(6));
T1069 = getPowerDeriv(y(23),1-params(1),1);
T1082 = params(5)*T857*params(46)*getPowerDeriv(y(74),1+params(6),1)/(1+params(6));
T1090 = T863*params(46)*getPowerDeriv(y(24),1+params(6),1)/(1+params(6));
T1103 = getPowerDeriv(y(24),1-params(1),1);
T1116 = params(5)*T874*params(46)*getPowerDeriv(y(75),1+params(6),1)/(1+params(6));
T1121 = y(28)/y(25)/y(7);
T1126 = y(31)/y(25)/y(10);
T1152 = params(25)*getPowerDeriv(y(25),T16,1);
T1153 = getPowerDeriv(T32,T33,1);
T1158 = y(4)*(-y(28))/(y(25)*y(25))/y(7);
T1164 = y(4)*(-y(31))/(y(25)*y(25))/y(10);
T1193 = params(39)*y(61)*y(82)/y(76)/y(31);
T1200 = getPowerDeriv(T32,T404,1);
T1234 = params(37)*y(61)*y(25)*(-y(79))/(y(76)*y(76))/y(28);
T1242 = params(39)*y(61)*y(25)*(-y(82))/(y(76)*y(76))/y(31);
T1263 = (-(y(26)/y(29)*y(8)))/(y(5)*y(5));
T1269 = (-(y(11)*y(26)/y(32)))/(y(5)*y(5));
T1300 = params(28)*params(19)*getPowerDeriv(params(19)*y(26),T16,1);
T1301 = getPowerDeriv(T88,T33,1);
T1305 = y(8)*1/y(29)/y(5);
T1311 = y(11)*1/y(32)/y(5);
T1322 = params(40)*y(62)*(-(y(29)*y(77)/y(80)))/(y(26)*y(26));
T1337 = params(42)*y(62)*(-(y(32)*y(77)/y(83)))/(y(26)*y(26));
T1350 = getPowerDeriv(T88,T404,1);
T1383 = params(40)*y(62)*y(29)*1/y(80)/y(26);
T1393 = params(42)*y(62)*y(32)*1/y(83)/y(26);
T1409 = (-(y(27)/y(30)*y(9)))/(y(6)*y(6));
T1415 = (-(y(12)*y(27)/y(33)))/(y(6)*y(6));
T1446 = params(31)*params(20)*getPowerDeriv(params(20)*y(27),T16,1);
T1447 = getPowerDeriv(T143,T33,1);
T1451 = y(9)*1/y(30)/y(6);
T1457 = y(12)*1/y(33)/y(6);
T1468 = params(43)*y(62)*(-(y(30)*y(78)/y(81)))/(y(27)*y(27));
T1483 = params(45)*y(62)*(-(y(33)*y(78)/y(84)))/(y(27)*y(27));
T1494 = getPowerDeriv(T143,T404,1);
T1529 = params(43)*y(62)*y(30)*1/y(81)/y(27);
T1539 = params(45)*y(62)*y(33)*1/y(84)/y(27);
T1557 = (-(y(28)/y(25)*y(4)))/(y(7)*y(7));
T1562 = (-(y(28)/y(31)*y(10)))/(y(7)*y(7));
T1593 = params(26)*params(21)*getPowerDeriv(params(21)*y(28),T16,1);
T1597 = y(4)*1/y(25)/y(7);
T1603 = y(10)*1/y(31)/y(7);
T1617 = params(37)*y(61)*(-(y(25)*y(79)/y(76)))/(y(28)*y(28));
T1633 = params(38)*y(61)*(-(y(31)*y(79)/y(82)))/(y(28)*y(28));
T1676 = params(37)*y(61)*y(25)*1/y(76)/y(28);
T1684 = params(38)*y(61)*y(31)*1/y(82)/y(28);
T1702 = y(26)/y(29)/y(5);
T1706 = y(32)/y(29)/y(11);
T1732 = params(29)*getPowerDeriv(y(29),T16,1);
T1737 = y(8)*(-y(26))/(y(29)*y(29))/y(5);
T1743 = y(8)*(-y(32))/(y(29)*y(29))/y(11);
T1754 = params(40)*y(62)*y(77)/y(80)/y(26);
T1812 = params(40)*y(62)*y(29)*(-y(77))/(y(80)*y(80))/y(26);
T1822 = params(41)*y(62)*y(29)*(-y(83))/(y(80)*y(80))/y(32);
T1839 = y(27)/y(30)/y(6);
T1845 = (-(y(30)/y(33)*y(12)))/(y(9)*y(9));
T1873 = params(32)*params(22)*getPowerDeriv(params(22)*y(30),T16,1);
T1878 = y(9)*(-y(27))/(y(30)*y(30))/y(6);
T1882 = y(12)*1/y(33)/y(9);
T1893 = params(43)*y(62)*y(78)/y(81)/y(27);
T1908 = params(44)*y(62)*(-(y(33)*y(81)/y(84)))/(y(30)*y(30));
T1956 = params(43)*y(62)*y(30)*(-y(78))/(y(81)*y(81))/y(27);
T1964 = params(44)*y(62)*y(33)*1/y(84)/y(30);
T1979 = y(28)/y(31)/y(7);
T1985 = (-(y(4)*y(31)/y(25)))/(y(10)*y(10));
T2012 = params(27)*params(23)*getPowerDeriv(params(23)*y(31),T16,1);
T2017 = y(10)*(-y(28))/(y(31)*y(31))/y(7);
T2021 = y(4)*1/y(25)/y(10);
T2033 = params(39)*y(61)*(-(y(25)*y(82)/y(76)))/(y(31)*y(31));
T2050 = params(38)*y(61)*y(79)/y(82)/y(28);
T2091 = params(39)*y(61)*y(25)*1/y(76)/y(31);
T2100 = params(38)*y(61)*y(31)*(-y(79))/(y(82)*y(82))/y(28);
T2119 = (-(y(8)*y(32)/y(29)))/(y(11)*y(11));
T2123 = y(26)/y(32)/y(5);
T2154 = params(30)*params(24)*getPowerDeriv(params(24)*y(32),T16,1);
T2156 = y(8)*1/y(29)/y(11);
T2163 = y(11)*(-y(26))/(y(32)*y(32))/y(5);
T2174 = params(42)*y(62)*y(77)/y(83)/y(26);
T2192 = params(41)*y(62)*(-(y(29)*y(83)/y(80)))/(y(32)*y(32));
T2234 = params(42)*y(62)*y(32)*(-y(77))/(y(83)*y(83))/y(26);
T2241 = params(41)*y(62)*y(29)*1/y(80)/y(32);
T2256 = y(30)/y(33)/y(9);
T2260 = y(27)/y(33)/y(6);
T2289 = params(33)*getPowerDeriv(y(33),T16,1);
T2294 = y(12)*(-y(30))/(y(33)*y(33))/y(9);
T2300 = y(12)*(-y(27))/(y(33)*y(33))/y(6);
T2326 = params(44)*y(62)*y(81)/y(84)/y(30);
T2367 = params(45)*y(62)*y(33)*(-y(78))/(y(84)*y(84))/y(27);
T2377 = params(44)*y(62)*y(33)*(-y(81))/(y(84)*y(84))/y(30);
  g1(1,16)=(-1);
  g1(1,4)=(-(T37*T1121*2*T43))-T58*T1126*2*T62;
  g1(1,25)=T1152*T1153-T37*2*T43*T1158-T58*2*T62*T1164;
  g1(1,7)=(-(T37*2*T43*T1557))-T48*T1562*2*T53;
  g1(1,28)=T1153*T1593-T37*2*T43*T1597-T48*2*T53*T1603;
  g1(1,10)=(-(T48*2*T53*T1979))-T58*2*T62*T1985;
  g1(1,31)=T1153*T2012-T48*2*T53*T2017-T58*2*T62*T2021;
  g1(1,67)=(-1);
  g1(2,17)=(-1);
  g1(2,5)=(-(T92*T1263*2*T98))-T113*T1269*2*T117;
  g1(2,26)=T1300*T1301-T92*2*T98*T1305-T113*2*T117*T1311;
  g1(2,8)=(-(T92*2*T98*T1702))-T103*T1706*2*T108;
  g1(2,29)=T1301*T1732-T92*2*T98*T1737-T103*2*T108*T1743;
  g1(2,11)=(-(T103*2*T108*T2119))-T113*2*T117*T2123;
  g1(2,32)=T1301*T2154-T103*2*T108*T2156-T113*2*T117*T2163;
  g1(2,68)=(-1);
  g1(3,18)=(-1);
  g1(3,6)=(-(T147*T1409*2*T153))-T168*T1415*2*T172;
  g1(3,27)=T1446*T1447-T147*2*T153*T1451-T168*2*T172*T1457;
  g1(3,9)=(-(T147*2*T153*T1839))-T158*T1845*2*T163;
  g1(3,30)=T1447*T1873-T147*2*T153*T1878-T158*2*T163*T1882;
  g1(3,12)=(-(T158*2*T163*T2256))-T168*2*T172*T2260;
  g1(3,33)=T1447*T2289-T158*2*T163*T2294-T168*2*T172*T2300;
  g1(3,69)=(-1);
  g1(4,1)=1-params(3)-(params(47)*T189+y(1)*params(47)*(-y(67))/(y(1)*y(1))*2*(y(67)/y(1)-params(3)));
  g1(4,19)=(-1);
  g1(4,67)=1-y(1)*params(47)*2*(y(67)/y(1)-params(3))*1/y(1);
  g1(5,2)=1-params(3)-(params(47)*T202+params(47)*y(2)*(-y(68))/(y(2)*y(2))*2*(y(68)/y(2)-params(3)));
  g1(5,20)=(-1);
  g1(5,68)=1-params(47)*y(2)*2*(y(68)/y(2)-params(3))*1/y(2);
  g1(6,3)=1-params(3)-(params(47)*T215+params(47)*y(3)*(-y(69))/(y(3)*y(3))*2*(y(69)/y(3)-params(3)));
  g1(6,21)=(-1);
  g1(6,69)=1-params(47)*y(3)*2*(y(69)/y(3)-params(3))*1/y(3);
  g1(7,16)=(-(T822/T256));
  g1(7,70)=T247*params(5)*T840/T237;
  g1(7,1)=(-((-(T254*(-(params(47)*(-y(67))/(y(1)*y(1))))))/(T256*T256)));
  g1(7,19)=T247*(-(T232*(-(params(47)*(-y(88))/(y(19)*y(19))))))/(T237*T237)+T238*(-(T242*(-((-y(88))/(y(19)*y(19))*2*y(88)/y(19)))));
  g1(7,22)=(-(T1015/T256));
  g1(7,73)=T247*T1048/T237;
  g1(7,85)=T238;
  g1(7,67)=(-((-(T254*(-(params(47)*1/y(1)))))/(T256*T256)));
  g1(7,88)=T247*(-(T232*(-(params(47)*1/y(19)))))/(T237*T237)+T238*(-(T242*(-(2*y(88)/y(19)*1/y(19)))));
  g1(8,17)=(-(T846/T289));
  g1(8,71)=T280*params(5)*T857/T272;
  g1(8,2)=(-((-(T287*(-(params(47)*(-y(68))/(y(2)*y(2))))))/(T289*T289)));
  g1(8,20)=T280*(-(T267*(-(params(47)*(-y(89))/(y(20)*y(20))))))/(T272*T272)+T273*(-(T242*(-((-y(89))/(y(20)*y(20))*2*y(89)/y(20)))));
  g1(8,23)=(-(T1056/T289));
  g1(8,74)=T280*T1082/T272;
  g1(8,86)=T273;
  g1(8,68)=(-((-(T287*(-(params(47)*1/y(2)))))/(T289*T289)));
  g1(8,89)=T280*(-(T267*(-(params(47)*1/y(20)))))/(T272*T272)+T273*(-(T242*(-(2*y(89)/y(20)*1/y(20)))));
  g1(9,18)=(-(T863/T322));
  g1(9,72)=T313*params(5)*T874/T305;
  g1(9,3)=(-((-(T320*(-(params(47)*(-y(69))/(y(3)*y(3))))))/(T322*T322)));
  g1(9,21)=T313*(-(T300*(-(params(47)*(-y(90))/(y(21)*y(21))))))/(T305*T305)+T306*(-(T242*(-((-y(90))/(y(21)*y(21))*2*y(90)/y(21)))));
  g1(9,24)=(-(T1090/T322));
  g1(9,75)=T313*T1116/T305;
  g1(9,87)=T306;
  g1(9,69)=(-((-(T320*(-(params(47)*1/y(3)))))/(T322*T322)));
  g1(9,90)=T313*(-(T300*(-(params(47)*1/y(21)))))/(T305*T305)+T306*(-(T242*(-(2*y(90)/y(21)*1/y(21)))));
  g1(10,22)=(-(params(46)*getPowerDeriv(y(22),params(6),1)));
  g1(10,37)=1;
  g1(11,23)=(-(params(46)*getPowerDeriv(y(23),params(6),1)));
  g1(11,38)=1;
  g1(12,24)=(-(params(46)*getPowerDeriv(y(24),params(6),1)));
  g1(12,39)=1;
  g1(13,16)=(-(params(35)*(-(T287*T822))/(T254*T254)));
  g1(13,17)=(-(params(35)*T846/T254));
  g1(13,22)=(-(params(35)*(-(T287*T1015))/(T254*T254)));
  g1(13,23)=(-(params(35)*T1056/T254));
  g1(13,40)=1;
  g1(14,16)=(-(params(36)*(-(T320*T822))/(T254*T254)));
  g1(14,18)=(-(params(36)*T863/T254));
  g1(14,22)=(-(params(36)*(-(T320*T1015))/(T254*T254)));
  g1(14,24)=(-(params(36)*T1090/T254));
  g1(14,41)=1;
  g1(15,40)=(-((-y(41))/(y(40)*y(40))));
  g1(15,41)=(-(1/y(40)));
  g1(15,42)=1;
  g1(16,16)=(-((-(T232*T822))/(T254*T254)));
  g1(16,70)=(-(params(5)*T840/T254));
  g1(16,22)=(-((-(T232*T1015))/(T254*T254)));
  g1(16,73)=(-(T1048/T254));
  g1(16,61)=1;
  g1(17,17)=(-((-(T267*T846))/(T287*T287)));
  g1(17,71)=(-(params(5)*T857/T287));
  g1(17,23)=(-((-(T267*T1056))/(T287*T287)));
  g1(17,74)=(-(T1082/T287));
  g1(17,62)=1;
  g1(18,18)=(-((-(T300*T863))/(T320*T320)));
  g1(18,72)=(-(params(5)*T874/T320));
  g1(18,24)=(-((-(T300*T1090))/(T320*T320)));
  g1(18,75)=(-(T1116/T320));
  g1(18,63)=1;
  g1(19,4)=(params(37)*T43*T367+y(4)*T367*params(37)*T1121)/y(7)+T387*params(39)*T1126+params(39)*T62*(-y(31))/T366/y(10);
  g1(19,25)=y(4)*(T367*params(37)*T1158+params(37)*T43*(-((-y(28))*2*y(25)))/(T366*T366))/y(7)+T380*params(37)*y(61)*T380+T387*params(39)*T1164+params(39)*T62*y(4)*(-((-y(31))*2*y(25)))/(T366*T366)/y(10)+y(82)*T1193/y(76)/y(31)-(T405*params(25)*getPowerDeriv(y(25),T401,1)+T403*T1152*T1200);
  g1(19,76)=T380*T1234+T379*(-y(79))/(y(76)*y(76))/y(28)+(y(76)*y(82)*T1242-y(82)*T396)/(y(76)*y(76))/y(31);
  g1(19,7)=(y(7)*y(4)*T367*params(37)*T1557-y(4)*params(37)*T43*T367)/(y(7)*y(7));
  g1(19,28)=y(4)*(T367*params(37)*T1597+params(37)*T43*(-1)/T366)/y(7)+T380*T1617+T379*(-(y(79)/y(76)))/(y(28)*y(28))-T403*T1200*T1593;
  g1(19,79)=T380*T1676+T379*1/y(76)/y(28);
  g1(19,10)=T387*params(39)*T1985+params(39)*T62*(-(y(4)*(-y(31))/T366))/(y(10)*y(10));
  g1(19,31)=T387*params(39)*T2021+params(39)*T62*y(4)*(-1)/T366/y(10)+(y(31)*y(82)*T2033/y(76)-y(82)*T396/y(76))/(y(31)*y(31))-T403*T1200*T2012;
  g1(19,82)=(T396+y(82)*T2091)/y(76)/y(31);
  g1(19,43)=1;
  g1(19,61)=T380*params(37)*T378+y(82)*params(39)*T395/y(76)/y(31);
  g1(20,4)=T428*params(37)*T1121+params(37)*T43*1/y(7)/y(25);
  g1(20,25)=T428*params(37)*T1158+params(37)*T43*(-(y(4)/y(7)))/(y(25)*y(25))+T433*params(37)*y(61)*T380+T379*(-y(79))/y(76)/T423-T437*T1152*T1200;
  g1(20,76)=T433*T1234+T379*y(25)*y(79)/(y(76)*y(76))/T423;
  g1(20,7)=(y(7)*y(10)*params(38)*T1562/y(31)-y(10)*params(38)*T53/y(31))/(y(7)*y(7))+T428*params(37)*T1557+params(37)*T43*(-y(4))/(y(7)*y(7))/y(25);
  g1(20,28)=y(10)*params(38)*T1603/y(31)/y(7)+T424*T1633+T419*(-(y(31)*(-y(79))/y(82)*2*y(28)))/(T423*T423)+T428*params(37)*T1597+T433*T1617+T379*(-(y(25)*(-y(79))/y(76)*2*y(28)))/(T423*T423)-(T437*T1200*T1593+T405*params(26)*params(21)*getPowerDeriv(params(21)*y(28),T401,1));
  g1(20,79)=T424*T1684+T419*y(31)*(-1)/y(82)/T423+T433*T1676+T379*y(25)*(-1)/y(76)/T423;
  g1(20,10)=(params(38)*T53+y(10)*params(38)*T1979)/y(31)/y(7);
  g1(20,31)=(y(31)*y(10)*params(38)*T2017-y(10)*params(38)*T53)/(y(31)*y(31))/y(7)+T424*T2050+T419*(-y(79))/y(82)/T423-T437*T1200*T2012;
  g1(20,82)=T424*T2100+T419*y(31)*y(79)/(y(82)*y(82))/T423;
  g1(20,46)=1;
  g1(20,61)=T424*params(38)*T418+T433*params(37)*T378;
  g1(21,4)=(params(39)*T62+y(4)*params(39)*T1126)/y(25)/y(10);
  g1(21,25)=(y(25)*y(4)*params(39)*T1164-y(4)*params(39)*T62)/(y(25)*y(25))/y(10)+T449*T1193+T396*(-y(82))/y(76)/T448-T462*T1152*T1200;
  g1(21,76)=T449*T1242+T396*y(25)*y(82)/(y(76)*y(76))/T448;
  g1(21,7)=T454*params(38)*T1562+params(38)*T53*(-(y(10)*(-y(28))/T448))/(y(7)*y(7));
  g1(21,28)=T454*params(38)*T1603+params(38)*T53*y(10)*(-1)/T448/y(7)+(y(28)*y(79)*T1633/y(82)-y(79)*T419/y(82))/(y(28)*y(28))-T462*T1200*T1593;
  g1(21,79)=(T419+y(79)*T1684)/y(82)/y(28);
  g1(21,10)=(y(10)*y(4)*params(39)*T1985/y(25)-y(4)*params(39)*T62/y(25))/(y(10)*y(10))+T454*params(38)*T1979+params(38)*T53*(-y(28))/T448/y(7);
  g1(21,31)=y(4)*params(39)*T2021/y(25)/y(10)+T449*T2033+T396*(-(y(25)*(-y(82))/y(76)*2*y(31)))/(T448*T448)+T454*params(38)*T2017+params(38)*T53*y(10)*(-((-y(28))*2*y(31)))/(T448*T448)/y(7)+y(79)*T2050/y(82)/y(28)-(T462*T1200*T2012+T405*params(27)*params(23)*getPowerDeriv(params(23)*y(31),T401,1));
  g1(21,82)=T449*T2091+T396*y(25)*(-1)/y(76)/T448+(y(82)*y(79)*T2100-y(79)*T419)/(y(82)*y(82))/y(28);
  g1(21,49)=1;
  g1(21,61)=T449*params(39)*T395+y(79)*params(38)*T418/y(82)/y(28);
  g1(22,5)=(y(5)*y(8)*params(40)*T1263/y(29)-y(8)*params(40)*T98/y(29))/(y(5)*y(5))+T488*params(42)*T1269+params(42)*T117*(-y(11))/(y(5)*y(5))/y(32);
  g1(22,26)=y(8)*params(40)*T1305/y(29)/y(5)+T483*T1322+T478*(-(y(29)*(-y(77))/y(80)*2*y(26)))/(T482*T482)+T488*params(42)*T1311+T501*T1337+T497*y(77)*(-((-y(32))*2*y(26)))/(T482*T482)/y(83)-(T506*params(28)*params(19)*getPowerDeriv(params(19)*y(26),T401,1)+T505*T1300*T1350);
  g1(22,77)=T483*T1383+T478*y(29)*(-1)/y(80)/T482+T501*T1393+T497*(-y(32))/T482/y(83);
  g1(22,8)=(params(40)*T98+y(8)*params(40)*T1702)/y(29)/y(5);
  g1(22,29)=(y(29)*y(8)*params(40)*T1737-y(8)*params(40)*T98)/(y(29)*y(29))/y(5)+T483*T1754+T478*(-y(77))/y(80)/T482-T505*T1350*T1732;
  g1(22,80)=T483*T1812+T478*y(29)*y(77)/(y(80)*y(80))/T482;
  g1(22,11)=T488*params(42)*T2123+params(42)*T117*1/y(5)/y(32);
  g1(22,32)=T488*params(42)*T2163+params(42)*T117*(-(y(11)/y(5)))/(y(32)*y(32))+T501*T2174+T497*y(77)*(-1)/T482/y(83)-T505*T1350*T2154;
  g1(22,83)=T501*T2234+T497*(-(y(77)*(-y(32))/T482))/(y(83)*y(83));
  g1(22,44)=1;
  g1(22,62)=T483*params(40)*T477+T501*params(42)*T496;
  g1(23,5)=T529*params(40)*T1263+params(40)*T98*(-(y(8)*(-y(26))/T511))/(y(5)*y(5));
  g1(23,26)=T529*params(40)*T1305+params(40)*T98*y(8)*(-1)/T511/y(5)+(y(26)*y(77)*T1322/y(80)-y(77)*T478/y(80))/(y(26)*y(26))-T537*T1300*T1350;
  g1(23,77)=(T478+y(77)*T1383)/y(80)/y(26);
  g1(23,8)=T514*params(41)*T1706+params(41)*T108*(-y(32))/T511/y(11)+T529*params(40)*T1702+params(40)*T98*(-y(26))/T511/y(5);
  g1(23,29)=T514*params(41)*T1743+params(41)*T108*y(8)*(-((-y(32))*2*y(29)))/(T511*T511)/y(11)+T523*params(41)*y(62)*T523+T529*params(40)*T1737+params(40)*T98*y(8)*(-((-y(26))*2*y(29)))/(T511*T511)/y(5)+y(77)*T1754/y(80)/y(26)-(T537*T1350*T1732+T506*params(29)*getPowerDeriv(y(29),T401,1));
  g1(23,80)=T523*T1822+T522*(-y(83))/(y(80)*y(80))/y(32)+(y(80)*y(77)*T1812-y(77)*T478)/(y(80)*y(80))/y(26);
  g1(23,11)=T514*params(41)*T2119+params(41)*T108*(-(y(8)*(-y(32))/T511))/(y(11)*y(11));
  g1(23,32)=T514*params(41)*T2156+params(41)*T108*y(8)*(-1)/T511/y(11)+T523*T2192+T522*(-(y(83)/y(80)))/(y(32)*y(32))-T537*T1350*T2154;
  g1(23,83)=T523*T2241+T522*1/y(80)/y(32);
  g1(23,47)=1;
  g1(23,62)=T523*params(41)*T521+y(77)*params(40)*T477/y(80)/y(26);
  g1(24,5)=T545*params(42)*T1269+params(42)*T117*y(26)*y(11)/(y(5)*y(5))/T544;
  g1(24,26)=T545*params(42)*T1311+params(42)*T117*(-y(11))/y(5)/T544+y(32)*y(77)*T1337/y(83)-T563*T1300*T1350;
  g1(24,77)=y(32)*(T497+y(77)*T1393)/y(83);
  g1(24,8)=T553*params(41)*T1706+params(41)*T108*1/y(11)/y(29);
  g1(24,29)=T553*params(41)*T1743+params(41)*T108*(-(y(8)/y(11)))/(y(29)*y(29))+T559*params(41)*y(62)*T523+T522*(-y(83))/y(80)/T544-T563*T1350*T1732;
  g1(24,80)=T559*T1822+T522*y(29)*y(83)/(y(80)*y(80))/T544;
  g1(24,11)=T545*params(42)*T2123+params(42)*T117*y(26)*(-1)/y(5)/T544+T553*params(41)*T2119+params(41)*T108*(-y(8))/(y(11)*y(11))/y(29);
  g1(24,32)=T545*params(42)*T2163+params(42)*T117*(-(y(26)*(-y(11))/y(5)*2*y(32)))/(T544*T544)+y(77)*T497/y(83)+y(32)*y(77)*T2174/y(83)+T553*params(41)*T2156+T559*T2192+T522*(-(y(29)*(-y(83))/y(80)*2*y(32)))/(T544*T544)-(T563*T1350*T2154+T506*params(30)*params(24)*getPowerDeriv(params(24)*y(32),T401,1));
  g1(24,83)=y(32)*(y(83)*y(77)*T2234-y(77)*T497)/(y(83)*y(83))+T559*T2241+T522*y(29)*(-1)/y(80)/T544;
  g1(24,50)=1;
  g1(24,62)=y(32)*y(77)*params(42)*T496/y(83)+T559*params(41)*T521;
  g1(25,6)=(y(6)*y(9)*params(43)*T1409/y(30)-y(9)*params(43)*T153/y(30))/(y(6)*y(6))+T589*params(45)*T1415+params(45)*T172*1/y(12)/y(33);
  g1(25,27)=y(9)*params(43)*T1451/y(30)/y(6)+T584*T1468+T579*(-(y(30)*(-y(78))/y(81)*2*y(27)))/(T583*T583)+T589*params(45)*T1457+T601*T1483+T598*(-(y(33)*(-y(78))/y(84)*2*y(27)))/(T583*T583)-(T606*params(31)*params(20)*getPowerDeriv(params(20)*y(27),T401,1)+T605*T1446*T1494);
  g1(25,78)=T584*T1529+T579*y(30)*(-1)/y(81)/T583+T601*T1539+T598*y(33)*(-1)/y(84)/T583;
  g1(25,9)=(params(43)*T153+y(9)*params(43)*T1839)/y(30)/y(6);
  g1(25,30)=(y(30)*y(9)*params(43)*T1878-y(9)*params(43)*T153)/(y(30)*y(30))/y(6)+T584*T1893+T579*(-y(78))/y(81)/T583-T605*T1494*T1873;
  g1(25,81)=T584*T1956+T579*y(30)*y(78)/(y(81)*y(81))/T583;
  g1(25,12)=T589*params(45)*T2260+params(45)*T172*(-y(6))/(y(12)*y(12))/y(33);
  g1(25,33)=T589*params(45)*T2300+params(45)*T172*(-(y(6)/y(12)))/(y(33)*y(33))+T601*params(45)*y(62)*T650+T598*(-y(78))/y(84)/T583-T605*T1494*T2289;
  g1(25,84)=T601*T2367+T598*y(33)*y(78)/(y(84)*y(84))/T583;
  g1(25,45)=1;
  g1(25,62)=T584*params(43)*T578+T601*params(45)*T597;
  g1(26,6)=T631*params(43)*T1409+params(43)*T153*(-(y(9)*(-y(27))/T624))/(y(6)*y(6));
  g1(26,27)=T631*params(43)*T1451+params(43)*T153*y(9)*(-1)/T624/y(6)+(y(27)*y(78)*T1468/y(81)-y(78)*T579/y(81))/(y(27)*y(27))-T639*T1446*T1494;
  g1(26,78)=(T579+y(78)*T1529)/y(81)/y(27);
  g1(26,9)=(y(9)*y(12)*params(44)*T1845/y(33)-y(12)*params(44)*T163/y(33))/(y(9)*y(9))+T631*params(43)*T1839+params(43)*T153*(-y(27))/T624/y(6);
  g1(26,30)=y(12)*params(44)*T1882/y(33)/y(9)+T625*T1908+T620*(-(y(33)*(-y(81))/y(84)*2*y(30)))/(T624*T624)+T631*params(43)*T1878+params(43)*T153*y(9)*(-((-y(27))*2*y(30)))/(T624*T624)/y(6)+y(78)*T1893/y(81)/y(27)-(T639*T1494*T1873+T606*params(32)*params(22)*getPowerDeriv(params(22)*y(30),T401,1));
  g1(26,81)=T625*T1964+T620*y(33)*(-1)/y(84)/T624+(y(81)*y(78)*T1956-y(78)*T579)/(y(81)*y(81))/y(27);
  g1(26,12)=(params(44)*T163+y(12)*params(44)*T2256)/y(33)/y(9);
  g1(26,33)=(y(33)*y(12)*params(44)*T2294-y(12)*params(44)*T163)/(y(33)*y(33))/y(9)+T625*T2326+T620*(-y(81))/y(84)/T624-T639*T1494*T2289;
  g1(26,84)=T625*T2377+T620*y(33)*y(81)/(y(84)*y(84))/T624;
  g1(26,48)=1;
  g1(26,62)=T625*params(44)*T619+y(78)*params(43)*T578/y(81)/y(27);
  g1(27,6)=T647*params(45)*T1415+params(45)*T172*y(27)*y(12)/(y(6)*y(6))/T646;
  g1(27,27)=T647*params(45)*T1457+params(45)*T172*(-y(12))/y(6)/T646+T650*T1483+T598*(-(y(78)/y(84)))/(y(27)*y(27))-T664*T1446*T1494;
  g1(27,78)=T650*T1539+T598*1/y(84)/y(27);
  g1(27,9)=T656*params(44)*T1845+params(44)*T163*(-(y(12)*(-y(30))/T646))/(y(9)*y(9));
  g1(27,30)=T656*params(44)*T1882+params(44)*T163*y(12)*(-1)/T646/y(9)+(y(30)*y(81)*T1908/y(84)-y(81)*T620/y(84))/(y(30)*y(30))-T664*T1494*T1873;
  g1(27,81)=(T620+y(81)*T1964)/y(84)/y(30);
  g1(27,12)=T647*params(45)*T2260+params(45)*T172*y(27)*(-1)/y(6)/T646+T656*params(44)*T2256+params(44)*T163*(-y(30))/T646/y(9);
  g1(27,33)=T647*params(45)*T2300+params(45)*T172*(-(y(27)*(-y(12))/y(6)*2*y(33)))/(T646*T646)+T650*params(45)*y(62)*T650+T656*params(44)*T2294+params(44)*T163*y(12)*(-((-y(30))*2*y(33)))/(T646*T646)/y(9)+y(81)*T2326/y(84)/y(30)-(T664*T1494*T2289+T606*params(33)*getPowerDeriv(y(33),T401,1));
  g1(27,84)=T650*T2367+T598*(-y(78))/(y(84)*y(84))/y(27)+(y(84)*y(81)*T2377-y(81)*T620)/(y(84)*y(84))/y(30);
  g1(27,51)=1;
  g1(27,62)=T650*params(45)*T597+y(81)*params(44)*T619/y(84)/y(30);
  g1(28,19)=(-(T677*y(64)*y(52)*params(1)*getPowerDeriv(y(19),params(1)-1,1)));
  g1(28,22)=(-(T675*T1035));
  g1(28,34)=1;
  g1(28,52)=(-(T677*T674*y(64)*params(1)));
  g1(28,64)=(-(T677*T674*y(52)*params(1)));
  g1(29,19)=(-(T684*y(64)*y(52)*(1-params(1))*T917));
  g1(29,22)=(-(y(64)*y(52)*(1-params(1))*T681*getPowerDeriv(y(22),(-params(1)),1)));
  g1(29,37)=1;
  g1(29,52)=(-(T684*T681*y(64)*(1-params(1))));
  g1(29,64)=(-(T684*T681*y(52)*(1-params(1))));
  g1(30,20)=(-(T694*params(1)*y(65)*y(56)*getPowerDeriv(y(20),params(1)-1,1)));
  g1(30,23)=(-(T693*T1069));
  g1(30,35)=1;
  g1(30,56)=(-(T694*T692*params(1)*y(65)));
  g1(30,65)=(-(T694*T692*params(1)*y(56)));
  g1(31,20)=(-(T700*(1-params(1))*y(65)*y(56)*T961));
  g1(31,23)=(-((1-params(1))*y(65)*y(56)*T698*getPowerDeriv(y(23),(-params(1)),1)));
  g1(31,38)=1;
  g1(31,56)=(-(T700*T698*(1-params(1))*y(65)));
  g1(31,65)=(-(T700*T698*(1-params(1))*y(56)));
  g1(32,21)=(-(T710*params(1)*y(66)*y(60)*getPowerDeriv(y(21),params(1)-1,1)));
  g1(32,24)=(-(T709*T1103));
  g1(32,36)=1;
  g1(32,60)=(-(T710*T708*params(1)*y(66)));
  g1(32,66)=(-(T710*T708*params(1)*y(60)));
  g1(33,21)=(-(T716*(1-params(1))*y(66)*y(60)*T1005));
  g1(33,24)=(-((1-params(1))*y(66)*y(60)*T714*getPowerDeriv(y(24),(-params(1)),1)));
  g1(33,39)=1;
  g1(33,60)=(-(T716*T714*(1-params(1))*y(66)));
  g1(33,66)=(-(T716*T714*(1-params(1))*y(60)));
  g1(34,43)=(-1);
  g1(34,52)=1;
  g1(35,44)=1;
  g1(35,53)=(-((1+params(13))/params(19)));
  g1(36,45)=1;
  g1(36,54)=(-((1+params(14))/params(20)));
  g1(37,46)=1;
  g1(37,55)=(-((1+params(15))/params(21)));
  g1(38,47)=(-1);
  g1(38,56)=1;
  g1(39,48)=1;
  g1(39,57)=(-((1+params(16))/params(22)));
  g1(40,49)=1;
  g1(40,58)=(-((1+params(17))/params(23)));
  g1(41,50)=1;
  g1(41,59)=(-((1+params(16))/params(22)));
  g1(42,51)=(-1);
  g1(42,60)=1;
  g1(43,40)=(-y(53));
  g1(43,52)=1;
  g1(43,53)=(-y(40));
  g1(44,40)=(-y(56));
  g1(44,55)=1;
  g1(44,56)=(-y(40));
  g1(45,40)=(-y(59));
  g1(45,58)=1;
  g1(45,59)=(-y(40));
  g1(46,41)=(-y(54));
  g1(46,52)=1;
  g1(46,54)=(-y(41));
  g1(47,41)=(-y(57));
  g1(47,55)=1;
  g1(47,57)=(-y(41));
  g1(48,41)=(-y(60));
  g1(48,58)=1;
  g1(48,60)=(-y(41));
  g1(49,19)=(-(y(64)*params(7)*T677*T917));
  g1(49,22)=(-(y(64)*params(7)*T681*T1035));
  g1(49,25)=params(7);
  g1(49,26)=params(8);
  g1(49,27)=params(9);
  g1(49,64)=(-(params(7)*T677*T681));
  g1(50,20)=(-(y(65)*params(8)*T694*T961));
  g1(50,23)=(-(y(65)*params(8)*T698*T1069));
  g1(50,28)=params(7);
  g1(50,29)=params(8);
  g1(50,30)=params(9);
  g1(50,65)=(-(params(8)*T694*T698));
  g1(51,21)=(-(y(66)*params(9)*T710*T1005));
  g1(51,24)=(-(y(66)*params(9)*T714*T1103));
  g1(51,31)=params(7);
  g1(51,32)=params(8);
  g1(51,33)=params(9);
  g1(51,66)=(-(params(9)*T710*T714));
  g1(52,13)=(-(params(10)*1/y(13)));
  g1(52,64)=1/y(64);
  g1(52,91)=(-1);
  g1(53,14)=(-(params(11)*1/y(14)));
  g1(53,65)=1/y(65);
  g1(53,92)=(-1);
  g1(54,15)=(-(params(12)*1/y(15)));
  g1(54,66)=1/y(66);
  g1(54,93)=(-1);

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],54,8649);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],54,804357);
end
end
end
end
