function [residual, g1, g2, g3] = BKK3C_GHH2_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 54, 1);

%
% Model equations
%

T16 = (params(4)-1)/params(4);
T32 = params(25)*y(10)^T16+params(26)*(params(21)*y(13))^T16+params(27)*(params(23)*y(16))^T16;
T33 = params(4)/(params(4)-1);
T38 = y(13)/y(10);
T41 = y(10)*T38/y(13)-1;
T50 = y(16)*y(13)/y(16)/y(13)-1;
T59 = y(10)*y(16)/y(10)/y(16)-1;
T85 = params(28)*(params(19)*y(11))^T16+params(29)*y(14)^T16+params(30)*(params(24)*y(17))^T16;
T93 = y(14)*y(11)/y(14)/y(11)-1;
T99 = y(17)/y(14);
T102 = y(14)*T99/y(17)-1;
T111 = y(17)*y(11)/y(17)/y(11)-1;
T137 = params(31)*(params(20)*y(12))^T16+params(32)*(params(22)*y(15))^T16+params(33)*y(18)^T16;
T145 = y(15)*y(12)/y(15)/y(12)-1;
T154 = y(18)*y(15)/y(18)/y(15)-1;
T160 = y(12)/y(18);
T163 = y(18)*T160/y(12)-1;
T179 = (y(52)/y(4)-params(3))^2;
T191 = (y(53)/y(5)-params(3))^2;
T203 = (y(54)/y(6)-params(3))^2;
T215 = y(1)+params(46)*y(7)^(1+params(6))/(1+params(6));
T218 = T215^(-params(2));
T221 = 1-params(47)*(y(52)/y(4)-params(3));
T222 = params(5)*T218/T221;
T226 = params(47)/2;
T227 = params(3)^2;
T231 = 1+y(19)-params(3)-T226*(T227-(y(52)/y(4))^2);
T240 = y(2)+params(46)*y(8)^(1+params(6))/(1+params(6));
T241 = T240^(-params(2));
T244 = 1-params(47)*(y(53)/y(5)-params(3));
T245 = params(5)*T241/T244;
T252 = 1+y(20)-params(3)-T226*(T227-(y(53)/y(5))^2);
T261 = y(3)+params(46)*y(9)^(1+params(6))/(1+params(6));
T262 = T261^(-params(2));
T265 = 1-params(47)*(y(54)/y(6)-params(3));
T266 = params(5)*T262/T265;
T273 = 1+y(21)-params(3)-T226*(T227-(y(54)/y(6))^2);
T318 = y(10)^2;
T326 = T38/y(13);
T333 = y(10)*(-y(16))/T318/y(16);
T342 = (-1)/params(4);
T344 = params(25)*y(10)^T342;
T345 = 1/(params(4)-1);
T346 = T32^T345;
T359 = y(13)^2;
T360 = y(16)*(-y(13))/y(16)/T359;
T364 = y(10)/y(13)/y(10);
T369 = y(10)*(-y(13))/y(10)/T359;
T373 = params(26)*(params(21)*y(13))^T342;
T383 = y(16)^2;
T384 = y(10)*(-y(16))/y(10)/T383;
T389 = y(16)*(-y(13))/T383/y(13);
T397 = params(27)*(params(23)*y(16))^T342;
T411 = y(11)^2;
T412 = y(14)*(-y(11))/y(14)/T411;
T417 = y(17)/y(11)/y(17);
T425 = y(11)*(-y(17))/T411/y(17);
T429 = params(28)*(params(19)*y(11))^T342;
T430 = T85^T345;
T435 = y(14)^2;
T438 = y(14)*(-y(17))/T435/y(17);
T443 = T99/y(17);
T448 = y(14)*(-y(11))/T435/y(11);
T456 = params(29)*y(14)^T342;
T462 = y(17)^2;
T463 = y(11)*(-y(17))/y(11)/T462;
T471 = y(14)/y(17)/y(14);
T476 = y(14)*(-y(17))/y(14)/T462;
T480 = params(30)*(params(24)*y(17))^T342;
T494 = y(12)^2;
T495 = y(15)*(-y(12))/y(15)/T494;
T506 = y(18)*(-y(12))/y(18)/T494;
T510 = params(31)*(params(20)*y(12))^T342;
T511 = T137^T345;
T525 = y(15)^2;
T526 = y(18)*(-y(15))/y(18)/T525;
T531 = y(15)*(-y(12))/T525/y(12);
T539 = params(32)*(params(22)*y(15))^T342;
T546 = y(18)^2;
T547 = y(12)*(-y(18))/y(12)/T546;
T550 = T160/y(12);
T555 = y(18)*(-y(15))/T546/y(15);
T563 = params(33)*y(18)^T342;
T572 = y(4)^(params(1)-1);
T573 = y(49)*y(37)*params(1)*T572;
T575 = y(7)^(1-params(1));
T579 = y(4)^params(1);
T582 = y(7)^(-params(1));
T589 = y(5)^(params(1)-1);
T590 = params(1)*y(50)*y(41)*T589;
T591 = y(8)^(1-params(1));
T595 = y(5)^params(1);
T597 = y(8)^(-params(1));
T604 = y(6)^(params(1)-1);
T605 = params(1)*y(51)*y(45)*T604;
T606 = y(9)^(1-params(1));
T610 = y(6)^params(1);
T612 = y(9)^(-params(1));
residual(1) = (-y(1))-y(52)+T32^T33-params(37)/2*T41^2-params(38)/2*T50^2-params(39)/2*T59^2;
residual(2) = (-y(2))-y(53)+T85^T33-params(40)/2*T93^2-params(41)/2*T102^2-params(42)/2*T111^2;
residual(3) = (-y(3))-y(54)+T137^T33-params(43)/2*T145^2-params(44)/2*T154^2-params(45)/2*T163^2;
residual(4) = y(52)+(-y(4))+y(4)*(1-params(3))-y(4)*params(47)*T179;
residual(5) = y(53)+(-y(5))+(1-params(3))*y(5)-params(47)*y(5)*T191;
residual(6) = y(54)+(-y(6))+(1-params(3))*y(6)-params(47)*y(6)*T203;
residual(7) = T222*T231-T218/T221;
residual(8) = T245*T252-T241/T244;
residual(9) = T266*T273-T262/T265;
residual(10) = y(22)-params(46)*y(7)^params(6);
residual(11) = y(23)-params(46)*y(8)^params(6);
residual(12) = y(24)-params(46)*y(9)^params(6);
lhs =y(25);
rhs =T241/T218*params(35);
residual(13)= lhs-rhs;
lhs =y(26);
rhs =T262/T218*params(36);
residual(14)= lhs-rhs;
lhs =y(27);
rhs =y(26)/y(25);
residual(15)= lhs-rhs;
lhs =y(46);
rhs =params(5)*T218/T218;
residual(16)= lhs-rhs;
lhs =y(47);
rhs =params(5)*T241/T241;
residual(17)= lhs-rhs;
lhs =y(48);
rhs =params(5)*T262/T262;
residual(18)= lhs-rhs;
lhs =y(28)+y(10)*params(37)*T41*(-y(13))/T318/y(13)+T41*params(37)*y(46)*T326+params(39)*T59*T333+y(16)*T59*params(39)*y(46)/y(10)/y(16);
rhs =T344*T346;
residual(19)= lhs-rhs;
lhs =y(31)+y(16)*params(38)*T50/y(16)/y(13)+T50*params(38)*y(46)*T360+params(37)*T41*T364+T41*params(37)*y(46)*T369;
rhs =T346*T373;
residual(20)= lhs-rhs;
lhs =y(34)+y(10)*params(39)*T59/y(10)/y(16)+T59*params(39)*y(46)*T384+params(38)*T50*T389+y(13)*T50*params(38)*y(46)/y(16)/y(13);
rhs =T346*T397;
residual(21)= lhs-rhs;
lhs =y(29)+y(14)*params(40)*T93/y(14)/y(11)+T93*params(40)*y(47)*T412+params(42)*T111*T417+T111*params(42)*y(47)*T425;
rhs =T429*T430;
residual(22)= lhs-rhs;
lhs =y(32)+params(41)*T102*T438+T102*params(41)*y(47)*T443+params(40)*T93*T448+y(11)*T93*params(40)*y(47)/y(14)/y(11);
rhs =T430*T456;
residual(23)= lhs-rhs;
lhs =y(35)+params(42)*T111*T463+y(17)*y(11)*T111*params(42)*y(47)/y(17)+params(41)*T102*T471+T102*params(41)*y(47)*T476;
rhs =T430*T480;
residual(24)= lhs-rhs;
lhs =y(30)+y(15)*params(43)*T145/y(15)/y(12)+T145*params(43)*y(47)*T495+params(45)*T163*T160/y(18)+T163*params(45)*y(47)*T506;
rhs =T510*T511;
residual(25)= lhs-rhs;
lhs =y(33)+y(18)*params(44)*T154/y(18)/y(15)+T154*params(44)*y(47)*T526+params(43)*T145*T531+y(12)*T145*params(43)*y(47)/y(15)/y(12);
rhs =T511*T539;
residual(26)= lhs-rhs;
lhs =y(36)+params(45)*T163*T547+T163*params(45)*y(47)*T550+params(44)*T154*T555+y(15)*T154*params(44)*y(47)/y(18)/y(15);
rhs =T511*T563;
residual(27)= lhs-rhs;
lhs =y(19);
rhs =T573*T575;
residual(28)= lhs-rhs;
lhs =y(22);
rhs =y(49)*y(37)*(1-params(1))*T579*T582;
residual(29)= lhs-rhs;
lhs =y(20);
rhs =T590*T591;
residual(30)= lhs-rhs;
lhs =y(23);
rhs =(1-params(1))*y(50)*y(41)*T595*T597;
residual(31)= lhs-rhs;
lhs =y(21);
rhs =T605*T606;
residual(32)= lhs-rhs;
lhs =y(24);
rhs =(1-params(1))*y(51)*y(45)*T610*T612;
residual(33)= lhs-rhs;
lhs =y(37);
rhs =y(28);
residual(34)= lhs-rhs;
lhs =y(29);
rhs =(1+params(13))*y(38)/params(19);
residual(35)= lhs-rhs;
lhs =y(30);
rhs =(1+params(14))*y(39)/params(20);
residual(36)= lhs-rhs;
lhs =y(31);
rhs =(1+params(15))*y(40)/params(21);
residual(37)= lhs-rhs;
lhs =y(41);
rhs =y(32);
residual(38)= lhs-rhs;
lhs =y(33);
rhs =(1+params(16))*y(42)/params(22);
residual(39)= lhs-rhs;
lhs =y(34);
rhs =(1+params(17))*y(43)/params(23);
residual(40)= lhs-rhs;
lhs =y(35);
rhs =(1+params(16))*y(44)/params(22);
residual(41)= lhs-rhs;
lhs =y(45);
rhs =y(36);
residual(42)= lhs-rhs;
lhs =y(37);
rhs =y(25)*y(38);
residual(43)= lhs-rhs;
lhs =y(40);
rhs =y(25)*y(41);
residual(44)= lhs-rhs;
lhs =y(43);
rhs =y(25)*y(44);
residual(45)= lhs-rhs;
lhs =y(37);
rhs =y(26)*y(39);
residual(46)= lhs-rhs;
lhs =y(40);
rhs =y(26)*y(42);
residual(47)= lhs-rhs;
lhs =y(43);
rhs =y(26)*y(45);
residual(48)= lhs-rhs;
lhs =y(10)*params(7)+y(11)*params(8)+y(12)*params(9);
rhs =y(49)*params(7)*T575*T579;
residual(49)= lhs-rhs;
lhs =y(13)*params(7)+y(14)*params(8)+y(15)*params(9);
rhs =y(50)*params(8)*T591*T595;
residual(50)= lhs-rhs;
lhs =y(16)*params(7)+y(17)*params(8)+y(18)*params(9);
rhs =y(51)*params(9)*T606*T610;
residual(51)= lhs-rhs;
lhs =log(y(49));
rhs =log(y(49))*params(10)+x(1);
residual(52)= lhs-rhs;
lhs =log(y(50));
rhs =log(y(50))*params(11)+x(2);
residual(53)= lhs-rhs;
lhs =log(y(51));
rhs =log(y(51))*params(12)+x(3);
residual(54)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(54, 54);

  %
  % Jacobian matrix
  %

T712 = getPowerDeriv(T215,(-params(2)),1);
T734 = getPowerDeriv(T240,(-params(2)),1);
T749 = getPowerDeriv(T261,(-params(2)),1);
T796 = getPowerDeriv(y(4),params(1),1);
T834 = getPowerDeriv(y(5),params(1),1);
T872 = getPowerDeriv(y(6),params(1),1);
T882 = T712*params(46)*getPowerDeriv(y(7),1+params(6),1)/(1+params(6));
T906 = getPowerDeriv(y(7),1-params(1),1);
T918 = T734*params(46)*getPowerDeriv(y(8),1+params(6),1)/(1+params(6));
T935 = getPowerDeriv(y(8),1-params(1),1);
T947 = T749*params(46)*getPowerDeriv(y(9),1+params(6),1)/(1+params(6));
T964 = getPowerDeriv(y(9),1-params(1),1);
T974 = params(25)*getPowerDeriv(y(10),T16,1);
T975 = getPowerDeriv(T32,T33,1);
T981 = (T38+y(10)*(-y(13))/(y(10)*y(10)))/y(13);
T989 = (y(16)/y(10)+y(10)*(-y(16))/(y(10)*y(10)))/y(16);
T1032 = getPowerDeriv(T32,T345,1);
T1073 = params(28)*params(19)*getPowerDeriv(params(19)*y(11),T16,1);
T1074 = getPowerDeriv(T85,T33,1);
T1081 = (y(11)*y(14)*1/y(14)-y(14)*y(11)/y(14))/(y(11)*y(11));
T1090 = (y(11)*y(17)*1/y(17)-y(17)*y(11)/y(17))/(y(11)*y(11));
T1135 = getPowerDeriv(T85,T345,1);
T1174 = params(31)*params(20)*getPowerDeriv(params(20)*y(12),T16,1);
T1175 = getPowerDeriv(T137,T33,1);
T1182 = (y(12)*y(15)*1/y(15)-y(15)*y(12)/y(15))/(y(12)*y(12));
T1191 = (y(12)*y(18)*1/y(18)-y(18)*T160)/(y(12)*y(12));
T1235 = getPowerDeriv(T137,T345,1);
T1276 = params(26)*params(21)*getPowerDeriv(params(21)*y(13),T16,1);
T1283 = (y(13)*y(10)*1/y(10)-y(10)*T38)/(y(13)*y(13));
T1291 = (y(13)*y(16)*1/y(16)-y(16)*y(13)/y(16))/(y(13)*y(13));
T1377 = params(29)*getPowerDeriv(y(14),T16,1);
T1383 = (y(11)/y(14)+y(14)*(-y(11))/(y(14)*y(14)))/y(11);
T1390 = (T99+y(14)*(-y(17))/(y(14)*y(14)))/y(17);
T1472 = params(32)*params(22)*getPowerDeriv(params(22)*y(15),T16,1);
T1478 = (y(12)/y(15)+y(15)*(-y(12))/(y(15)*y(15)))/y(12);
T1484 = (y(15)*y(18)*1/y(18)-y(18)*y(15)/y(18))/(y(15)*y(15));
T1567 = params(27)*params(23)*getPowerDeriv(params(23)*y(16),T16,1);
T1573 = (y(13)/y(16)+y(16)*(-y(13))/(y(16)*y(16)))/y(13);
T1579 = (y(16)*y(10)*1/y(10)-y(10)*y(16)/y(10))/(y(16)*y(16));
T1660 = params(30)*params(24)*getPowerDeriv(params(24)*y(17),T16,1);
T1665 = (y(17)*y(14)*1/y(14)-y(14)*T99)/(y(17)*y(17));
T1672 = (y(11)/y(17)+y(17)*(-y(11))/(y(17)*y(17)))/y(11);
T1755 = params(33)*getPowerDeriv(y(18),T16,1);
T1761 = (y(15)/y(18)+y(18)*(-y(15))/(y(18)*y(18)))/y(15);
T1768 = (T160+y(18)*(-y(12))/(y(18)*y(18)))/y(12);
  g1(1,1)=(-1);
  g1(1,10)=T974*T975-params(37)/2*T981*2*T41-params(39)/2*T989*2*T59;
  g1(1,13)=T975*T1276-params(37)/2*2*T41*T1283-params(38)/2*T1291*2*T50;
  g1(1,16)=T975*T1567-params(38)/2*2*T50*T1573-params(39)/2*2*T59*T1579;
  g1(1,52)=(-1);
  g1(2,2)=(-1);
  g1(2,11)=T1073*T1074-params(40)/2*T1081*2*T93-params(42)/2*T1090*2*T111;
  g1(2,14)=T1074*T1377-params(40)/2*2*T93*T1383-params(41)/2*T1390*2*T102;
  g1(2,17)=T1074*T1660-params(41)/2*2*T102*T1665-params(42)/2*2*T111*T1672;
  g1(2,53)=(-1);
  g1(3,3)=(-1);
  g1(3,12)=T1174*T1175-params(43)/2*T1182*2*T145-params(45)/2*T1191*2*T163;
  g1(3,15)=T1175*T1472-params(43)/2*2*T145*T1478-params(44)/2*T1484*2*T154;
  g1(3,18)=T1175*T1755-params(44)/2*2*T154*T1761-params(45)/2*2*T163*T1768;
  g1(3,54)=(-1);
  g1(4,4)=(-1)+1-params(3)-(params(47)*T179+y(4)*params(47)*(-y(52))/(y(4)*y(4))*2*(y(52)/y(4)-params(3)));
  g1(4,52)=1-y(4)*params(47)*2*(y(52)/y(4)-params(3))*1/y(4);
  g1(5,5)=(-1)+1-params(3)-(params(47)*T191+params(47)*y(5)*(-y(53))/(y(5)*y(5))*2*(y(53)/y(5)-params(3)));
  g1(5,53)=1-params(47)*y(5)*2*(y(53)/y(5)-params(3))*1/y(5);
  g1(6,6)=(-1)+1-params(3)-(params(47)*T203+params(47)*y(6)*(-y(54))/(y(6)*y(6))*2*(y(54)/y(6)-params(3)));
  g1(6,54)=1-params(47)*y(6)*2*(y(54)/y(6)-params(3))*1/y(6);
  g1(7,1)=T231*params(5)*T712/T221-T712/T221;
  g1(7,4)=T231*(-(params(5)*T218*(-(params(47)*(-y(52))/(y(4)*y(4))))))/(T221*T221)+T222*(-(T226*(-((-y(52))/(y(4)*y(4))*2*y(52)/y(4)))))-(-(T218*(-(params(47)*(-y(52))/(y(4)*y(4))))))/(T221*T221);
  g1(7,7)=T231*params(5)*T882/T221-T882/T221;
  g1(7,19)=T222;
  g1(7,52)=T231*(-(params(5)*T218*(-(params(47)*1/y(4)))))/(T221*T221)+T222*(-(T226*(-(2*y(52)/y(4)*1/y(4)))))-(-(T218*(-(params(47)*1/y(4)))))/(T221*T221);
  g1(8,2)=T252*params(5)*T734/T244-T734/T244;
  g1(8,5)=T252*(-(params(5)*T241*(-(params(47)*(-y(53))/(y(5)*y(5))))))/(T244*T244)+T245*(-(T226*(-((-y(53))/(y(5)*y(5))*2*y(53)/y(5)))))-(-(T241*(-(params(47)*(-y(53))/(y(5)*y(5))))))/(T244*T244);
  g1(8,8)=T252*params(5)*T918/T244-T918/T244;
  g1(8,20)=T245;
  g1(8,53)=T252*(-(params(5)*T241*(-(params(47)*1/y(5)))))/(T244*T244)+T245*(-(T226*(-(2*y(53)/y(5)*1/y(5)))))-(-(T241*(-(params(47)*1/y(5)))))/(T244*T244);
  g1(9,3)=T273*params(5)*T749/T265-T749/T265;
  g1(9,6)=T273*(-(params(5)*T262*(-(params(47)*(-y(54))/(y(6)*y(6))))))/(T265*T265)+T266*(-(T226*(-((-y(54))/(y(6)*y(6))*2*y(54)/y(6)))))-(-(T262*(-(params(47)*(-y(54))/(y(6)*y(6))))))/(T265*T265);
  g1(9,9)=T273*params(5)*T947/T265-T947/T265;
  g1(9,21)=T266;
  g1(9,54)=T273*(-(params(5)*T262*(-(params(47)*1/y(6)))))/(T265*T265)+T266*(-(T226*(-(2*y(54)/y(6)*1/y(6)))))-(-(T262*(-(params(47)*1/y(6)))))/(T265*T265);
  g1(10,7)=(-(params(46)*getPowerDeriv(y(7),params(6),1)));
  g1(10,22)=1;
  g1(11,8)=(-(params(46)*getPowerDeriv(y(8),params(6),1)));
  g1(11,23)=1;
  g1(12,9)=(-(params(46)*getPowerDeriv(y(9),params(6),1)));
  g1(12,24)=1;
  g1(13,1)=(-(params(35)*(-(T241*T712))/(T218*T218)));
  g1(13,2)=(-(params(35)*T734/T218));
  g1(13,7)=(-(params(35)*(-(T241*T882))/(T218*T218)));
  g1(13,8)=(-(params(35)*T918/T218));
  g1(13,25)=1;
  g1(14,1)=(-(params(36)*(-(T262*T712))/(T218*T218)));
  g1(14,3)=(-(params(36)*T749/T218));
  g1(14,7)=(-(params(36)*(-(T262*T882))/(T218*T218)));
  g1(14,9)=(-(params(36)*T947/T218));
  g1(14,26)=1;
  g1(15,25)=(-((-y(26))/(y(25)*y(25))));
  g1(15,26)=(-(1/y(25)));
  g1(15,27)=1;
  g1(16,1)=(-((T218*params(5)*T712-params(5)*T218*T712)/(T218*T218)));
  g1(16,7)=(-((T218*params(5)*T882-params(5)*T218*T882)/(T218*T218)));
  g1(16,46)=1;
  g1(17,2)=(-((T241*params(5)*T734-params(5)*T241*T734)/(T241*T241)));
  g1(17,8)=(-((T241*params(5)*T918-params(5)*T241*T918)/(T241*T241)));
  g1(17,47)=1;
  g1(18,3)=(-((T262*params(5)*T749-params(5)*T262*T749)/(T262*T262)));
  g1(18,9)=(-((T262*params(5)*T947-params(5)*T262*T947)/(T262*T262)));
  g1(18,48)=1;
  g1(19,10)=(params(37)*T41*(-y(13))/T318+y(10)*((-y(13))/T318*params(37)*T981+params(37)*T41*(-((-y(13))*2*y(10)))/(T318*T318)))/y(13)+T326*params(37)*y(46)*T981+T41*params(37)*y(46)*(-y(13))/(y(10)*y(10))/y(13)+T333*params(39)*T989+params(39)*T59*((-y(16))/T318+y(10)*(-((-y(16))*2*y(10)))/(T318*T318))/y(16)+(y(10)*y(16)*params(39)*y(46)*T989-y(16)*T59*params(39)*y(46))/(y(10)*y(10))/y(16)-(T346*params(25)*getPowerDeriv(y(10),T342,1)+T344*T974*T1032);
  g1(19,13)=(y(13)*y(10)*((-y(13))/T318*params(37)*T1283+params(37)*T41*(-1)/T318)-y(10)*params(37)*T41*(-y(13))/T318)/(y(13)*y(13))+T326*params(37)*y(46)*T1283+T41*params(37)*y(46)*(y(13)*1/y(10)-T38)/(y(13)*y(13))-T344*T1032*T1276;
  g1(19,16)=T333*params(39)*T1579+params(39)*T59*(y(16)*y(10)*(-1)/T318-y(10)*(-y(16))/T318)/(y(16)*y(16))+(y(16)*(T59*params(39)*y(46)+y(16)*params(39)*y(46)*T1579)/y(10)-y(16)*T59*params(39)*y(46)/y(10))/(y(16)*y(16))-T344*T1032*T1567;
  g1(19,28)=1;
  g1(19,46)=params(37)*T41*T326+y(16)*params(39)*T59/y(10)/y(16);
  g1(20,10)=T364*params(37)*T981+params(37)*T41*(y(10)*1/y(13)-y(10)/y(13))/(y(10)*y(10))+T369*params(37)*y(46)*T981+T41*params(37)*y(46)*((-y(13))/y(10)+y(10)*y(13)/(y(10)*y(10)))/T359-T373*T974*T1032;
  g1(20,13)=(y(13)*y(16)*params(38)*T1291/y(16)-y(16)*params(38)*T50/y(16))/(y(13)*y(13))+T360*params(38)*y(46)*T1291+T50*params(38)*y(46)*(T359*y(16)*(-1)/y(16)-y(16)*(-y(13))/y(16)*2*y(13))/(T359*T359)+T364*params(37)*T1283+params(37)*T41*(-y(10))/(y(13)*y(13))/y(10)+T369*params(37)*y(46)*T1283+T41*params(37)*y(46)*(T359*y(10)*(-1)/y(10)-y(10)*(-y(13))/y(10)*2*y(13))/(T359*T359)-(T373*T1032*T1276+T346*params(26)*params(21)*getPowerDeriv(params(21)*y(13),T342,1));
  g1(20,16)=(y(16)*(params(38)*T50+y(16)*params(38)*T1573)-y(16)*params(38)*T50)/(y(16)*y(16))/y(13)+T360*params(38)*y(46)*T1573+T50*params(38)*y(46)*((-y(13))/y(16)+y(16)*y(13)/(y(16)*y(16)))/T359-T373*T1032*T1567;
  g1(20,31)=1;
  g1(20,46)=params(38)*T50*T360+params(37)*T41*T369;
  g1(21,10)=(y(10)*(params(39)*T59+y(10)*params(39)*T989)-y(10)*params(39)*T59)/(y(10)*y(10))/y(16)+T384*params(39)*y(46)*T989+T59*params(39)*y(46)*((-y(16))/y(10)+y(10)*y(16)/(y(10)*y(10)))/T383-T397*T974*T1032;
  g1(21,13)=T389*params(38)*T1291+params(38)*T50*(y(13)*y(16)*(-1)/T383-y(16)*(-y(13))/T383)/(y(13)*y(13))+(y(13)*(T50*params(38)*y(46)+y(13)*params(38)*y(46)*T1291)/y(16)-y(13)*T50*params(38)*y(46)/y(16))/(y(13)*y(13))-T397*T1032*T1276;
  g1(21,16)=(y(16)*y(10)*params(39)*T1579/y(10)-y(10)*params(39)*T59/y(10))/(y(16)*y(16))+T384*params(39)*y(46)*T1579+T59*params(39)*y(46)*(T383*y(10)*(-1)/y(10)-y(10)*(-y(16))/y(10)*2*y(16))/(T383*T383)+T389*params(38)*T1573+params(38)*T50*((-y(13))/T383+y(16)*(-((-y(13))*2*y(16)))/(T383*T383))/y(13)+(y(16)*y(13)*params(38)*y(46)*T1573-y(13)*T50*params(38)*y(46))/(y(16)*y(16))/y(13)-(T397*T1032*T1567+T346*params(27)*params(23)*getPowerDeriv(params(23)*y(16),T342,1));
  g1(21,34)=1;
  g1(21,46)=params(39)*T59*T384+y(13)*params(38)*T50/y(16)/y(13);
  g1(22,11)=(y(11)*y(14)*params(40)*T1081/y(14)-y(14)*params(40)*T93/y(14))/(y(11)*y(11))+T412*params(40)*y(47)*T1081+T93*params(40)*y(47)*(T411*y(14)*(-1)/y(14)-y(14)*(-y(11))/y(14)*2*y(11))/(T411*T411)+T417*params(42)*T1090+params(42)*T111*(-y(17))/(y(11)*y(11))/y(17)+T425*params(42)*y(47)*T1090+T111*params(42)*y(47)*((-y(17))/T411+y(11)*(-((-y(17))*2*y(11)))/(T411*T411))/y(17)-(T430*params(28)*params(19)*getPowerDeriv(params(19)*y(11),T342,1)+T429*T1073*T1135);
  g1(22,14)=(y(14)*(params(40)*T93+y(14)*params(40)*T1383)-y(14)*params(40)*T93)/(y(14)*y(14))/y(11)+T412*params(40)*y(47)*T1383+T93*params(40)*y(47)*((-y(11))/y(14)+y(14)*y(11)/(y(14)*y(14)))/T411-T429*T1135*T1377;
  g1(22,17)=T417*params(42)*T1672+params(42)*T111*(y(17)*1/y(11)-y(17)/y(11))/(y(17)*y(17))+T425*params(42)*y(47)*T1672+T111*params(42)*y(47)*(y(17)*y(11)*(-1)/T411-y(11)*(-y(17))/T411)/(y(17)*y(17))-T429*T1135*T1660;
  g1(22,29)=1;
  g1(22,47)=params(40)*T93*T412+params(42)*T111*T425;
  g1(23,11)=T448*params(40)*T1081+params(40)*T93*(y(11)*y(14)*(-1)/T435-y(14)*(-y(11))/T435)/(y(11)*y(11))+(y(11)*(T93*params(40)*y(47)+y(11)*params(40)*y(47)*T1081)/y(14)-y(11)*T93*params(40)*y(47)/y(14))/(y(11)*y(11))-T456*T1073*T1135;
  g1(23,14)=T438*params(41)*T1390+params(41)*T102*((-y(17))/T435+y(14)*(-((-y(17))*2*y(14)))/(T435*T435))/y(17)+T443*params(41)*y(47)*T1390+T102*params(41)*y(47)*(-y(17))/(y(14)*y(14))/y(17)+T448*params(40)*T1383+params(40)*T93*((-y(11))/T435+y(14)*(-((-y(11))*2*y(14)))/(T435*T435))/y(11)+(y(14)*y(11)*params(40)*y(47)*T1383-y(11)*T93*params(40)*y(47))/(y(14)*y(14))/y(11)-(T456*T1135*T1377+T430*params(29)*getPowerDeriv(y(14),T342,1));
  g1(23,17)=T438*params(41)*T1665+params(41)*T102*(y(17)*y(14)*(-1)/T435-y(14)*(-y(17))/T435)/(y(17)*y(17))+T443*params(41)*y(47)*T1665+T102*params(41)*y(47)*(y(17)*1/y(14)-T99)/(y(17)*y(17))-T456*T1135*T1660;
  g1(23,32)=1;
  g1(23,47)=params(41)*T102*T443+y(11)*params(40)*T93/y(14)/y(11);
  g1(24,11)=T463*params(42)*T1090+params(42)*T111*((-y(17))/y(11)+y(11)*y(17)/(y(11)*y(11)))/T462+y(17)*(T111*params(42)*y(47)+y(11)*params(42)*y(47)*T1090)/y(17)-T480*T1073*T1135;
  g1(24,14)=T471*params(41)*T1390+params(41)*T102*(y(14)*1/y(17)-y(14)/y(17))/(y(14)*y(14))+T476*params(41)*y(47)*T1390+T102*params(41)*y(47)*((-y(17))/y(14)+y(14)*y(17)/(y(14)*y(14)))/T462-T480*T1135*T1377;
  g1(24,17)=T463*params(42)*T1672+params(42)*T111*(T462*y(11)*(-1)/y(11)-y(11)*(-y(17))/y(11)*2*y(17))/(T462*T462)+y(11)*T111*params(42)*y(47)/y(17)+y(17)*(y(17)*y(11)*params(42)*y(47)*T1672-y(11)*T111*params(42)*y(47))/(y(17)*y(17))+T471*params(41)*T1665+params(41)*T102*(-y(14))/(y(17)*y(17))/y(14)+T476*params(41)*y(47)*T1665+T102*params(41)*y(47)*(T462*y(14)*(-1)/y(14)-y(14)*(-y(17))/y(14)*2*y(17))/(T462*T462)-(T480*T1135*T1660+T430*params(30)*params(24)*getPowerDeriv(params(24)*y(17),T342,1));
  g1(24,35)=1;
  g1(24,47)=y(17)*y(11)*params(42)*T111/y(17)+params(41)*T102*T476;
  g1(25,12)=(y(12)*y(15)*params(43)*T1182/y(15)-y(15)*params(43)*T145/y(15))/(y(12)*y(12))+T495*params(43)*y(47)*T1182+T145*params(43)*y(47)*(T494*y(15)*(-1)/y(15)-y(15)*(-y(12))/y(15)*2*y(12))/(T494*T494)+T160/y(18)*params(45)*T1191+params(45)*T163*1/y(18)/y(18)+T506*params(45)*y(47)*T1191+T163*params(45)*y(47)*(T494*y(18)*(-1)/y(18)-y(18)*(-y(12))/y(18)*2*y(12))/(T494*T494)-(T511*params(31)*params(20)*getPowerDeriv(params(20)*y(12),T342,1)+T510*T1174*T1235);
  g1(25,15)=(y(15)*(params(43)*T145+y(15)*params(43)*T1478)-y(15)*params(43)*T145)/(y(15)*y(15))/y(12)+T495*params(43)*y(47)*T1478+T145*params(43)*y(47)*((-y(12))/y(15)+y(15)*y(12)/(y(15)*y(15)))/T494-T510*T1235*T1472;
  g1(25,18)=T160/y(18)*params(45)*T1768+params(45)*T163*(y(18)*(-y(12))/(y(18)*y(18))-T160)/(y(18)*y(18))+T506*params(45)*y(47)*T1768+T163*params(45)*y(47)*((-y(12))/y(18)+y(18)*y(12)/(y(18)*y(18)))/T494-T510*T1235*T1755;
  g1(25,30)=1;
  g1(25,47)=params(43)*T145*T495+params(45)*T163*T506;
  g1(26,12)=T531*params(43)*T1182+params(43)*T145*(y(12)*y(15)*(-1)/T525-y(15)*(-y(12))/T525)/(y(12)*y(12))+(y(12)*(T145*params(43)*y(47)+y(12)*params(43)*y(47)*T1182)/y(15)-y(12)*T145*params(43)*y(47)/y(15))/(y(12)*y(12))-T539*T1174*T1235;
  g1(26,15)=(y(15)*y(18)*params(44)*T1484/y(18)-y(18)*params(44)*T154/y(18))/(y(15)*y(15))+T526*params(44)*y(47)*T1484+T154*params(44)*y(47)*(T525*y(18)*(-1)/y(18)-y(18)*(-y(15))/y(18)*2*y(15))/(T525*T525)+T531*params(43)*T1478+params(43)*T145*((-y(12))/T525+y(15)*(-((-y(12))*2*y(15)))/(T525*T525))/y(12)+(y(15)*y(12)*params(43)*y(47)*T1478-y(12)*T145*params(43)*y(47))/(y(15)*y(15))/y(12)-(T539*T1235*T1472+T511*params(32)*params(22)*getPowerDeriv(params(22)*y(15),T342,1));
  g1(26,18)=(y(18)*(params(44)*T154+y(18)*params(44)*T1761)-y(18)*params(44)*T154)/(y(18)*y(18))/y(15)+T526*params(44)*y(47)*T1761+T154*params(44)*y(47)*((-y(15))/y(18)+y(18)*y(15)/(y(18)*y(18)))/T525-T539*T1235*T1755;
  g1(26,33)=1;
  g1(26,47)=params(44)*T154*T526+y(12)*params(43)*T145/y(15)/y(12);
  g1(27,12)=T547*params(45)*T1191+params(45)*T163*((-y(18))/y(12)+y(12)*y(18)/(y(12)*y(12)))/T546+T550*params(45)*y(47)*T1191+T163*params(45)*y(47)*(y(12)*1/y(18)-T160)/(y(12)*y(12))-T563*T1174*T1235;
  g1(27,15)=T555*params(44)*T1484+params(44)*T154*(y(15)*y(18)*(-1)/T546-y(18)*(-y(15))/T546)/(y(15)*y(15))+(y(15)*(T154*params(44)*y(47)+y(15)*params(44)*y(47)*T1484)/y(18)-y(15)*T154*params(44)*y(47)/y(18))/(y(15)*y(15))-T563*T1235*T1472;
  g1(27,18)=T547*params(45)*T1768+params(45)*T163*(T546*y(12)*(-1)/y(12)-y(12)*(-y(18))/y(12)*2*y(18))/(T546*T546)+T550*params(45)*y(47)*T1768+T163*params(45)*y(47)*(-y(12))/(y(18)*y(18))/y(12)+T555*params(44)*T1761+params(44)*T154*((-y(15))/T546+y(18)*(-((-y(15))*2*y(18)))/(T546*T546))/y(15)+(y(18)*y(15)*params(44)*y(47)*T1761-y(15)*T154*params(44)*y(47))/(y(18)*y(18))/y(15)-(T563*T1235*T1755+T511*params(33)*getPowerDeriv(y(18),T342,1));
  g1(27,36)=1;
  g1(27,47)=params(45)*T163*T550+y(15)*params(44)*T154/y(18)/y(15);
  g1(28,4)=(-(T575*y(49)*y(37)*params(1)*getPowerDeriv(y(4),params(1)-1,1)));
  g1(28,7)=(-(T573*T906));
  g1(28,19)=1;
  g1(28,37)=(-(T575*T572*y(49)*params(1)));
  g1(28,49)=(-(T575*T572*y(37)*params(1)));
  g1(29,4)=(-(T582*y(49)*y(37)*(1-params(1))*T796));
  g1(29,7)=(-(y(49)*y(37)*(1-params(1))*T579*getPowerDeriv(y(7),(-params(1)),1)));
  g1(29,22)=1;
  g1(29,37)=(-(T582*T579*y(49)*(1-params(1))));
  g1(29,49)=(-(T582*T579*y(37)*(1-params(1))));
  g1(30,5)=(-(T591*params(1)*y(50)*y(41)*getPowerDeriv(y(5),params(1)-1,1)));
  g1(30,8)=(-(T590*T935));
  g1(30,20)=1;
  g1(30,41)=(-(T591*T589*params(1)*y(50)));
  g1(30,50)=(-(T591*T589*params(1)*y(41)));
  g1(31,5)=(-(T597*(1-params(1))*y(50)*y(41)*T834));
  g1(31,8)=(-((1-params(1))*y(50)*y(41)*T595*getPowerDeriv(y(8),(-params(1)),1)));
  g1(31,23)=1;
  g1(31,41)=(-(T597*T595*(1-params(1))*y(50)));
  g1(31,50)=(-(T597*T595*(1-params(1))*y(41)));
  g1(32,6)=(-(T606*params(1)*y(51)*y(45)*getPowerDeriv(y(6),params(1)-1,1)));
  g1(32,9)=(-(T605*T964));
  g1(32,21)=1;
  g1(32,45)=(-(T606*T604*params(1)*y(51)));
  g1(32,51)=(-(T606*T604*params(1)*y(45)));
  g1(33,6)=(-(T612*(1-params(1))*y(51)*y(45)*T872));
  g1(33,9)=(-((1-params(1))*y(51)*y(45)*T610*getPowerDeriv(y(9),(-params(1)),1)));
  g1(33,24)=1;
  g1(33,45)=(-(T612*T610*(1-params(1))*y(51)));
  g1(33,51)=(-(T612*T610*(1-params(1))*y(45)));
  g1(34,28)=(-1);
  g1(34,37)=1;
  g1(35,29)=1;
  g1(35,38)=(-((1+params(13))/params(19)));
  g1(36,30)=1;
  g1(36,39)=(-((1+params(14))/params(20)));
  g1(37,31)=1;
  g1(37,40)=(-((1+params(15))/params(21)));
  g1(38,32)=(-1);
  g1(38,41)=1;
  g1(39,33)=1;
  g1(39,42)=(-((1+params(16))/params(22)));
  g1(40,34)=1;
  g1(40,43)=(-((1+params(17))/params(23)));
  g1(41,35)=1;
  g1(41,44)=(-((1+params(16))/params(22)));
  g1(42,36)=(-1);
  g1(42,45)=1;
  g1(43,25)=(-y(38));
  g1(43,37)=1;
  g1(43,38)=(-y(25));
  g1(44,25)=(-y(41));
  g1(44,40)=1;
  g1(44,41)=(-y(25));
  g1(45,25)=(-y(44));
  g1(45,43)=1;
  g1(45,44)=(-y(25));
  g1(46,26)=(-y(39));
  g1(46,37)=1;
  g1(46,39)=(-y(26));
  g1(47,26)=(-y(42));
  g1(47,40)=1;
  g1(47,42)=(-y(26));
  g1(48,26)=(-y(45));
  g1(48,43)=1;
  g1(48,45)=(-y(26));
  g1(49,4)=(-(y(49)*params(7)*T575*T796));
  g1(49,7)=(-(y(49)*params(7)*T579*T906));
  g1(49,10)=params(7);
  g1(49,11)=params(8);
  g1(49,12)=params(9);
  g1(49,49)=(-(params(7)*T575*T579));
  g1(50,5)=(-(y(50)*params(8)*T591*T834));
  g1(50,8)=(-(y(50)*params(8)*T595*T935));
  g1(50,13)=params(7);
  g1(50,14)=params(8);
  g1(50,15)=params(9);
  g1(50,50)=(-(params(8)*T591*T595));
  g1(51,6)=(-(y(51)*params(9)*T606*T872));
  g1(51,9)=(-(y(51)*params(9)*T610*T964));
  g1(51,16)=params(7);
  g1(51,17)=params(8);
  g1(51,18)=params(9);
  g1(51,51)=(-(params(9)*T606*T610));
  g1(52,49)=1/y(49)-params(10)*1/y(49);
  g1(53,50)=1/y(50)-params(11)*1/y(50);
  g1(54,51)=1/y(51)-params(12)*1/y(51);
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],54,2916);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],54,157464);
end
end
end
end
