function [residual, g1, g2, g3] = BKK3C_fg2_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(63, 1);
T16 = (params(4)-1)/params(4);
T32 = params(25)*y(25)^T16+params(26)*(params(21)*y(28))^T16+params(27)*(params(23)*y(31))^T16;
T33 = params(4)/(params(4)-1);
T37 = params(37)/2;
T43 = y(28)/y(25)*y(4)/y(7)-1;
T48 = params(38)/2;
T53 = y(28)/y(31)*y(10)/y(7)-1;
T58 = params(39)/2;
T62 = y(4)*y(31)/y(25)/y(10)-1;
T88 = params(28)*(params(19)*y(26))^T16+params(29)*y(29)^T16+params(30)*(params(24)*y(32))^T16;
T92 = params(40)/2;
T98 = y(26)/y(29)*y(8)/y(5)-1;
T103 = params(41)/2;
T108 = y(8)*y(32)/y(29)/y(11)-1;
T113 = params(42)/2;
T117 = y(11)*y(26)/y(32)/y(5)-1;
T143 = params(31)*(params(20)*y(27))^T16+params(32)*(params(22)*y(30))^T16+params(33)*y(33)^T16;
T147 = params(43)/2;
T153 = y(27)/y(30)*y(9)/y(6)-1;
T158 = params(44)/2;
T163 = y(30)/y(33)*y(12)/y(9)-1;
T168 = params(45)/2;
T172 = y(12)*y(27)/y(33)/y(6)-1;
T189 = (y(67)/y(1)-params(3))^2;
T202 = (y(68)/y(2)-params(3))^2;
T215 = (y(69)/y(3)-params(3))^2;
T224 = y(79)^params(6);
T229 = (params(34)-y(82))^(1-params(6));
T230 = T224*T229;
T233 = T230^(1-params(2));
T239 = 1-params(46)*(y(97)/y(19)-params(3));
T240 = params(5)*params(6)/y(79)*T233/T239;
T244 = params(46)/2;
T245 = params(3)^2;
T249 = 1+y(94)-params(3)-T244*(T245-(y(97)/y(19))^2);
T252 = y(16)^params(6);
T255 = (params(34)-y(22))^(1-params(6));
T256 = T252*T255;
T257 = T256^(1-params(2));
T260 = 1-params(46)*(y(67)/y(1)-params(3));
T266 = y(80)^params(6);
T269 = (params(34)-y(83))^(1-params(6));
T270 = T266*T269;
T271 = T270^(1-params(2));
T277 = 1-params(46)*(y(98)/y(20)-params(3));
T278 = params(5)*params(6)/y(80)*T271/T277;
T285 = 1+y(95)-params(3)-T244*(T245-(y(98)/y(20))^2);
T288 = y(17)^params(6);
T291 = (params(34)-y(23))^(1-params(6));
T292 = T288*T291;
T293 = T292^(1-params(2));
T296 = 1-params(46)*(y(68)/y(2)-params(3));
T302 = y(81)^params(6);
T305 = (params(34)-y(84))^(1-params(6));
T306 = T302*T305;
T307 = T306^(1-params(2));
T313 = 1-params(46)*(y(99)/y(21)-params(3));
T314 = params(5)*params(6)/y(81)*T307/T313;
T321 = 1+y(96)-params(3)-T244*(T245-(y(99)/y(21))^2);
T324 = y(18)^params(6);
T327 = (params(34)-y(24))^(1-params(6));
T328 = T324*T327;
T329 = T328^(1-params(2));
T332 = 1-params(46)*(y(69)/y(3)-params(3));
T356 = T293*1/y(17);
T358 = T257*1/y(16);
T365 = T329*1/y(18);
T394 = y(25)^2;
T395 = (-y(28))/T394;
T406 = y(25)*y(88)/y(85)/y(28)-1;
T407 = params(37)*y(61)*T406;
T408 = y(88)/y(85)/y(28);
T415 = y(4)*(-y(31))/T394/y(10);
T423 = y(25)*y(91)/y(85)/y(31)-1;
T424 = params(39)*y(61)*T423;
T429 = (-1)/params(4);
T431 = params(25)*y(25)^T429;
T432 = 1/(params(4)-1);
T433 = T32^T432;
T446 = y(31)*y(88)/y(91)/y(28)-1;
T447 = params(38)*y(61)*T446;
T451 = y(28)^2;
T452 = y(31)*(-y(88))/y(91)/T451;
T456 = y(4)/y(7)/y(25);
T461 = y(25)*(-y(88))/y(85)/T451;
T465 = params(26)*(params(21)*y(28))^T429;
T476 = y(31)^2;
T477 = y(25)*(-y(91))/y(85)/T476;
T482 = y(10)*(-y(28))/T476/y(7);
T490 = params(27)*(params(23)*y(31))^T429;
T505 = y(29)*y(86)/y(89)/y(26)-1;
T506 = params(40)*y(62)*T505;
T510 = y(26)^2;
T511 = y(29)*(-y(86))/y(89)/T510;
T516 = y(11)/y(5)/y(32);
T524 = y(32)*y(86)/y(92)/y(26)-1;
T525 = params(42)*y(62)*T524;
T529 = y(86)*(-y(32))/T510/y(92);
T533 = params(28)*(params(19)*y(26))^T429;
T534 = T88^T432;
T539 = y(29)^2;
T542 = y(8)*(-y(32))/T539/y(11);
T549 = y(29)*y(92)/y(89)/y(32)-1;
T550 = params(41)*y(62)*T549;
T551 = y(92)/y(89)/y(32);
T557 = y(8)*(-y(26))/T539/y(5);
T565 = params(29)*y(29)^T429;
T572 = y(32)^2;
T573 = y(26)*(-y(11))/y(5)/T572;
T581 = y(8)/y(11)/y(29);
T587 = y(29)*(-y(92))/y(89)/T572;
T591 = params(30)*(params(24)*y(32))^T429;
T606 = y(30)*y(87)/y(90)/y(27)-1;
T607 = params(43)*y(62)*T606;
T611 = y(27)^2;
T612 = y(30)*(-y(87))/y(90)/T611;
T617 = y(6)/y(12)/y(33);
T625 = y(33)*y(87)/y(93)/y(27)-1;
T626 = params(45)*y(62)*T625;
T629 = y(33)*(-y(87))/y(93)/T611;
T633 = params(31)*(params(20)*y(27))^T429;
T634 = T143^T432;
T647 = y(33)*y(90)/y(93)/y(30)-1;
T648 = params(44)*y(62)*T647;
T652 = y(30)^2;
T653 = y(33)*(-y(90))/y(93)/T652;
T659 = y(9)*(-y(27))/T652/y(6);
T667 = params(32)*(params(22)*y(30))^T429;
T674 = y(33)^2;
T675 = y(27)*(-y(12))/y(6)/T674;
T678 = y(87)/y(93)/y(27);
T684 = y(12)*(-y(30))/T674/y(9);
T692 = params(33)*y(33)^T429;
T702 = y(19)^(params(1)-1);
T703 = y(64)*y(52)*params(1)*T702;
T705 = y(22)^(1-params(1));
T709 = y(19)^params(1);
T712 = y(22)^(-params(1));
T720 = y(20)^(params(1)-1);
T721 = params(1)*y(65)*y(56)*T720;
T722 = y(23)^(1-params(1));
T726 = y(20)^params(1);
T728 = y(23)^(-params(1));
T736 = y(21)^(params(1)-1);
T737 = params(1)*y(66)*y(60)*T736;
T738 = y(24)^(1-params(1));
T742 = y(21)^params(1);
T744 = y(24)^(-params(1));
T867 = params(9)*y(41)*(-0.5)*(y(27)*params(49)+y(30)*params(52)+y(33)*params(55)-T738*T742*y(66)*params(55))/params(7);
residual(1) = (-y(16))-y(67)+T32^T33-T37*T43^2-T48*T53^2-T58*T62^2;
residual(2) = (-y(17))-y(68)+T88^T33-T92*T98^2-T103*T108^2-T113*T117^2;
residual(3) = (-y(18))-y(69)+T143^T33-T147*T153^2-T158*T163^2-T168*T172^2;
residual(4) = y(67)+(-y(19))+(1-params(3))*y(1)-y(1)*params(46)*T189;
residual(5) = y(68)+(-y(20))+(1-params(3))*y(2)-params(46)*y(2)*T202;
residual(6) = y(69)+(-y(21))+(1-params(3))*y(3)-params(46)*y(3)*T215;
residual(7) = T240*T249-params(6)/y(16)*T257/T260;
residual(8) = T278*T285-params(6)/y(17)*T293/T296;
residual(9) = T314*T321-params(6)/y(18)*T329/T332;
residual(10) = y(16)*(1-params(6))-params(6)*(params(34)-y(22))*y(37);
residual(11) = y(17)*(1-params(6))-params(6)*(params(34)-y(23))*y(38);
residual(12) = y(18)*(1-params(6))-params(6)*(params(34)-y(24))*y(39);
lhs =y(40);
rhs =T356/T358*params(35);
residual(13)= lhs-rhs;
lhs =y(41);
rhs =T365/T358*params(36);
residual(14)= lhs-rhs;
lhs =y(42);
rhs =y(41)/y(40);
residual(15)= lhs-rhs;
lhs =y(61);
rhs =params(5)*T233*1/y(79)/T358;
residual(16)= lhs-rhs;
lhs =y(62);
rhs =params(5)*T271*1/y(80)/T356;
residual(17)= lhs-rhs;
lhs =y(63);
rhs =params(5)*T307*1/y(81)/T365;
residual(18)= lhs-rhs;
lhs =y(43)+y(4)*params(37)*T43*T395/y(7)+T407*T408+params(39)*T62*T415+y(91)*T424/y(85)/y(31);
rhs =T431*T433;
residual(19)= lhs-rhs;
lhs =y(46)+y(10)*params(38)*T53/y(31)/y(7)+T447*T452+params(37)*T43*T456+T407*T461;
rhs =T433*T465;
residual(20)= lhs-rhs;
lhs =y(49)+y(4)*params(39)*T62/y(25)/y(10)+T424*T477+params(38)*T53*T482+y(88)*T447/y(91)/y(28);
rhs =T433*T490;
residual(21)= lhs-rhs;
lhs =y(44)+y(8)*params(40)*T98/y(29)/y(5)+T506*T511+params(42)*T117*T516+T525*T529;
rhs =T533*T534;
residual(22)= lhs-rhs;
lhs =y(47)+params(41)*T108*T542+T550*T551+params(40)*T98*T557+y(86)*T506/y(89)/y(26);
rhs =T534*T565;
residual(23)= lhs-rhs;
lhs =y(50)+params(42)*T117*T573+y(32)*y(86)*T525/y(92)+params(41)*T108*T581+T550*T587;
rhs =T534*T591;
residual(24)= lhs-rhs;
lhs =y(45)+y(9)*params(43)*T153/y(30)/y(6)+T607*T612+params(45)*T172*T617+T626*T629;
rhs =T633*T634;
residual(25)= lhs-rhs;
lhs =y(48)+y(12)*params(44)*T163/y(33)/y(9)+T648*T653+params(43)*T153*T659+y(87)*T607/y(90)/y(27);
rhs =T634*T667;
residual(26)= lhs-rhs;
lhs =y(51)+params(45)*T172*T675+T626*T678+params(44)*T163*T684+y(90)*T648/y(93)/y(30);
rhs =T634*T692;
residual(27)= lhs-rhs;
lhs =y(34);
rhs =T703*T705;
residual(28)= lhs-rhs;
lhs =y(37);
rhs =y(64)*y(52)*(1-params(1))*T709*T712;
residual(29)= lhs-rhs;
lhs =y(35);
rhs =T721*T722;
residual(30)= lhs-rhs;
lhs =y(38);
rhs =(1-params(1))*y(65)*y(56)*T726*T728;
residual(31)= lhs-rhs;
lhs =y(36);
rhs =T737*T738;
residual(32)= lhs-rhs;
lhs =y(39);
rhs =(1-params(1))*y(66)*y(60)*T742*T744;
residual(33)= lhs-rhs;
lhs =y(52);
rhs =y(43);
residual(34)= lhs-rhs;
lhs =y(44);
rhs =(1+params(13))*y(53)/params(19);
residual(35)= lhs-rhs;
lhs =y(45);
rhs =(1+params(14))*y(54)/params(20);
residual(36)= lhs-rhs;
lhs =y(46);
rhs =(1+params(15))*y(55)/params(21);
residual(37)= lhs-rhs;
lhs =y(56);
rhs =y(47);
residual(38)= lhs-rhs;
lhs =y(48);
rhs =(1+params(16))*y(57)/params(22);
residual(39)= lhs-rhs;
lhs =y(49);
rhs =(1+params(17))*y(58)/params(23);
residual(40)= lhs-rhs;
lhs =y(50);
rhs =(1+params(16))*y(59)/params(22);
residual(41)= lhs-rhs;
lhs =y(60);
rhs =y(51);
residual(42)= lhs-rhs;
lhs =y(52);
rhs =y(40)*y(53);
residual(43)= lhs-rhs;
lhs =y(55);
rhs =y(40)*y(56);
residual(44)= lhs-rhs;
lhs =y(58);
rhs =y(40)*y(59);
residual(45)= lhs-rhs;
lhs =y(52);
rhs =y(41)*y(54);
residual(46)= lhs-rhs;
lhs =y(55);
rhs =y(41)*y(57);
residual(47)= lhs-rhs;
lhs =y(58);
rhs =y(41)*y(60);
residual(48)= lhs-rhs;
lhs =y(25)*params(7)+y(26)*params(8)+y(27)*params(9);
rhs =y(64)*params(7)*T705*T709;
residual(49)= lhs-rhs;
lhs =y(28)*params(7)+y(29)*params(8)+y(30)*params(9);
rhs =y(65)*params(8)*T722*T726;
residual(50)= lhs-rhs;
lhs =y(31)*params(7)+y(32)*params(8)+y(33)*params(9);
rhs =y(66)*params(9)*T738*T742;
residual(51)= lhs-rhs;
lhs =log(y(64));
rhs =params(10)*log(y(13))+x(it_, 1);
residual(52)= lhs-rhs;
lhs =log(y(65));
rhs =params(11)*log(y(14))+x(it_, 2);
residual(53)= lhs-rhs;
lhs =log(y(66));
rhs =params(12)*log(y(15))+x(it_, 3);
residual(54)= lhs-rhs;
lhs =y(71);
rhs =T867/y(43);
residual(55)= lhs-rhs;
lhs =y(70);
rhs =(y(25)*params(47)+y(28)*params(50)+y(31)*params(53)-T705*T709*y(64)*params(47))/y(43)-y(71);
residual(56)= lhs-rhs;
lhs =y(72);
rhs =y(46)/y(43);
residual(57)= lhs-rhs;
lhs =y(73);
rhs =y(49)/y(43);
residual(58)= lhs-rhs;
lhs =y(74);
rhs =y(28)*(1-y(72));
residual(59)= lhs-rhs;
lhs =y(75);
rhs =y(31)*(1-y(73));
residual(60)= lhs-rhs;
lhs =y(76);
rhs =y(31)+y(25)+y(28)-y(74)-y(75)-y(64)*T705*T709;
residual(61)= lhs-rhs;
lhs =y(77);
rhs =y(64)*T705*T709;
residual(62)= lhs-rhs;
lhs =y(78);
rhs =y(65)*T722*T726;
residual(63)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(63, 102);

  %
  % Jacobian matrix
  %

T917 = getPowerDeriv(T256,1-params(2),1);
T918 = T255*getPowerDeriv(y(16),params(6),1)*T917;
T927 = 1/y(16)*T918+T257*(-1)/(y(16)*y(16));
T948 = getPowerDeriv(T230,1-params(2),1);
T949 = T229*getPowerDeriv(y(79),params(6),1)*T948;
T966 = getPowerDeriv(T292,1-params(2),1);
T967 = T291*getPowerDeriv(y(17),params(6),1)*T966;
T976 = 1/y(17)*T967+T293*(-1)/(y(17)*y(17));
T989 = getPowerDeriv(T270,1-params(2),1);
T990 = T269*getPowerDeriv(y(80),params(6),1)*T989;
T1007 = getPowerDeriv(T328,1-params(2),1);
T1008 = T327*getPowerDeriv(y(18),params(6),1)*T1007;
T1017 = 1/y(18)*T1008+T329*(-1)/(y(18)*y(18));
T1030 = getPowerDeriv(T306,1-params(2),1);
T1031 = T305*getPowerDeriv(y(81),params(6),1)*T1030;
T1081 = getPowerDeriv(y(19),params(1),1);
T1131 = getPowerDeriv(y(20),params(1),1);
T1177 = getPowerDeriv(y(21),params(1),1);
T1193 = T917*T252*(-(getPowerDeriv(params(34)-y(22),1-params(6),1)));
T1214 = getPowerDeriv(y(22),1-params(1),1);
T1232 = T948*T224*(-(getPowerDeriv(params(34)-y(82),1-params(6),1)));
T1243 = T966*T288*(-(getPowerDeriv(params(34)-y(23),1-params(6),1)));
T1257 = getPowerDeriv(y(23),1-params(1),1);
T1271 = T989*T266*(-(getPowerDeriv(params(34)-y(83),1-params(6),1)));
T1282 = T1007*T324*(-(getPowerDeriv(params(34)-y(24),1-params(6),1)));
T1296 = getPowerDeriv(y(24),1-params(1),1);
T1314 = T1030*T302*(-(getPowerDeriv(params(34)-y(84),1-params(6),1)));
T1322 = y(28)/y(25)/y(7);
T1327 = y(31)/y(25)/y(10);
T1353 = params(25)*getPowerDeriv(y(25),T16,1);
T1354 = getPowerDeriv(T32,T33,1);
T1359 = y(4)*(-y(28))/(y(25)*y(25))/y(7);
T1365 = y(4)*(-y(31))/(y(25)*y(25))/y(10);
T1394 = params(39)*y(61)*y(91)/y(85)/y(31);
T1401 = getPowerDeriv(T32,T432,1);
T1437 = params(37)*y(61)*y(25)*(-y(88))/(y(85)*y(85))/y(28);
T1445 = params(39)*y(61)*y(25)*(-y(91))/(y(85)*y(85))/y(31);
T1466 = (-(y(26)/y(29)*y(8)))/(y(5)*y(5));
T1472 = (-(y(11)*y(26)/y(32)))/(y(5)*y(5));
T1503 = params(28)*params(19)*getPowerDeriv(params(19)*y(26),T16,1);
T1504 = getPowerDeriv(T88,T33,1);
T1508 = y(8)*1/y(29)/y(5);
T1514 = y(11)*1/y(32)/y(5);
T1525 = params(40)*y(62)*(-(y(29)*y(86)/y(89)))/(y(26)*y(26));
T1540 = params(42)*y(62)*(-(y(32)*y(86)/y(92)))/(y(26)*y(26));
T1553 = getPowerDeriv(T88,T432,1);
T1586 = params(40)*y(62)*y(29)*1/y(89)/y(26);
T1596 = params(42)*y(62)*y(32)*1/y(92)/y(26);
T1612 = (-(y(27)/y(30)*y(9)))/(y(6)*y(6));
T1618 = (-(y(12)*y(27)/y(33)))/(y(6)*y(6));
T1649 = params(31)*params(20)*getPowerDeriv(params(20)*y(27),T16,1);
T1650 = getPowerDeriv(T143,T33,1);
T1654 = y(9)*1/y(30)/y(6);
T1660 = y(12)*1/y(33)/y(6);
T1671 = params(43)*y(62)*(-(y(30)*y(87)/y(90)))/(y(27)*y(27));
T1686 = params(45)*y(62)*(-(y(33)*y(87)/y(93)))/(y(27)*y(27));
T1697 = getPowerDeriv(T143,T432,1);
T1736 = params(43)*y(62)*y(30)*1/y(90)/y(27);
T1746 = params(45)*y(62)*y(33)*1/y(93)/y(27);
T1764 = (-(y(28)/y(25)*y(4)))/(y(7)*y(7));
T1769 = (-(y(28)/y(31)*y(10)))/(y(7)*y(7));
T1800 = params(26)*params(21)*getPowerDeriv(params(21)*y(28),T16,1);
T1804 = y(4)*1/y(25)/y(7);
T1810 = y(10)*1/y(31)/y(7);
T1824 = params(37)*y(61)*(-(y(25)*y(88)/y(85)))/(y(28)*y(28));
T1840 = params(38)*y(61)*(-(y(31)*y(88)/y(91)))/(y(28)*y(28));
T1886 = params(37)*y(61)*y(25)*1/y(85)/y(28);
T1894 = params(38)*y(61)*y(31)*1/y(91)/y(28);
T1912 = y(26)/y(29)/y(5);
T1916 = y(32)/y(29)/y(11);
T1942 = params(29)*getPowerDeriv(y(29),T16,1);
T1947 = y(8)*(-y(26))/(y(29)*y(29))/y(5);
T1953 = y(8)*(-y(32))/(y(29)*y(29))/y(11);
T1964 = params(40)*y(62)*y(86)/y(89)/y(26);
T2022 = params(40)*y(62)*y(29)*(-y(86))/(y(89)*y(89))/y(26);
T2032 = params(41)*y(62)*y(29)*(-y(92))/(y(89)*y(89))/y(32);
T2049 = y(27)/y(30)/y(6);
T2055 = (-(y(30)/y(33)*y(12)))/(y(9)*y(9));
T2083 = params(32)*params(22)*getPowerDeriv(params(22)*y(30),T16,1);
T2088 = y(9)*(-y(27))/(y(30)*y(30))/y(6);
T2092 = y(12)*1/y(33)/y(9);
T2103 = params(43)*y(62)*y(87)/y(90)/y(27);
T2118 = params(44)*y(62)*(-(y(33)*y(90)/y(93)))/(y(30)*y(30));
T2170 = params(43)*y(62)*y(30)*(-y(87))/(y(90)*y(90))/y(27);
T2178 = params(44)*y(62)*y(33)*1/y(93)/y(30);
T2193 = y(28)/y(31)/y(7);
T2199 = (-(y(4)*y(31)/y(25)))/(y(10)*y(10));
T2226 = params(27)*params(23)*getPowerDeriv(params(23)*y(31),T16,1);
T2231 = y(10)*(-y(28))/(y(31)*y(31))/y(7);
T2235 = y(4)*1/y(25)/y(10);
T2247 = params(39)*y(61)*(-(y(25)*y(91)/y(85)))/(y(31)*y(31));
T2264 = params(38)*y(61)*y(88)/y(91)/y(28);
T2308 = params(39)*y(61)*y(25)*1/y(85)/y(31);
T2317 = params(38)*y(61)*y(31)*(-y(88))/(y(91)*y(91))/y(28);
T2336 = (-(y(8)*y(32)/y(29)))/(y(11)*y(11));
T2340 = y(26)/y(32)/y(5);
T2371 = params(30)*params(24)*getPowerDeriv(params(24)*y(32),T16,1);
T2373 = y(8)*1/y(29)/y(11);
T2380 = y(11)*(-y(26))/(y(32)*y(32))/y(5);
T2391 = params(42)*y(62)*y(86)/y(92)/y(26);
T2409 = params(41)*y(62)*(-(y(29)*y(92)/y(89)))/(y(32)*y(32));
T2451 = params(42)*y(62)*y(32)*(-y(86))/(y(92)*y(92))/y(26);
T2458 = params(41)*y(62)*y(29)*1/y(89)/y(32);
T2473 = y(30)/y(33)/y(9);
T2477 = y(27)/y(33)/y(6);
T2506 = params(33)*getPowerDeriv(y(33),T16,1);
T2511 = y(12)*(-y(30))/(y(33)*y(33))/y(9);
T2517 = y(12)*(-y(27))/(y(33)*y(33))/y(6);
T2543 = params(44)*y(62)*y(90)/y(93)/y(30);
T2588 = params(45)*y(62)*y(33)*(-y(87))/(y(93)*y(93))/y(27);
T2598 = params(44)*y(62)*y(33)*(-y(90))/(y(93)*y(93))/y(30);
  g1(1,16)=(-1);
  g1(1,4)=(-(T37*T1322*2*T43))-T58*T1327*2*T62;
  g1(1,25)=T1353*T1354-T37*2*T43*T1359-T58*2*T62*T1365;
  g1(1,7)=(-(T37*2*T43*T1764))-T48*T1769*2*T53;
  g1(1,28)=T1354*T1800-T37*2*T43*T1804-T48*2*T53*T1810;
  g1(1,10)=(-(T48*2*T53*T2193))-T58*2*T62*T2199;
  g1(1,31)=T1354*T2226-T48*2*T53*T2231-T58*2*T62*T2235;
  g1(1,67)=(-1);
  g1(2,17)=(-1);
  g1(2,5)=(-(T92*T1466*2*T98))-T113*T1472*2*T117;
  g1(2,26)=T1503*T1504-T92*2*T98*T1508-T113*2*T117*T1514;
  g1(2,8)=(-(T92*2*T98*T1912))-T103*T1916*2*T108;
  g1(2,29)=T1504*T1942-T92*2*T98*T1947-T103*2*T108*T1953;
  g1(2,11)=(-(T103*2*T108*T2336))-T113*2*T117*T2340;
  g1(2,32)=T1504*T2371-T103*2*T108*T2373-T113*2*T117*T2380;
  g1(2,68)=(-1);
  g1(3,18)=(-1);
  g1(3,6)=(-(T147*T1612*2*T153))-T168*T1618*2*T172;
  g1(3,27)=T1649*T1650-T147*2*T153*T1654-T168*2*T172*T1660;
  g1(3,9)=(-(T147*2*T153*T2049))-T158*T2055*2*T163;
  g1(3,30)=T1650*T2083-T147*2*T153*T2088-T158*2*T163*T2092;
  g1(3,12)=(-(T158*2*T163*T2473))-T168*2*T172*T2477;
  g1(3,33)=T1650*T2506-T158*2*T163*T2511-T168*2*T172*T2517;
  g1(3,69)=(-1);
  g1(4,1)=1-params(3)-(params(46)*T189+y(1)*params(46)*(-y(67))/(y(1)*y(1))*2*(y(67)/y(1)-params(3)));
  g1(4,19)=(-1);
  g1(4,67)=1-y(1)*params(46)*2*(y(67)/y(1)-params(3))*1/y(1);
  g1(5,2)=1-params(3)-(params(46)*T202+params(46)*y(2)*(-y(68))/(y(2)*y(2))*2*(y(68)/y(2)-params(3)));
  g1(5,20)=(-1);
  g1(5,68)=1-params(46)*y(2)*2*(y(68)/y(2)-params(3))*1/y(2);
  g1(6,3)=1-params(3)-(params(46)*T215+params(46)*y(3)*(-y(69))/(y(3)*y(3))*2*(y(69)/y(3)-params(3)));
  g1(6,21)=(-1);
  g1(6,69)=1-params(46)*y(3)*2*(y(69)/y(3)-params(3))*1/y(3);
  g1(7,16)=(-((T257*(-params(6))/(y(16)*y(16))+params(6)/y(16)*T918)/T260));
  g1(7,79)=T249*(T233*(-(params(5)*params(6)))/(y(79)*y(79))+params(5)*params(6)/y(79)*T949)/T239;
  g1(7,1)=(-((-(params(6)/y(16)*T257*(-(params(46)*(-y(67))/(y(1)*y(1))))))/(T260*T260)));
  g1(7,19)=T249*(-(params(5)*params(6)/y(79)*T233*(-(params(46)*(-y(97))/(y(19)*y(19))))))/(T239*T239)+T240*(-(T244*(-((-y(97))/(y(19)*y(19))*2*y(97)/y(19)))));
  g1(7,22)=(-(params(6)/y(16)*T1193/T260));
  g1(7,82)=T249*params(5)*params(6)/y(79)*T1232/T239;
  g1(7,94)=T240;
  g1(7,67)=(-((-(params(6)/y(16)*T257*(-(params(46)*1/y(1)))))/(T260*T260)));
  g1(7,97)=T249*(-(params(5)*params(6)/y(79)*T233*(-(params(46)*1/y(19)))))/(T239*T239)+T240*(-(T244*(-(2*y(97)/y(19)*1/y(19)))));
  g1(8,17)=(-((T293*(-params(6))/(y(17)*y(17))+params(6)/y(17)*T967)/T296));
  g1(8,80)=T285*(T271*(-(params(5)*params(6)))/(y(80)*y(80))+params(5)*params(6)/y(80)*T990)/T277;
  g1(8,2)=(-((-(params(6)/y(17)*T293*(-(params(46)*(-y(68))/(y(2)*y(2))))))/(T296*T296)));
  g1(8,20)=T285*(-(params(5)*params(6)/y(80)*T271*(-(params(46)*(-y(98))/(y(20)*y(20))))))/(T277*T277)+T278*(-(T244*(-((-y(98))/(y(20)*y(20))*2*y(98)/y(20)))));
  g1(8,23)=(-(params(6)/y(17)*T1243/T296));
  g1(8,83)=T285*params(5)*params(6)/y(80)*T1271/T277;
  g1(8,95)=T278;
  g1(8,68)=(-((-(params(6)/y(17)*T293*(-(params(46)*1/y(2)))))/(T296*T296)));
  g1(8,98)=T285*(-(params(5)*params(6)/y(80)*T271*(-(params(46)*1/y(20)))))/(T277*T277)+T278*(-(T244*(-(2*y(98)/y(20)*1/y(20)))));
  g1(9,18)=(-((T329*(-params(6))/(y(18)*y(18))+params(6)/y(18)*T1008)/T332));
  g1(9,81)=T321*(T307*(-(params(5)*params(6)))/(y(81)*y(81))+params(5)*params(6)/y(81)*T1031)/T313;
  g1(9,3)=(-((-(params(6)/y(18)*T329*(-(params(46)*(-y(69))/(y(3)*y(3))))))/(T332*T332)));
  g1(9,21)=T321*(-(params(5)*params(6)/y(81)*T307*(-(params(46)*(-y(99))/(y(21)*y(21))))))/(T313*T313)+T314*(-(T244*(-((-y(99))/(y(21)*y(21))*2*y(99)/y(21)))));
  g1(9,24)=(-(params(6)/y(18)*T1282/T332));
  g1(9,84)=T321*params(5)*params(6)/y(81)*T1314/T313;
  g1(9,96)=T314;
  g1(9,69)=(-((-(params(6)/y(18)*T329*(-(params(46)*1/y(3)))))/(T332*T332)));
  g1(9,99)=T321*(-(params(5)*params(6)/y(81)*T307*(-(params(46)*1/y(21)))))/(T313*T313)+T314*(-(T244*(-(2*y(99)/y(21)*1/y(21)))));
  g1(10,16)=1-params(6);
  g1(10,22)=(-(y(37)*(-params(6))));
  g1(10,37)=(-(params(6)*(params(34)-y(22))));
  g1(11,17)=1-params(6);
  g1(11,23)=(-(y(38)*(-params(6))));
  g1(11,38)=(-(params(6)*(params(34)-y(23))));
  g1(12,18)=1-params(6);
  g1(12,24)=(-(y(39)*(-params(6))));
  g1(12,39)=(-(params(6)*(params(34)-y(24))));
  g1(13,16)=(-(params(35)*(-(T356*T927))/(T358*T358)));
  g1(13,17)=(-(params(35)*T976/T358));
  g1(13,22)=(-(params(35)*(-(T356*1/y(16)*T1193))/(T358*T358)));
  g1(13,23)=(-(params(35)*1/y(17)*T1243/T358));
  g1(13,40)=1;
  g1(14,16)=(-(params(36)*(-(T365*T927))/(T358*T358)));
  g1(14,18)=(-(params(36)*T1017/T358));
  g1(14,22)=(-(params(36)*(-(T365*1/y(16)*T1193))/(T358*T358)));
  g1(14,24)=(-(params(36)*1/y(18)*T1282/T358));
  g1(14,41)=1;
  g1(15,40)=(-((-y(41))/(y(40)*y(40))));
  g1(15,41)=(-(1/y(40)));
  g1(15,42)=1;
  g1(16,16)=(-((-(params(5)*T233*1/y(79)*T927))/(T358*T358)));
  g1(16,79)=(-(params(5)*(1/y(79)*T949+T233*(-1)/(y(79)*y(79)))/T358));
  g1(16,22)=(-((-(params(5)*T233*1/y(79)*1/y(16)*T1193))/(T358*T358)));
  g1(16,82)=(-(params(5)*1/y(79)*T1232/T358));
  g1(16,61)=1;
  g1(17,17)=(-((-(params(5)*T271*1/y(80)*T976))/(T356*T356)));
  g1(17,80)=(-(params(5)*(1/y(80)*T990+T271*(-1)/(y(80)*y(80)))/T356));
  g1(17,23)=(-((-(params(5)*T271*1/y(80)*1/y(17)*T1243))/(T356*T356)));
  g1(17,83)=(-(params(5)*1/y(80)*T1271/T356));
  g1(17,62)=1;
  g1(18,18)=(-((-(params(5)*T307*1/y(81)*T1017))/(T365*T365)));
  g1(18,81)=(-(params(5)*(1/y(81)*T1031+T307*(-1)/(y(81)*y(81)))/T365));
  g1(18,24)=(-((-(params(5)*T307*1/y(81)*1/y(18)*T1282))/(T365*T365)));
  g1(18,84)=(-(params(5)*1/y(81)*T1314/T365));
  g1(18,63)=1;
  g1(19,4)=(params(37)*T43*T395+y(4)*T395*params(37)*T1322)/y(7)+T415*params(39)*T1327+params(39)*T62*(-y(31))/T394/y(10);
  g1(19,25)=y(4)*(T395*params(37)*T1359+params(37)*T43*(-((-y(28))*2*y(25)))/(T394*T394))/y(7)+T408*params(37)*y(61)*T408+T415*params(39)*T1365+params(39)*T62*y(4)*(-((-y(31))*2*y(25)))/(T394*T394)/y(10)+y(91)*T1394/y(85)/y(31)-(T433*params(25)*getPowerDeriv(y(25),T429,1)+T431*T1353*T1401);
  g1(19,85)=T408*T1437+T407*(-y(88))/(y(85)*y(85))/y(28)+(y(85)*y(91)*T1445-y(91)*T424)/(y(85)*y(85))/y(31);
  g1(19,7)=(y(7)*y(4)*T395*params(37)*T1764-y(4)*params(37)*T43*T395)/(y(7)*y(7));
  g1(19,28)=y(4)*(T395*params(37)*T1804+params(37)*T43*(-1)/T394)/y(7)+T408*T1824+T407*(-(y(88)/y(85)))/(y(28)*y(28))-T431*T1401*T1800;
  g1(19,88)=T408*T1886+T407*1/y(85)/y(28);
  g1(19,10)=T415*params(39)*T2199+params(39)*T62*(-(y(4)*(-y(31))/T394))/(y(10)*y(10));
  g1(19,31)=T415*params(39)*T2235+params(39)*T62*y(4)*(-1)/T394/y(10)+(y(31)*y(91)*T2247/y(85)-y(91)*T424/y(85))/(y(31)*y(31))-T431*T1401*T2226;
  g1(19,91)=(T424+y(91)*T2308)/y(85)/y(31);
  g1(19,43)=1;
  g1(19,61)=T408*params(37)*T406+y(91)*params(39)*T423/y(85)/y(31);
  g1(20,4)=T456*params(37)*T1322+params(37)*T43*1/y(7)/y(25);
  g1(20,25)=T456*params(37)*T1359+params(37)*T43*(-(y(4)/y(7)))/(y(25)*y(25))+T461*params(37)*y(61)*T408+T407*(-y(88))/y(85)/T451-T465*T1353*T1401;
  g1(20,85)=T461*T1437+T407*y(25)*y(88)/(y(85)*y(85))/T451;
  g1(20,7)=(y(7)*y(10)*params(38)*T1769/y(31)-y(10)*params(38)*T53/y(31))/(y(7)*y(7))+T456*params(37)*T1764+params(37)*T43*(-y(4))/(y(7)*y(7))/y(25);
  g1(20,28)=y(10)*params(38)*T1810/y(31)/y(7)+T452*T1840+T447*(-(y(31)*(-y(88))/y(91)*2*y(28)))/(T451*T451)+T456*params(37)*T1804+T461*T1824+T407*(-(y(25)*(-y(88))/y(85)*2*y(28)))/(T451*T451)-(T465*T1401*T1800+T433*params(26)*params(21)*getPowerDeriv(params(21)*y(28),T429,1));
  g1(20,88)=T452*T1894+T447*y(31)*(-1)/y(91)/T451+T461*T1886+T407*y(25)*(-1)/y(85)/T451;
  g1(20,10)=(params(38)*T53+y(10)*params(38)*T2193)/y(31)/y(7);
  g1(20,31)=(y(31)*y(10)*params(38)*T2231-y(10)*params(38)*T53)/(y(31)*y(31))/y(7)+T452*T2264+T447*(-y(88))/y(91)/T451-T465*T1401*T2226;
  g1(20,91)=T452*T2317+T447*y(31)*y(88)/(y(91)*y(91))/T451;
  g1(20,46)=1;
  g1(20,61)=T452*params(38)*T446+T461*params(37)*T406;
  g1(21,4)=(params(39)*T62+y(4)*params(39)*T1327)/y(25)/y(10);
  g1(21,25)=(y(25)*y(4)*params(39)*T1365-y(4)*params(39)*T62)/(y(25)*y(25))/y(10)+T477*T1394+T424*(-y(91))/y(85)/T476-T490*T1353*T1401;
  g1(21,85)=T477*T1445+T424*y(25)*y(91)/(y(85)*y(85))/T476;
  g1(21,7)=T482*params(38)*T1769+params(38)*T53*(-(y(10)*(-y(28))/T476))/(y(7)*y(7));
  g1(21,28)=T482*params(38)*T1810+params(38)*T53*y(10)*(-1)/T476/y(7)+(y(28)*y(88)*T1840/y(91)-y(88)*T447/y(91))/(y(28)*y(28))-T490*T1401*T1800;
  g1(21,88)=(T447+y(88)*T1894)/y(91)/y(28);
  g1(21,10)=(y(10)*y(4)*params(39)*T2199/y(25)-y(4)*params(39)*T62/y(25))/(y(10)*y(10))+T482*params(38)*T2193+params(38)*T53*(-y(28))/T476/y(7);
  g1(21,31)=y(4)*params(39)*T2235/y(25)/y(10)+T477*T2247+T424*(-(y(25)*(-y(91))/y(85)*2*y(31)))/(T476*T476)+T482*params(38)*T2231+params(38)*T53*y(10)*(-((-y(28))*2*y(31)))/(T476*T476)/y(7)+y(88)*T2264/y(91)/y(28)-(T490*T1401*T2226+T433*params(27)*params(23)*getPowerDeriv(params(23)*y(31),T429,1));
  g1(21,91)=T477*T2308+T424*y(25)*(-1)/y(85)/T476+(y(91)*y(88)*T2317-y(88)*T447)/(y(91)*y(91))/y(28);
  g1(21,49)=1;
  g1(21,61)=T477*params(39)*T423+y(88)*params(38)*T446/y(91)/y(28);
  g1(22,5)=(y(5)*y(8)*params(40)*T1466/y(29)-y(8)*params(40)*T98/y(29))/(y(5)*y(5))+T516*params(42)*T1472+params(42)*T117*(-y(11))/(y(5)*y(5))/y(32);
  g1(22,26)=y(8)*params(40)*T1508/y(29)/y(5)+T511*T1525+T506*(-(y(29)*(-y(86))/y(89)*2*y(26)))/(T510*T510)+T516*params(42)*T1514+T529*T1540+T525*y(86)*(-((-y(32))*2*y(26)))/(T510*T510)/y(92)-(T534*params(28)*params(19)*getPowerDeriv(params(19)*y(26),T429,1)+T533*T1503*T1553);
  g1(22,86)=T511*T1586+T506*y(29)*(-1)/y(89)/T510+T529*T1596+T525*(-y(32))/T510/y(92);
  g1(22,8)=(params(40)*T98+y(8)*params(40)*T1912)/y(29)/y(5);
  g1(22,29)=(y(29)*y(8)*params(40)*T1947-y(8)*params(40)*T98)/(y(29)*y(29))/y(5)+T511*T1964+T506*(-y(86))/y(89)/T510-T533*T1553*T1942;
  g1(22,89)=T511*T2022+T506*y(29)*y(86)/(y(89)*y(89))/T510;
  g1(22,11)=T516*params(42)*T2340+params(42)*T117*1/y(5)/y(32);
  g1(22,32)=T516*params(42)*T2380+params(42)*T117*(-(y(11)/y(5)))/(y(32)*y(32))+T529*T2391+T525*y(86)*(-1)/T510/y(92)-T533*T1553*T2371;
  g1(22,92)=T529*T2451+T525*(-(y(86)*(-y(32))/T510))/(y(92)*y(92));
  g1(22,44)=1;
  g1(22,62)=T511*params(40)*T505+T529*params(42)*T524;
  g1(23,5)=T557*params(40)*T1466+params(40)*T98*(-(y(8)*(-y(26))/T539))/(y(5)*y(5));
  g1(23,26)=T557*params(40)*T1508+params(40)*T98*y(8)*(-1)/T539/y(5)+(y(26)*y(86)*T1525/y(89)-y(86)*T506/y(89))/(y(26)*y(26))-T565*T1503*T1553;
  g1(23,86)=(T506+y(86)*T1586)/y(89)/y(26);
  g1(23,8)=T542*params(41)*T1916+params(41)*T108*(-y(32))/T539/y(11)+T557*params(40)*T1912+params(40)*T98*(-y(26))/T539/y(5);
  g1(23,29)=T542*params(41)*T1953+params(41)*T108*y(8)*(-((-y(32))*2*y(29)))/(T539*T539)/y(11)+T551*params(41)*y(62)*T551+T557*params(40)*T1947+params(40)*T98*y(8)*(-((-y(26))*2*y(29)))/(T539*T539)/y(5)+y(86)*T1964/y(89)/y(26)-(T565*T1553*T1942+T534*params(29)*getPowerDeriv(y(29),T429,1));
  g1(23,89)=T551*T2032+T550*(-y(92))/(y(89)*y(89))/y(32)+(y(89)*y(86)*T2022-y(86)*T506)/(y(89)*y(89))/y(26);
  g1(23,11)=T542*params(41)*T2336+params(41)*T108*(-(y(8)*(-y(32))/T539))/(y(11)*y(11));
  g1(23,32)=T542*params(41)*T2373+params(41)*T108*y(8)*(-1)/T539/y(11)+T551*T2409+T550*(-(y(92)/y(89)))/(y(32)*y(32))-T565*T1553*T2371;
  g1(23,92)=T551*T2458+T550*1/y(89)/y(32);
  g1(23,47)=1;
  g1(23,62)=T551*params(41)*T549+y(86)*params(40)*T505/y(89)/y(26);
  g1(24,5)=T573*params(42)*T1472+params(42)*T117*y(26)*y(11)/(y(5)*y(5))/T572;
  g1(24,26)=T573*params(42)*T1514+params(42)*T117*(-y(11))/y(5)/T572+y(32)*y(86)*T1540/y(92)-T591*T1503*T1553;
  g1(24,86)=y(32)*(T525+y(86)*T1596)/y(92);
  g1(24,8)=T581*params(41)*T1916+params(41)*T108*1/y(11)/y(29);
  g1(24,29)=T581*params(41)*T1953+params(41)*T108*(-(y(8)/y(11)))/(y(29)*y(29))+T587*params(41)*y(62)*T551+T550*(-y(92))/y(89)/T572-T591*T1553*T1942;
  g1(24,89)=T587*T2032+T550*y(29)*y(92)/(y(89)*y(89))/T572;
  g1(24,11)=T573*params(42)*T2340+params(42)*T117*y(26)*(-1)/y(5)/T572+T581*params(41)*T2336+params(41)*T108*(-y(8))/(y(11)*y(11))/y(29);
  g1(24,32)=T573*params(42)*T2380+params(42)*T117*(-(y(26)*(-y(11))/y(5)*2*y(32)))/(T572*T572)+y(86)*T525/y(92)+y(32)*y(86)*T2391/y(92)+T581*params(41)*T2373+T587*T2409+T550*(-(y(29)*(-y(92))/y(89)*2*y(32)))/(T572*T572)-(T591*T1553*T2371+T534*params(30)*params(24)*getPowerDeriv(params(24)*y(32),T429,1));
  g1(24,92)=y(32)*(y(92)*y(86)*T2451-y(86)*T525)/(y(92)*y(92))+T587*T2458+T550*y(29)*(-1)/y(89)/T572;
  g1(24,50)=1;
  g1(24,62)=y(32)*y(86)*params(42)*T524/y(92)+T587*params(41)*T549;
  g1(25,6)=(y(6)*y(9)*params(43)*T1612/y(30)-y(9)*params(43)*T153/y(30))/(y(6)*y(6))+T617*params(45)*T1618+params(45)*T172*1/y(12)/y(33);
  g1(25,27)=y(9)*params(43)*T1654/y(30)/y(6)+T612*T1671+T607*(-(y(30)*(-y(87))/y(90)*2*y(27)))/(T611*T611)+T617*params(45)*T1660+T629*T1686+T626*(-(y(33)*(-y(87))/y(93)*2*y(27)))/(T611*T611)-(T634*params(31)*params(20)*getPowerDeriv(params(20)*y(27),T429,1)+T633*T1649*T1697);
  g1(25,87)=T612*T1736+T607*y(30)*(-1)/y(90)/T611+T629*T1746+T626*y(33)*(-1)/y(93)/T611;
  g1(25,9)=(params(43)*T153+y(9)*params(43)*T2049)/y(30)/y(6);
  g1(25,30)=(y(30)*y(9)*params(43)*T2088-y(9)*params(43)*T153)/(y(30)*y(30))/y(6)+T612*T2103+T607*(-y(87))/y(90)/T611-T633*T1697*T2083;
  g1(25,90)=T612*T2170+T607*y(30)*y(87)/(y(90)*y(90))/T611;
  g1(25,12)=T617*params(45)*T2477+params(45)*T172*(-y(6))/(y(12)*y(12))/y(33);
  g1(25,33)=T617*params(45)*T2517+params(45)*T172*(-(y(6)/y(12)))/(y(33)*y(33))+T629*params(45)*y(62)*T678+T626*(-y(87))/y(93)/T611-T633*T1697*T2506;
  g1(25,93)=T629*T2588+T626*y(33)*y(87)/(y(93)*y(93))/T611;
  g1(25,45)=1;
  g1(25,62)=T612*params(43)*T606+T629*params(45)*T625;
  g1(26,6)=T659*params(43)*T1612+params(43)*T153*(-(y(9)*(-y(27))/T652))/(y(6)*y(6));
  g1(26,27)=T659*params(43)*T1654+params(43)*T153*y(9)*(-1)/T652/y(6)+(y(27)*y(87)*T1671/y(90)-y(87)*T607/y(90))/(y(27)*y(27))-T667*T1649*T1697;
  g1(26,87)=(T607+y(87)*T1736)/y(90)/y(27);
  g1(26,9)=(y(9)*y(12)*params(44)*T2055/y(33)-y(12)*params(44)*T163/y(33))/(y(9)*y(9))+T659*params(43)*T2049+params(43)*T153*(-y(27))/T652/y(6);
  g1(26,30)=y(12)*params(44)*T2092/y(33)/y(9)+T653*T2118+T648*(-(y(33)*(-y(90))/y(93)*2*y(30)))/(T652*T652)+T659*params(43)*T2088+params(43)*T153*y(9)*(-((-y(27))*2*y(30)))/(T652*T652)/y(6)+y(87)*T2103/y(90)/y(27)-(T667*T1697*T2083+T634*params(32)*params(22)*getPowerDeriv(params(22)*y(30),T429,1));
  g1(26,90)=T653*T2178+T648*y(33)*(-1)/y(93)/T652+(y(90)*y(87)*T2170-y(87)*T607)/(y(90)*y(90))/y(27);
  g1(26,12)=(params(44)*T163+y(12)*params(44)*T2473)/y(33)/y(9);
  g1(26,33)=(y(33)*y(12)*params(44)*T2511-y(12)*params(44)*T163)/(y(33)*y(33))/y(9)+T653*T2543+T648*(-y(90))/y(93)/T652-T667*T1697*T2506;
  g1(26,93)=T653*T2598+T648*y(33)*y(90)/(y(93)*y(93))/T652;
  g1(26,48)=1;
  g1(26,62)=T653*params(44)*T647+y(87)*params(43)*T606/y(90)/y(27);
  g1(27,6)=T675*params(45)*T1618+params(45)*T172*y(27)*y(12)/(y(6)*y(6))/T674;
  g1(27,27)=T675*params(45)*T1660+params(45)*T172*(-y(12))/y(6)/T674+T678*T1686+T626*(-(y(87)/y(93)))/(y(27)*y(27))-T692*T1649*T1697;
  g1(27,87)=T678*T1746+T626*1/y(93)/y(27);
  g1(27,9)=T684*params(44)*T2055+params(44)*T163*(-(y(12)*(-y(30))/T674))/(y(9)*y(9));
  g1(27,30)=T684*params(44)*T2092+params(44)*T163*y(12)*(-1)/T674/y(9)+(y(30)*y(90)*T2118/y(93)-y(90)*T648/y(93))/(y(30)*y(30))-T692*T1697*T2083;
  g1(27,90)=(T648+y(90)*T2178)/y(93)/y(30);
  g1(27,12)=T675*params(45)*T2477+params(45)*T172*y(27)*(-1)/y(6)/T674+T684*params(44)*T2473+params(44)*T163*(-y(30))/T674/y(9);
  g1(27,33)=T675*params(45)*T2517+params(45)*T172*(-(y(27)*(-y(12))/y(6)*2*y(33)))/(T674*T674)+T678*params(45)*y(62)*T678+T684*params(44)*T2511+params(44)*T163*y(12)*(-((-y(30))*2*y(33)))/(T674*T674)/y(9)+y(90)*T2543/y(93)/y(30)-(T692*T1697*T2506+T634*params(33)*getPowerDeriv(y(33),T429,1));
  g1(27,93)=T678*T2588+T626*(-y(87))/(y(93)*y(93))/y(27)+(y(93)*y(90)*T2598-y(90)*T648)/(y(93)*y(93))/y(30);
  g1(27,51)=1;
  g1(27,62)=T678*params(45)*T625+y(90)*params(44)*T647/y(93)/y(30);
  g1(28,19)=(-(T705*y(64)*y(52)*params(1)*getPowerDeriv(y(19),params(1)-1,1)));
  g1(28,22)=(-(T703*T1214));
  g1(28,34)=1;
  g1(28,52)=(-(T705*T702*y(64)*params(1)));
  g1(28,64)=(-(T705*T702*y(52)*params(1)));
  g1(29,19)=(-(T712*y(64)*y(52)*(1-params(1))*T1081));
  g1(29,22)=(-(y(64)*y(52)*(1-params(1))*T709*getPowerDeriv(y(22),(-params(1)),1)));
  g1(29,37)=1;
  g1(29,52)=(-(T712*T709*y(64)*(1-params(1))));
  g1(29,64)=(-(T712*T709*y(52)*(1-params(1))));
  g1(30,20)=(-(T722*params(1)*y(65)*y(56)*getPowerDeriv(y(20),params(1)-1,1)));
  g1(30,23)=(-(T721*T1257));
  g1(30,35)=1;
  g1(30,56)=(-(T722*T720*params(1)*y(65)));
  g1(30,65)=(-(T722*T720*params(1)*y(56)));
  g1(31,20)=(-(T728*(1-params(1))*y(65)*y(56)*T1131));
  g1(31,23)=(-((1-params(1))*y(65)*y(56)*T726*getPowerDeriv(y(23),(-params(1)),1)));
  g1(31,38)=1;
  g1(31,56)=(-(T728*T726*(1-params(1))*y(65)));
  g1(31,65)=(-(T728*T726*(1-params(1))*y(56)));
  g1(32,21)=(-(T738*params(1)*y(66)*y(60)*getPowerDeriv(y(21),params(1)-1,1)));
  g1(32,24)=(-(T737*T1296));
  g1(32,36)=1;
  g1(32,60)=(-(T738*T736*params(1)*y(66)));
  g1(32,66)=(-(T738*T736*params(1)*y(60)));
  g1(33,21)=(-(T744*(1-params(1))*y(66)*y(60)*T1177));
  g1(33,24)=(-((1-params(1))*y(66)*y(60)*T742*getPowerDeriv(y(24),(-params(1)),1)));
  g1(33,39)=1;
  g1(33,60)=(-(T744*T742*(1-params(1))*y(66)));
  g1(33,66)=(-(T744*T742*(1-params(1))*y(60)));
  g1(34,43)=(-1);
  g1(34,52)=1;
  g1(35,44)=1;
  g1(35,53)=(-((1+params(13))/params(19)));
  g1(36,45)=1;
  g1(36,54)=(-((1+params(14))/params(20)));
  g1(37,46)=1;
  g1(37,55)=(-((1+params(15))/params(21)));
  g1(38,47)=(-1);
  g1(38,56)=1;
  g1(39,48)=1;
  g1(39,57)=(-((1+params(16))/params(22)));
  g1(40,49)=1;
  g1(40,58)=(-((1+params(17))/params(23)));
  g1(41,50)=1;
  g1(41,59)=(-((1+params(16))/params(22)));
  g1(42,51)=(-1);
  g1(42,60)=1;
  g1(43,40)=(-y(53));
  g1(43,52)=1;
  g1(43,53)=(-y(40));
  g1(44,40)=(-y(56));
  g1(44,55)=1;
  g1(44,56)=(-y(40));
  g1(45,40)=(-y(59));
  g1(45,58)=1;
  g1(45,59)=(-y(40));
  g1(46,41)=(-y(54));
  g1(46,52)=1;
  g1(46,54)=(-y(41));
  g1(47,41)=(-y(57));
  g1(47,55)=1;
  g1(47,57)=(-y(41));
  g1(48,41)=(-y(60));
  g1(48,58)=1;
  g1(48,60)=(-y(41));
  g1(49,19)=(-(y(64)*params(7)*T705*T1081));
  g1(49,22)=(-(y(64)*params(7)*T709*T1214));
  g1(49,25)=params(7);
  g1(49,26)=params(8);
  g1(49,27)=params(9);
  g1(49,64)=(-(params(7)*T705*T709));
  g1(50,20)=(-(y(65)*params(8)*T722*T1131));
  g1(50,23)=(-(y(65)*params(8)*T726*T1257));
  g1(50,28)=params(7);
  g1(50,29)=params(8);
  g1(50,30)=params(9);
  g1(50,65)=(-(params(8)*T722*T726));
  g1(51,21)=(-(y(66)*params(9)*T738*T1177));
  g1(51,24)=(-(y(66)*params(9)*T742*T1296));
  g1(51,31)=params(7);
  g1(51,32)=params(8);
  g1(51,33)=params(9);
  g1(51,66)=(-(params(9)*T738*T742));
  g1(52,13)=(-(params(10)*1/y(13)));
  g1(52,64)=1/y(64);
  g1(52,100)=(-1);
  g1(53,14)=(-(params(11)*1/y(14)));
  g1(53,65)=1/y(65);
  g1(53,101)=(-1);
  g1(54,15)=(-(params(12)*1/y(15)));
  g1(54,66)=1/y(66);
  g1(54,102)=(-1);
  g1(55,21)=(-(params(9)*y(41)*(-0.5)*(-(y(66)*params(55)*T738*T1177))/params(7)/y(43)));
  g1(55,24)=(-(params(9)*y(41)*(-0.5)*(-(y(66)*params(55)*T742*T1296))/params(7)/y(43)));
  g1(55,27)=(-(params(9)*y(41)*(-0.5)*params(49)/params(7)/y(43)));
  g1(55,30)=(-(params(9)*y(41)*(-0.5)*params(52)/params(7)/y(43)));
  g1(55,33)=(-(params(9)*y(41)*(-0.5)*params(55)/params(7)/y(43)));
  g1(55,41)=(-((y(27)*params(49)+y(30)*params(52)+y(33)*params(55)-T738*T742*y(66)*params(55))*params(9)*(-0.5)/params(7)/y(43)));
  g1(55,43)=(-((-T867)/(y(43)*y(43))));
  g1(55,66)=(-(params(9)*y(41)*(-0.5)*(-(T738*T742*params(55)))/params(7)/y(43)));
  g1(55,71)=1;
  g1(56,19)=(-((-(y(64)*params(47)*T705*T1081))/y(43)));
  g1(56,22)=(-((-(y(64)*params(47)*T709*T1214))/y(43)));
  g1(56,25)=(-(params(47)/y(43)));
  g1(56,28)=(-(params(50)/y(43)));
  g1(56,31)=(-(params(53)/y(43)));
  g1(56,43)=(-((-(y(25)*params(47)+y(28)*params(50)+y(31)*params(53)-T705*T709*y(64)*params(47)))/(y(43)*y(43))));
  g1(56,64)=(-((-(T705*T709*params(47)))/y(43)));
  g1(56,70)=1;
  g1(56,71)=1;
  g1(57,43)=(-((-y(46))/(y(43)*y(43))));
  g1(57,46)=(-(1/y(43)));
  g1(57,72)=1;
  g1(58,43)=(-((-y(49))/(y(43)*y(43))));
  g1(58,49)=(-(1/y(43)));
  g1(58,73)=1;
  g1(59,28)=(-(1-y(72)));
  g1(59,72)=y(28);
  g1(59,74)=1;
  g1(60,31)=(-(1-y(73)));
  g1(60,73)=y(31);
  g1(60,75)=1;
  g1(61,19)=y(64)*T705*T1081;
  g1(61,22)=y(64)*T709*T1214;
  g1(61,25)=(-1);
  g1(61,28)=(-1);
  g1(61,31)=(-1);
  g1(61,64)=T705*T709;
  g1(61,74)=1;
  g1(61,75)=1;
  g1(61,76)=1;
  g1(62,19)=(-(y(64)*T705*T1081));
  g1(62,22)=(-(y(64)*T709*T1214));
  g1(62,64)=(-(T705*T709));
  g1(62,77)=1;
  g1(63,20)=(-(y(65)*T722*T1131));
  g1(63,23)=(-(y(65)*T726*T1257));
  g1(63,65)=(-(T722*T726));
  g1(63,78)=1;

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],63,10404);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],63,1061208);
end
end
end
end
