function [residual, g1, g2, g3] = BKK3C_aut_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(54, 1);
T16 = (params(4)-1)/params(4);
T32 = params(25)*y(25)^T16+params(26)*(params(21)*y(28))^T16+params(27)*(params(23)*y(31))^T16;
T33 = params(4)/(params(4)-1);
T37 = params(37)/2;
T43 = y(28)/y(25)*y(4)/y(7)-1;
T48 = params(38)/2;
T53 = y(28)/y(31)*y(10)/y(7)-1;
T58 = params(39)/2;
T62 = y(4)*y(31)/y(25)/y(10)-1;
T88 = params(28)*(params(19)*y(26))^T16+params(29)*y(29)^T16+params(30)*(params(24)*y(32))^T16;
T92 = params(40)/2;
T98 = y(26)/y(29)*y(8)/y(5)-1;
T103 = params(41)/2;
T108 = y(8)*y(32)/y(29)/y(11)-1;
T113 = params(42)/2;
T117 = y(11)*y(26)/y(32)/y(5)-1;
T143 = params(31)*(params(20)*y(27))^T16+params(32)*(params(22)*y(30))^T16+params(33)*y(33)^T16;
T147 = params(43)/2;
T153 = y(27)/y(30)*y(9)/y(6)-1;
T158 = params(44)/2;
T163 = y(30)/y(33)*y(12)/y(9)-1;
T168 = params(45)/2;
T172 = y(12)*y(27)/y(33)/y(6)-1;
T189 = (y(67)/y(1)-params(3))^2;
T202 = (y(68)/y(2)-params(3))^2;
T215 = (y(69)/y(3)-params(3))^2;
T224 = y(70)^params(6);
T229 = (params(34)-y(73))^(1-params(6));
T230 = T224*T229;
T233 = T230^(1-params(2));
T239 = 1-params(46)*(y(88)/y(19)-params(3));
T240 = params(5)*params(6)/y(70)*T233/T239;
T244 = params(46)/2;
T245 = params(3)^2;
T249 = 1+y(85)-params(3)-T244*(T245-(y(88)/y(19))^2);
T252 = y(16)^params(6);
T255 = (params(34)-y(22))^(1-params(6));
T256 = T252*T255;
T257 = T256^(1-params(2));
T260 = 1-params(46)*(y(67)/y(1)-params(3));
T266 = y(71)^params(6);
T269 = (params(34)-y(74))^(1-params(6));
T270 = T266*T269;
T271 = T270^(1-params(2));
T277 = 1-params(46)*(y(89)/y(20)-params(3));
T278 = params(5)*params(6)/y(71)*T271/T277;
T285 = 1+y(86)-params(3)-T244*(T245-(y(89)/y(20))^2);
T288 = y(17)^params(6);
T291 = (params(34)-y(23))^(1-params(6));
T292 = T288*T291;
T293 = T292^(1-params(2));
T296 = 1-params(46)*(y(68)/y(2)-params(3));
T302 = y(72)^params(6);
T305 = (params(34)-y(75))^(1-params(6));
T306 = T302*T305;
T307 = T306^(1-params(2));
T313 = 1-params(46)*(y(90)/y(21)-params(3));
T314 = params(5)*params(6)/y(72)*T307/T313;
T321 = 1+y(87)-params(3)-T244*(T245-(y(90)/y(21))^2);
T324 = y(18)^params(6);
T327 = (params(34)-y(24))^(1-params(6));
T328 = T324*T327;
T329 = T328^(1-params(2));
T332 = 1-params(46)*(y(69)/y(3)-params(3));
T413 = T257*1/y(16);
T421 = T293*1/y(17);
T429 = T329*1/y(18);
T435 = y(25)^2;
T436 = (-y(28))/T435;
T447 = y(25)*y(79)/y(76)/y(28)-1;
T448 = params(37)*y(61)*T447;
T449 = y(79)/y(76)/y(28);
T456 = y(4)*(-y(31))/T435/y(10);
T464 = y(25)*y(82)/y(76)/y(31)-1;
T465 = params(39)*y(61)*T464;
T470 = (-1)/params(4);
T472 = params(25)*y(25)^T470;
T473 = 1/(params(4)-1);
T474 = T32^T473;
T487 = y(31)*y(79)/y(82)/y(28)-1;
T488 = params(38)*y(61)*T487;
T492 = y(28)^2;
T493 = y(31)*(-y(79))/y(82)/T492;
T497 = y(4)/y(7)/y(25);
T502 = y(25)*(-y(79))/y(76)/T492;
T506 = params(26)*(params(21)*y(28))^T470;
T517 = y(31)^2;
T518 = y(25)*(-y(82))/y(76)/T517;
T523 = y(10)*(-y(28))/T517/y(7);
T531 = params(27)*(params(23)*y(31))^T470;
T546 = y(29)*y(77)/y(80)/y(26)-1;
T547 = params(40)*y(62)*T546;
T551 = y(26)^2;
T552 = y(29)*(-y(77))/y(80)/T551;
T557 = y(11)/y(5)/y(32);
T565 = y(32)*y(77)/y(83)/y(26)-1;
T566 = params(42)*y(62)*T565;
T570 = y(77)*(-y(32))/T551/y(83);
T574 = params(28)*(params(19)*y(26))^T470;
T575 = T88^T473;
T580 = y(29)^2;
T583 = y(8)*(-y(32))/T580/y(11);
T590 = y(29)*y(83)/y(80)/y(32)-1;
T591 = params(41)*y(62)*T590;
T592 = y(83)/y(80)/y(32);
T598 = y(8)*(-y(26))/T580/y(5);
T606 = params(29)*y(29)^T470;
T613 = y(32)^2;
T614 = y(26)*(-y(11))/y(5)/T613;
T622 = y(8)/y(11)/y(29);
T628 = y(29)*(-y(83))/y(80)/T613;
T632 = params(30)*(params(24)*y(32))^T470;
T647 = y(30)*y(78)/y(81)/y(27)-1;
T648 = params(43)*y(62)*T647;
T652 = y(27)^2;
T653 = y(30)*(-y(78))/y(81)/T652;
T658 = y(6)/y(12)/y(33);
T666 = y(33)*y(78)/y(84)/y(27)-1;
T667 = params(45)*y(62)*T666;
T670 = y(33)*(-y(78))/y(84)/T652;
T674 = params(31)*(params(20)*y(27))^T470;
T675 = T143^T473;
T688 = y(33)*y(81)/y(84)/y(30)-1;
T689 = params(44)*y(62)*T688;
T693 = y(30)^2;
T694 = y(33)*(-y(81))/y(84)/T693;
T700 = y(9)*(-y(27))/T693/y(6);
T708 = params(32)*(params(22)*y(30))^T470;
T715 = y(33)^2;
T716 = y(27)*(-y(12))/y(6)/T715;
T719 = y(78)/y(84)/y(27);
T725 = y(12)*(-y(30))/T715/y(9);
T733 = params(33)*y(33)^T470;
T743 = y(19)^(params(1)-1);
T744 = y(64)*y(52)*params(1)*T743;
T746 = y(22)^(1-params(1));
T750 = y(19)^params(1);
T753 = y(22)^(-params(1));
T761 = y(20)^(params(1)-1);
T762 = params(1)*y(65)*y(56)*T761;
T763 = y(23)^(1-params(1));
T767 = y(20)^params(1);
T769 = y(23)^(-params(1));
T777 = y(21)^(params(1)-1);
T778 = params(1)*y(66)*y(60)*T777;
T779 = y(24)^(1-params(1));
T783 = y(21)^params(1);
T785 = y(24)^(-params(1));
residual(1) = (-y(16))-y(67)+T32^T33-T37*T43^2-T48*T53^2-T58*T62^2;
residual(2) = (-y(17))-y(68)+T88^T33-T92*T98^2-T103*T108^2-T113*T117^2;
residual(3) = (-y(18))-y(69)+T143^T33-T147*T153^2-T158*T163^2-T168*T172^2;
residual(4) = y(67)+(-y(19))+(1-params(3))*y(1)-y(1)*params(46)*T189;
residual(5) = y(68)+(-y(20))+(1-params(3))*y(2)-params(46)*y(2)*T202;
residual(6) = y(69)+(-y(21))+(1-params(3))*y(3)-params(46)*y(3)*T215;
residual(7) = T240*T249-params(6)/y(16)*T257/T260;
residual(8) = T278*T285-params(6)/y(17)*T293/T296;
residual(9) = T314*T321-params(6)/y(18)*T329/T332;
residual(10) = y(16)*(1-params(6))-params(6)*(params(34)-y(22))*y(37);
residual(11) = y(17)*(1-params(6))-params(6)*(params(34)-y(23))*y(38);
residual(12) = y(18)*(1-params(6))-params(6)*(params(34)-y(24))*y(39);
lhs =0;
rhs =params(7)*(y(28)*(-y(55))-y(31)*y(58))+y(26)*params(8)*y(40)*y(53)+y(27)*params(9)*y(41)*y(54);
residual(13)= lhs-rhs;
lhs =0;
rhs =params(8)*(y(26)*(-y(53))-y(32)*y(59))+y(28)*params(7)*y(55)/y(40)+y(30)*params(9)*y(42)*y(57);
residual(14)= lhs-rhs;
lhs =0;
rhs =params(9)*(y(27)*(-y(54))-y(30)*y(57))+y(31)*params(7)*y(58)/y(41)+y(32)*params(8)*y(59)/y(42);
residual(15)= lhs-rhs;
lhs =y(61);
rhs =params(5)*T233*1/y(70)/T413;
residual(16)= lhs-rhs;
lhs =y(62);
rhs =params(5)*T271*1/y(71)/T421;
residual(17)= lhs-rhs;
lhs =y(63);
rhs =params(5)*T307*1/y(72)/T429;
residual(18)= lhs-rhs;
lhs =y(43)+y(4)*params(37)*T43*T436/y(7)+T448*T449+params(39)*T62*T456+y(82)*T465/y(76)/y(31);
rhs =T472*T474;
residual(19)= lhs-rhs;
lhs =y(46)+y(10)*params(38)*T53/y(31)/y(7)+T488*T493+params(37)*T43*T497+T448*T502;
rhs =T474*T506;
residual(20)= lhs-rhs;
lhs =y(49)+y(4)*params(39)*T62/y(25)/y(10)+T465*T518+params(38)*T53*T523+y(79)*T488/y(82)/y(28);
rhs =T474*T531;
residual(21)= lhs-rhs;
lhs =y(44)+y(8)*params(40)*T98/y(29)/y(5)+T547*T552+params(42)*T117*T557+T566*T570;
rhs =T574*T575;
residual(22)= lhs-rhs;
lhs =y(47)+params(41)*T108*T583+T591*T592+params(40)*T98*T598+y(77)*T547/y(80)/y(26);
rhs =T575*T606;
residual(23)= lhs-rhs;
lhs =y(50)+params(42)*T117*T614+y(32)*y(77)*T566/y(83)+params(41)*T108*T622+T591*T628;
rhs =T575*T632;
residual(24)= lhs-rhs;
lhs =y(45)+y(9)*params(43)*T153/y(30)/y(6)+T648*T653+params(45)*T172*T658+T667*T670;
rhs =T674*T675;
residual(25)= lhs-rhs;
lhs =y(48)+y(12)*params(44)*T163/y(33)/y(9)+T689*T694+params(43)*T153*T700+y(78)*T648/y(81)/y(27);
rhs =T675*T708;
residual(26)= lhs-rhs;
lhs =y(51)+params(45)*T172*T716+T667*T719+params(44)*T163*T725+y(81)*T689/y(84)/y(30);
rhs =T675*T733;
residual(27)= lhs-rhs;
lhs =y(34);
rhs =T744*T746;
residual(28)= lhs-rhs;
lhs =y(37);
rhs =y(64)*y(52)*(1-params(1))*T750*T753;
residual(29)= lhs-rhs;
lhs =y(35);
rhs =T762*T763;
residual(30)= lhs-rhs;
lhs =y(38);
rhs =(1-params(1))*y(65)*y(56)*T767*T769;
residual(31)= lhs-rhs;
lhs =y(36);
rhs =T778*T779;
residual(32)= lhs-rhs;
lhs =y(39);
rhs =(1-params(1))*y(66)*y(60)*T783*T785;
residual(33)= lhs-rhs;
lhs =y(52);
rhs =y(43);
residual(34)= lhs-rhs;
lhs =y(44);
rhs =y(53)*(1+params(13))/params(19);
residual(35)= lhs-rhs;
lhs =y(45);
rhs =y(54)*(1+params(14))/params(20);
residual(36)= lhs-rhs;
lhs =y(46);
rhs =y(55)*(1+params(15))/params(21);
residual(37)= lhs-rhs;
lhs =y(56);
rhs =y(47);
residual(38)= lhs-rhs;
lhs =y(48);
rhs =y(57)*(1+params(16))/params(22);
residual(39)= lhs-rhs;
lhs =y(49);
rhs =y(58)*(1+params(17))/params(23);
residual(40)= lhs-rhs;
lhs =y(50);
rhs =y(59)*(1+params(16))/params(22);
residual(41)= lhs-rhs;
lhs =y(60);
rhs =y(51);
residual(42)= lhs-rhs;
lhs =y(52);
rhs =y(40)*y(53);
residual(43)= lhs-rhs;
lhs =y(55);
rhs =y(40)*y(56);
residual(44)= lhs-rhs;
lhs =y(58);
rhs =y(40)*y(59);
residual(45)= lhs-rhs;
lhs =y(52);
rhs =y(41)*y(54);
residual(46)= lhs-rhs;
lhs =y(55);
rhs =y(41)*y(57);
residual(47)= lhs-rhs;
lhs =y(58);
rhs =y(41)*y(60);
residual(48)= lhs-rhs;
lhs =y(25)*params(7)+y(26)*params(8)+y(27)*params(9);
rhs =params(7)*y(64)*T746*T750;
residual(49)= lhs-rhs;
lhs =y(28)*params(7)+y(29)*params(8)+y(30)*params(9);
rhs =params(8)*y(65)*T763*T767;
residual(50)= lhs-rhs;
lhs =y(31)*params(7)+y(32)*params(8)+y(33)*params(9);
rhs =params(9)*y(66)*T779*T783;
residual(51)= lhs-rhs;
lhs =log(y(64));
rhs =params(10)*log(y(13))+x(it_, 1);
residual(52)= lhs-rhs;
lhs =log(y(65));
rhs =params(11)*log(y(14))+x(it_, 2);
residual(53)= lhs-rhs;
lhs =log(y(66));
rhs =params(12)*log(y(15))+x(it_, 3);
residual(54)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(54, 93);

  %
  % Jacobian matrix
  %

T887 = getPowerDeriv(T256,1-params(2),1);
T888 = T255*getPowerDeriv(y(16),params(6),1)*T887;
T908 = getPowerDeriv(T230,1-params(2),1);
T909 = T229*getPowerDeriv(y(70),params(6),1)*T908;
T926 = getPowerDeriv(T292,1-params(2),1);
T927 = T291*getPowerDeriv(y(17),params(6),1)*T926;
T946 = getPowerDeriv(T270,1-params(2),1);
T947 = T269*getPowerDeriv(y(71),params(6),1)*T946;
T964 = getPowerDeriv(T328,1-params(2),1);
T965 = T327*getPowerDeriv(y(18),params(6),1)*T964;
T984 = getPowerDeriv(T306,1-params(2),1);
T985 = T305*getPowerDeriv(y(72),params(6),1)*T984;
T1035 = getPowerDeriv(y(19),params(1),1);
T1079 = getPowerDeriv(y(20),params(1),1);
T1123 = getPowerDeriv(y(21),params(1),1);
T1133 = T887*T252*(-(getPowerDeriv(params(34)-y(22),1-params(6),1)));
T1144 = getPowerDeriv(y(22),1-params(1),1);
T1156 = T908*T224*(-(getPowerDeriv(params(34)-y(73),1-params(6),1)));
T1167 = T926*T288*(-(getPowerDeriv(params(34)-y(23),1-params(6),1)));
T1178 = getPowerDeriv(y(23),1-params(1),1);
T1190 = T946*T266*(-(getPowerDeriv(params(34)-y(74),1-params(6),1)));
T1201 = T964*T324*(-(getPowerDeriv(params(34)-y(24),1-params(6),1)));
T1212 = getPowerDeriv(y(24),1-params(1),1);
T1224 = T984*T302*(-(getPowerDeriv(params(34)-y(75),1-params(6),1)));
T1232 = y(28)/y(25)/y(7);
T1237 = y(31)/y(25)/y(10);
T1263 = params(25)*getPowerDeriv(y(25),T16,1);
T1264 = getPowerDeriv(T32,T33,1);
T1269 = y(4)*(-y(28))/(y(25)*y(25))/y(7);
T1275 = y(4)*(-y(31))/(y(25)*y(25))/y(10);
T1304 = params(39)*y(61)*y(82)/y(76)/y(31);
T1311 = getPowerDeriv(T32,T473,1);
T1345 = params(37)*y(61)*y(25)*(-y(79))/(y(76)*y(76))/y(28);
T1353 = params(39)*y(61)*y(25)*(-y(82))/(y(76)*y(76))/y(31);
T1374 = (-(y(26)/y(29)*y(8)))/(y(5)*y(5));
T1380 = (-(y(11)*y(26)/y(32)))/(y(5)*y(5));
T1411 = params(28)*params(19)*getPowerDeriv(params(19)*y(26),T16,1);
T1412 = getPowerDeriv(T88,T33,1);
T1416 = y(8)*1/y(29)/y(5);
T1422 = y(11)*1/y(32)/y(5);
T1436 = params(40)*y(62)*(-(y(29)*y(77)/y(80)))/(y(26)*y(26));
T1451 = params(42)*y(62)*(-(y(32)*y(77)/y(83)))/(y(26)*y(26));
T1464 = getPowerDeriv(T88,T473,1);
T1497 = params(40)*y(62)*y(29)*1/y(80)/y(26);
T1507 = params(42)*y(62)*y(32)*1/y(83)/y(26);
T1523 = (-(y(27)/y(30)*y(9)))/(y(6)*y(6));
T1529 = (-(y(12)*y(27)/y(33)))/(y(6)*y(6));
T1560 = params(31)*params(20)*getPowerDeriv(params(20)*y(27),T16,1);
T1561 = getPowerDeriv(T143,T33,1);
T1565 = y(9)*1/y(30)/y(6);
T1571 = y(12)*1/y(33)/y(6);
T1585 = params(43)*y(62)*(-(y(30)*y(78)/y(81)))/(y(27)*y(27));
T1600 = params(45)*y(62)*(-(y(33)*y(78)/y(84)))/(y(27)*y(27));
T1611 = getPowerDeriv(T143,T473,1);
T1646 = params(43)*y(62)*y(30)*1/y(81)/y(27);
T1656 = params(45)*y(62)*y(33)*1/y(84)/y(27);
T1674 = (-(y(28)/y(25)*y(4)))/(y(7)*y(7));
T1679 = (-(y(28)/y(31)*y(10)))/(y(7)*y(7));
T1710 = params(26)*params(21)*getPowerDeriv(params(21)*y(28),T16,1);
T1714 = y(4)*1/y(25)/y(7);
T1720 = y(10)*1/y(31)/y(7);
T1738 = params(37)*y(61)*(-(y(25)*y(79)/y(76)))/(y(28)*y(28));
T1754 = params(38)*y(61)*(-(y(31)*y(79)/y(82)))/(y(28)*y(28));
T1797 = params(37)*y(61)*y(25)*1/y(76)/y(28);
T1805 = params(38)*y(61)*y(31)*1/y(82)/y(28);
T1823 = y(26)/y(29)/y(5);
T1827 = y(32)/y(29)/y(11);
T1853 = params(29)*getPowerDeriv(y(29),T16,1);
T1858 = y(8)*(-y(26))/(y(29)*y(29))/y(5);
T1864 = y(8)*(-y(32))/(y(29)*y(29))/y(11);
T1875 = params(40)*y(62)*y(77)/y(80)/y(26);
T1933 = params(40)*y(62)*y(29)*(-y(77))/(y(80)*y(80))/y(26);
T1943 = params(41)*y(62)*y(29)*(-y(83))/(y(80)*y(80))/y(32);
T1960 = y(27)/y(30)/y(6);
T1966 = (-(y(30)/y(33)*y(12)))/(y(9)*y(9));
T1994 = params(32)*params(22)*getPowerDeriv(params(22)*y(30),T16,1);
T1999 = y(9)*(-y(27))/(y(30)*y(30))/y(6);
T2003 = y(12)*1/y(33)/y(9);
T2018 = params(43)*y(62)*y(78)/y(81)/y(27);
T2033 = params(44)*y(62)*(-(y(33)*y(81)/y(84)))/(y(30)*y(30));
T2081 = params(43)*y(62)*y(30)*(-y(78))/(y(81)*y(81))/y(27);
T2089 = params(44)*y(62)*y(33)*1/y(84)/y(30);
T2104 = y(28)/y(31)/y(7);
T2110 = (-(y(4)*y(31)/y(25)))/(y(10)*y(10));
T2137 = params(27)*params(23)*getPowerDeriv(params(23)*y(31),T16,1);
T2142 = y(10)*(-y(28))/(y(31)*y(31))/y(7);
T2146 = y(4)*1/y(25)/y(10);
T2163 = params(39)*y(61)*(-(y(25)*y(82)/y(76)))/(y(31)*y(31));
T2180 = params(38)*y(61)*y(79)/y(82)/y(28);
T2221 = params(39)*y(61)*y(25)*1/y(76)/y(31);
T2230 = params(38)*y(61)*y(31)*(-y(79))/(y(82)*y(82))/y(28);
T2249 = (-(y(8)*y(32)/y(29)))/(y(11)*y(11));
T2253 = y(26)/y(32)/y(5);
T2284 = params(30)*params(24)*getPowerDeriv(params(24)*y(32),T16,1);
T2286 = y(8)*1/y(29)/y(11);
T2293 = y(11)*(-y(26))/(y(32)*y(32))/y(5);
T2309 = params(42)*y(62)*y(77)/y(83)/y(26);
T2327 = params(41)*y(62)*(-(y(29)*y(83)/y(80)))/(y(32)*y(32));
T2369 = params(42)*y(62)*y(32)*(-y(77))/(y(83)*y(83))/y(26);
T2376 = params(41)*y(62)*y(29)*1/y(80)/y(32);
T2391 = y(30)/y(33)/y(9);
T2395 = y(27)/y(33)/y(6);
T2424 = params(33)*getPowerDeriv(y(33),T16,1);
T2429 = y(12)*(-y(30))/(y(33)*y(33))/y(9);
T2435 = y(12)*(-y(27))/(y(33)*y(33))/y(6);
T2461 = params(44)*y(62)*y(81)/y(84)/y(30);
T2502 = params(45)*y(62)*y(33)*(-y(78))/(y(84)*y(84))/y(27);
T2512 = params(44)*y(62)*y(33)*(-y(81))/(y(84)*y(84))/y(30);
  g1(1,16)=(-1);
  g1(1,4)=(-(T37*T1232*2*T43))-T58*T1237*2*T62;
  g1(1,25)=T1263*T1264-T37*2*T43*T1269-T58*2*T62*T1275;
  g1(1,7)=(-(T37*2*T43*T1674))-T48*T1679*2*T53;
  g1(1,28)=T1264*T1710-T37*2*T43*T1714-T48*2*T53*T1720;
  g1(1,10)=(-(T48*2*T53*T2104))-T58*2*T62*T2110;
  g1(1,31)=T1264*T2137-T48*2*T53*T2142-T58*2*T62*T2146;
  g1(1,67)=(-1);
  g1(2,17)=(-1);
  g1(2,5)=(-(T92*T1374*2*T98))-T113*T1380*2*T117;
  g1(2,26)=T1411*T1412-T92*2*T98*T1416-T113*2*T117*T1422;
  g1(2,8)=(-(T92*2*T98*T1823))-T103*T1827*2*T108;
  g1(2,29)=T1412*T1853-T92*2*T98*T1858-T103*2*T108*T1864;
  g1(2,11)=(-(T103*2*T108*T2249))-T113*2*T117*T2253;
  g1(2,32)=T1412*T2284-T103*2*T108*T2286-T113*2*T117*T2293;
  g1(2,68)=(-1);
  g1(3,18)=(-1);
  g1(3,6)=(-(T147*T1523*2*T153))-T168*T1529*2*T172;
  g1(3,27)=T1560*T1561-T147*2*T153*T1565-T168*2*T172*T1571;
  g1(3,9)=(-(T147*2*T153*T1960))-T158*T1966*2*T163;
  g1(3,30)=T1561*T1994-T147*2*T153*T1999-T158*2*T163*T2003;
  g1(3,12)=(-(T158*2*T163*T2391))-T168*2*T172*T2395;
  g1(3,33)=T1561*T2424-T158*2*T163*T2429-T168*2*T172*T2435;
  g1(3,69)=(-1);
  g1(4,1)=1-params(3)-(params(46)*T189+y(1)*params(46)*(-y(67))/(y(1)*y(1))*2*(y(67)/y(1)-params(3)));
  g1(4,19)=(-1);
  g1(4,67)=1-y(1)*params(46)*2*(y(67)/y(1)-params(3))*1/y(1);
  g1(5,2)=1-params(3)-(params(46)*T202+params(46)*y(2)*(-y(68))/(y(2)*y(2))*2*(y(68)/y(2)-params(3)));
  g1(5,20)=(-1);
  g1(5,68)=1-params(46)*y(2)*2*(y(68)/y(2)-params(3))*1/y(2);
  g1(6,3)=1-params(3)-(params(46)*T215+params(46)*y(3)*(-y(69))/(y(3)*y(3))*2*(y(69)/y(3)-params(3)));
  g1(6,21)=(-1);
  g1(6,69)=1-params(46)*y(3)*2*(y(69)/y(3)-params(3))*1/y(3);
  g1(7,16)=(-((T257*(-params(6))/(y(16)*y(16))+params(6)/y(16)*T888)/T260));
  g1(7,70)=T249*(T233*(-(params(5)*params(6)))/(y(70)*y(70))+params(5)*params(6)/y(70)*T909)/T239;
  g1(7,1)=(-((-(params(6)/y(16)*T257*(-(params(46)*(-y(67))/(y(1)*y(1))))))/(T260*T260)));
  g1(7,19)=T249*(-(params(5)*params(6)/y(70)*T233*(-(params(46)*(-y(88))/(y(19)*y(19))))))/(T239*T239)+T240*(-(T244*(-((-y(88))/(y(19)*y(19))*2*y(88)/y(19)))));
  g1(7,22)=(-(params(6)/y(16)*T1133/T260));
  g1(7,73)=T249*params(5)*params(6)/y(70)*T1156/T239;
  g1(7,85)=T240;
  g1(7,67)=(-((-(params(6)/y(16)*T257*(-(params(46)*1/y(1)))))/(T260*T260)));
  g1(7,88)=T249*(-(params(5)*params(6)/y(70)*T233*(-(params(46)*1/y(19)))))/(T239*T239)+T240*(-(T244*(-(2*y(88)/y(19)*1/y(19)))));
  g1(8,17)=(-((T293*(-params(6))/(y(17)*y(17))+params(6)/y(17)*T927)/T296));
  g1(8,71)=T285*(T271*(-(params(5)*params(6)))/(y(71)*y(71))+params(5)*params(6)/y(71)*T947)/T277;
  g1(8,2)=(-((-(params(6)/y(17)*T293*(-(params(46)*(-y(68))/(y(2)*y(2))))))/(T296*T296)));
  g1(8,20)=T285*(-(params(5)*params(6)/y(71)*T271*(-(params(46)*(-y(89))/(y(20)*y(20))))))/(T277*T277)+T278*(-(T244*(-((-y(89))/(y(20)*y(20))*2*y(89)/y(20)))));
  g1(8,23)=(-(params(6)/y(17)*T1167/T296));
  g1(8,74)=T285*params(5)*params(6)/y(71)*T1190/T277;
  g1(8,86)=T278;
  g1(8,68)=(-((-(params(6)/y(17)*T293*(-(params(46)*1/y(2)))))/(T296*T296)));
  g1(8,89)=T285*(-(params(5)*params(6)/y(71)*T271*(-(params(46)*1/y(20)))))/(T277*T277)+T278*(-(T244*(-(2*y(89)/y(20)*1/y(20)))));
  g1(9,18)=(-((T329*(-params(6))/(y(18)*y(18))+params(6)/y(18)*T965)/T332));
  g1(9,72)=T321*(T307*(-(params(5)*params(6)))/(y(72)*y(72))+params(5)*params(6)/y(72)*T985)/T313;
  g1(9,3)=(-((-(params(6)/y(18)*T329*(-(params(46)*(-y(69))/(y(3)*y(3))))))/(T332*T332)));
  g1(9,21)=T321*(-(params(5)*params(6)/y(72)*T307*(-(params(46)*(-y(90))/(y(21)*y(21))))))/(T313*T313)+T314*(-(T244*(-((-y(90))/(y(21)*y(21))*2*y(90)/y(21)))));
  g1(9,24)=(-(params(6)/y(18)*T1201/T332));
  g1(9,75)=T321*params(5)*params(6)/y(72)*T1224/T313;
  g1(9,87)=T314;
  g1(9,69)=(-((-(params(6)/y(18)*T329*(-(params(46)*1/y(3)))))/(T332*T332)));
  g1(9,90)=T321*(-(params(5)*params(6)/y(72)*T307*(-(params(46)*1/y(21)))))/(T313*T313)+T314*(-(T244*(-(2*y(90)/y(21)*1/y(21)))));
  g1(10,16)=1-params(6);
  g1(10,22)=(-(y(37)*(-params(6))));
  g1(10,37)=(-(params(6)*(params(34)-y(22))));
  g1(11,17)=1-params(6);
  g1(11,23)=(-(y(38)*(-params(6))));
  g1(11,38)=(-(params(6)*(params(34)-y(23))));
  g1(12,18)=1-params(6);
  g1(12,24)=(-(y(39)*(-params(6))));
  g1(12,39)=(-(params(6)*(params(34)-y(24))));
  g1(13,26)=(-(params(8)*y(40)*y(53)));
  g1(13,27)=(-(params(9)*y(41)*y(54)));
  g1(13,28)=(-(params(7)*(-y(55))));
  g1(13,31)=(-(params(7)*(-y(58))));
  g1(13,40)=(-(y(26)*params(8)*y(53)));
  g1(13,41)=(-(y(27)*params(9)*y(54)));
  g1(13,53)=(-(y(26)*params(8)*y(40)));
  g1(13,54)=(-(y(27)*params(9)*y(41)));
  g1(13,55)=(-(params(7)*(-y(28))));
  g1(13,58)=(-(params(7)*(-y(31))));
  g1(14,26)=(-(params(8)*(-y(53))));
  g1(14,28)=(-(params(7)*y(55)/y(40)));
  g1(14,30)=(-(params(9)*y(42)*y(57)));
  g1(14,32)=(-(params(8)*(-y(59))));
  g1(14,40)=(-((-(y(28)*params(7)*y(55)))/(y(40)*y(40))));
  g1(14,42)=(-(y(30)*params(9)*y(57)));
  g1(14,53)=(-(params(8)*(-y(26))));
  g1(14,55)=(-(y(28)*params(7)/y(40)));
  g1(14,57)=(-(y(30)*params(9)*y(42)));
  g1(14,59)=(-(params(8)*(-y(32))));
  g1(15,27)=(-(params(9)*(-y(54))));
  g1(15,30)=(-(params(9)*(-y(57))));
  g1(15,31)=(-(params(7)*y(58)/y(41)));
  g1(15,32)=(-(params(8)*y(59)/y(42)));
  g1(15,41)=(-((-(y(31)*params(7)*y(58)))/(y(41)*y(41))));
  g1(15,42)=(-((-(y(32)*params(8)*y(59)))/(y(42)*y(42))));
  g1(15,54)=(-(params(9)*(-y(27))));
  g1(15,57)=(-(params(9)*(-y(30))));
  g1(15,58)=(-(y(31)*params(7)/y(41)));
  g1(15,59)=(-(y(32)*params(8)/y(42)));
  g1(16,16)=(-((-(params(5)*T233*1/y(70)*(1/y(16)*T888+T257*(-1)/(y(16)*y(16)))))/(T413*T413)));
  g1(16,70)=(-(params(5)*(1/y(70)*T909+T233*(-1)/(y(70)*y(70)))/T413));
  g1(16,22)=(-((-(params(5)*T233*1/y(70)*1/y(16)*T1133))/(T413*T413)));
  g1(16,73)=(-(params(5)*1/y(70)*T1156/T413));
  g1(16,61)=1;
  g1(17,17)=(-((-(params(5)*T271*1/y(71)*(1/y(17)*T927+T293*(-1)/(y(17)*y(17)))))/(T421*T421)));
  g1(17,71)=(-(params(5)*(1/y(71)*T947+T271*(-1)/(y(71)*y(71)))/T421));
  g1(17,23)=(-((-(params(5)*T271*1/y(71)*1/y(17)*T1167))/(T421*T421)));
  g1(17,74)=(-(params(5)*1/y(71)*T1190/T421));
  g1(17,62)=1;
  g1(18,18)=(-((-(params(5)*T307*1/y(72)*(1/y(18)*T965+T329*(-1)/(y(18)*y(18)))))/(T429*T429)));
  g1(18,72)=(-(params(5)*(1/y(72)*T985+T307*(-1)/(y(72)*y(72)))/T429));
  g1(18,24)=(-((-(params(5)*T307*1/y(72)*1/y(18)*T1201))/(T429*T429)));
  g1(18,75)=(-(params(5)*1/y(72)*T1224/T429));
  g1(18,63)=1;
  g1(19,4)=(params(37)*T43*T436+y(4)*T436*params(37)*T1232)/y(7)+T456*params(39)*T1237+params(39)*T62*(-y(31))/T435/y(10);
  g1(19,25)=y(4)*(T436*params(37)*T1269+params(37)*T43*(-((-y(28))*2*y(25)))/(T435*T435))/y(7)+T449*params(37)*y(61)*T449+T456*params(39)*T1275+params(39)*T62*y(4)*(-((-y(31))*2*y(25)))/(T435*T435)/y(10)+y(82)*T1304/y(76)/y(31)-(T474*params(25)*getPowerDeriv(y(25),T470,1)+T472*T1263*T1311);
  g1(19,76)=T449*T1345+T448*(-y(79))/(y(76)*y(76))/y(28)+(y(76)*y(82)*T1353-y(82)*T465)/(y(76)*y(76))/y(31);
  g1(19,7)=(y(7)*y(4)*T436*params(37)*T1674-y(4)*params(37)*T43*T436)/(y(7)*y(7));
  g1(19,28)=y(4)*(T436*params(37)*T1714+params(37)*T43*(-1)/T435)/y(7)+T449*T1738+T448*(-(y(79)/y(76)))/(y(28)*y(28))-T472*T1311*T1710;
  g1(19,79)=T449*T1797+T448*1/y(76)/y(28);
  g1(19,10)=T456*params(39)*T2110+params(39)*T62*(-(y(4)*(-y(31))/T435))/(y(10)*y(10));
  g1(19,31)=T456*params(39)*T2146+params(39)*T62*y(4)*(-1)/T435/y(10)+(y(31)*y(82)*T2163/y(76)-y(82)*T465/y(76))/(y(31)*y(31))-T472*T1311*T2137;
  g1(19,82)=(T465+y(82)*T2221)/y(76)/y(31);
  g1(19,43)=1;
  g1(19,61)=T449*params(37)*T447+y(82)*params(39)*T464/y(76)/y(31);
  g1(20,4)=T497*params(37)*T1232+params(37)*T43*1/y(7)/y(25);
  g1(20,25)=T497*params(37)*T1269+params(37)*T43*(-(y(4)/y(7)))/(y(25)*y(25))+T502*params(37)*y(61)*T449+T448*(-y(79))/y(76)/T492-T506*T1263*T1311;
  g1(20,76)=T502*T1345+T448*y(25)*y(79)/(y(76)*y(76))/T492;
  g1(20,7)=(y(7)*y(10)*params(38)*T1679/y(31)-y(10)*params(38)*T53/y(31))/(y(7)*y(7))+T497*params(37)*T1674+params(37)*T43*(-y(4))/(y(7)*y(7))/y(25);
  g1(20,28)=y(10)*params(38)*T1720/y(31)/y(7)+T493*T1754+T488*(-(y(31)*(-y(79))/y(82)*2*y(28)))/(T492*T492)+T497*params(37)*T1714+T502*T1738+T448*(-(y(25)*(-y(79))/y(76)*2*y(28)))/(T492*T492)-(T506*T1311*T1710+T474*params(26)*params(21)*getPowerDeriv(params(21)*y(28),T470,1));
  g1(20,79)=T493*T1805+T488*y(31)*(-1)/y(82)/T492+T502*T1797+T448*y(25)*(-1)/y(76)/T492;
  g1(20,10)=(params(38)*T53+y(10)*params(38)*T2104)/y(31)/y(7);
  g1(20,31)=(y(31)*y(10)*params(38)*T2142-y(10)*params(38)*T53)/(y(31)*y(31))/y(7)+T493*T2180+T488*(-y(79))/y(82)/T492-T506*T1311*T2137;
  g1(20,82)=T493*T2230+T488*y(31)*y(79)/(y(82)*y(82))/T492;
  g1(20,46)=1;
  g1(20,61)=T493*params(38)*T487+T502*params(37)*T447;
  g1(21,4)=(params(39)*T62+y(4)*params(39)*T1237)/y(25)/y(10);
  g1(21,25)=(y(25)*y(4)*params(39)*T1275-y(4)*params(39)*T62)/(y(25)*y(25))/y(10)+T518*T1304+T465*(-y(82))/y(76)/T517-T531*T1263*T1311;
  g1(21,76)=T518*T1353+T465*y(25)*y(82)/(y(76)*y(76))/T517;
  g1(21,7)=T523*params(38)*T1679+params(38)*T53*(-(y(10)*(-y(28))/T517))/(y(7)*y(7));
  g1(21,28)=T523*params(38)*T1720+params(38)*T53*y(10)*(-1)/T517/y(7)+(y(28)*y(79)*T1754/y(82)-y(79)*T488/y(82))/(y(28)*y(28))-T531*T1311*T1710;
  g1(21,79)=(T488+y(79)*T1805)/y(82)/y(28);
  g1(21,10)=(y(10)*y(4)*params(39)*T2110/y(25)-y(4)*params(39)*T62/y(25))/(y(10)*y(10))+T523*params(38)*T2104+params(38)*T53*(-y(28))/T517/y(7);
  g1(21,31)=y(4)*params(39)*T2146/y(25)/y(10)+T518*T2163+T465*(-(y(25)*(-y(82))/y(76)*2*y(31)))/(T517*T517)+T523*params(38)*T2142+params(38)*T53*y(10)*(-((-y(28))*2*y(31)))/(T517*T517)/y(7)+y(79)*T2180/y(82)/y(28)-(T531*T1311*T2137+T474*params(27)*params(23)*getPowerDeriv(params(23)*y(31),T470,1));
  g1(21,82)=T518*T2221+T465*y(25)*(-1)/y(76)/T517+(y(82)*y(79)*T2230-y(79)*T488)/(y(82)*y(82))/y(28);
  g1(21,49)=1;
  g1(21,61)=T518*params(39)*T464+y(79)*params(38)*T487/y(82)/y(28);
  g1(22,5)=(y(5)*y(8)*params(40)*T1374/y(29)-y(8)*params(40)*T98/y(29))/(y(5)*y(5))+T557*params(42)*T1380+params(42)*T117*(-y(11))/(y(5)*y(5))/y(32);
  g1(22,26)=y(8)*params(40)*T1416/y(29)/y(5)+T552*T1436+T547*(-(y(29)*(-y(77))/y(80)*2*y(26)))/(T551*T551)+T557*params(42)*T1422+T570*T1451+T566*y(77)*(-((-y(32))*2*y(26)))/(T551*T551)/y(83)-(T575*params(28)*params(19)*getPowerDeriv(params(19)*y(26),T470,1)+T574*T1411*T1464);
  g1(22,77)=T552*T1497+T547*y(29)*(-1)/y(80)/T551+T570*T1507+T566*(-y(32))/T551/y(83);
  g1(22,8)=(params(40)*T98+y(8)*params(40)*T1823)/y(29)/y(5);
  g1(22,29)=(y(29)*y(8)*params(40)*T1858-y(8)*params(40)*T98)/(y(29)*y(29))/y(5)+T552*T1875+T547*(-y(77))/y(80)/T551-T574*T1464*T1853;
  g1(22,80)=T552*T1933+T547*y(29)*y(77)/(y(80)*y(80))/T551;
  g1(22,11)=T557*params(42)*T2253+params(42)*T117*1/y(5)/y(32);
  g1(22,32)=T557*params(42)*T2293+params(42)*T117*(-(y(11)/y(5)))/(y(32)*y(32))+T570*T2309+T566*y(77)*(-1)/T551/y(83)-T574*T1464*T2284;
  g1(22,83)=T570*T2369+T566*(-(y(77)*(-y(32))/T551))/(y(83)*y(83));
  g1(22,44)=1;
  g1(22,62)=T552*params(40)*T546+T570*params(42)*T565;
  g1(23,5)=T598*params(40)*T1374+params(40)*T98*(-(y(8)*(-y(26))/T580))/(y(5)*y(5));
  g1(23,26)=T598*params(40)*T1416+params(40)*T98*y(8)*(-1)/T580/y(5)+(y(26)*y(77)*T1436/y(80)-y(77)*T547/y(80))/(y(26)*y(26))-T606*T1411*T1464;
  g1(23,77)=(T547+y(77)*T1497)/y(80)/y(26);
  g1(23,8)=T583*params(41)*T1827+params(41)*T108*(-y(32))/T580/y(11)+T598*params(40)*T1823+params(40)*T98*(-y(26))/T580/y(5);
  g1(23,29)=T583*params(41)*T1864+params(41)*T108*y(8)*(-((-y(32))*2*y(29)))/(T580*T580)/y(11)+T592*params(41)*y(62)*T592+T598*params(40)*T1858+params(40)*T98*y(8)*(-((-y(26))*2*y(29)))/(T580*T580)/y(5)+y(77)*T1875/y(80)/y(26)-(T606*T1464*T1853+T575*params(29)*getPowerDeriv(y(29),T470,1));
  g1(23,80)=T592*T1943+T591*(-y(83))/(y(80)*y(80))/y(32)+(y(80)*y(77)*T1933-y(77)*T547)/(y(80)*y(80))/y(26);
  g1(23,11)=T583*params(41)*T2249+params(41)*T108*(-(y(8)*(-y(32))/T580))/(y(11)*y(11));
  g1(23,32)=T583*params(41)*T2286+params(41)*T108*y(8)*(-1)/T580/y(11)+T592*T2327+T591*(-(y(83)/y(80)))/(y(32)*y(32))-T606*T1464*T2284;
  g1(23,83)=T592*T2376+T591*1/y(80)/y(32);
  g1(23,47)=1;
  g1(23,62)=T592*params(41)*T590+y(77)*params(40)*T546/y(80)/y(26);
  g1(24,5)=T614*params(42)*T1380+params(42)*T117*y(26)*y(11)/(y(5)*y(5))/T613;
  g1(24,26)=T614*params(42)*T1422+params(42)*T117*(-y(11))/y(5)/T613+y(32)*y(77)*T1451/y(83)-T632*T1411*T1464;
  g1(24,77)=y(32)*(T566+y(77)*T1507)/y(83);
  g1(24,8)=T622*params(41)*T1827+params(41)*T108*1/y(11)/y(29);
  g1(24,29)=T622*params(41)*T1864+params(41)*T108*(-(y(8)/y(11)))/(y(29)*y(29))+T628*params(41)*y(62)*T592+T591*(-y(83))/y(80)/T613-T632*T1464*T1853;
  g1(24,80)=T628*T1943+T591*y(29)*y(83)/(y(80)*y(80))/T613;
  g1(24,11)=T614*params(42)*T2253+params(42)*T117*y(26)*(-1)/y(5)/T613+T622*params(41)*T2249+params(41)*T108*(-y(8))/(y(11)*y(11))/y(29);
  g1(24,32)=T614*params(42)*T2293+params(42)*T117*(-(y(26)*(-y(11))/y(5)*2*y(32)))/(T613*T613)+y(77)*T566/y(83)+y(32)*y(77)*T2309/y(83)+T622*params(41)*T2286+T628*T2327+T591*(-(y(29)*(-y(83))/y(80)*2*y(32)))/(T613*T613)-(T632*T1464*T2284+T575*params(30)*params(24)*getPowerDeriv(params(24)*y(32),T470,1));
  g1(24,83)=y(32)*(y(83)*y(77)*T2369-y(77)*T566)/(y(83)*y(83))+T628*T2376+T591*y(29)*(-1)/y(80)/T613;
  g1(24,50)=1;
  g1(24,62)=y(32)*y(77)*params(42)*T565/y(83)+T628*params(41)*T590;
  g1(25,6)=(y(6)*y(9)*params(43)*T1523/y(30)-y(9)*params(43)*T153/y(30))/(y(6)*y(6))+T658*params(45)*T1529+params(45)*T172*1/y(12)/y(33);
  g1(25,27)=y(9)*params(43)*T1565/y(30)/y(6)+T653*T1585+T648*(-(y(30)*(-y(78))/y(81)*2*y(27)))/(T652*T652)+T658*params(45)*T1571+T670*T1600+T667*(-(y(33)*(-y(78))/y(84)*2*y(27)))/(T652*T652)-(T675*params(31)*params(20)*getPowerDeriv(params(20)*y(27),T470,1)+T674*T1560*T1611);
  g1(25,78)=T653*T1646+T648*y(30)*(-1)/y(81)/T652+T670*T1656+T667*y(33)*(-1)/y(84)/T652;
  g1(25,9)=(params(43)*T153+y(9)*params(43)*T1960)/y(30)/y(6);
  g1(25,30)=(y(30)*y(9)*params(43)*T1999-y(9)*params(43)*T153)/(y(30)*y(30))/y(6)+T653*T2018+T648*(-y(78))/y(81)/T652-T674*T1611*T1994;
  g1(25,81)=T653*T2081+T648*y(30)*y(78)/(y(81)*y(81))/T652;
  g1(25,12)=T658*params(45)*T2395+params(45)*T172*(-y(6))/(y(12)*y(12))/y(33);
  g1(25,33)=T658*params(45)*T2435+params(45)*T172*(-(y(6)/y(12)))/(y(33)*y(33))+T670*params(45)*y(62)*T719+T667*(-y(78))/y(84)/T652-T674*T1611*T2424;
  g1(25,84)=T670*T2502+T667*y(33)*y(78)/(y(84)*y(84))/T652;
  g1(25,45)=1;
  g1(25,62)=T653*params(43)*T647+T670*params(45)*T666;
  g1(26,6)=T700*params(43)*T1523+params(43)*T153*(-(y(9)*(-y(27))/T693))/(y(6)*y(6));
  g1(26,27)=T700*params(43)*T1565+params(43)*T153*y(9)*(-1)/T693/y(6)+(y(27)*y(78)*T1585/y(81)-y(78)*T648/y(81))/(y(27)*y(27))-T708*T1560*T1611;
  g1(26,78)=(T648+y(78)*T1646)/y(81)/y(27);
  g1(26,9)=(y(9)*y(12)*params(44)*T1966/y(33)-y(12)*params(44)*T163/y(33))/(y(9)*y(9))+T700*params(43)*T1960+params(43)*T153*(-y(27))/T693/y(6);
  g1(26,30)=y(12)*params(44)*T2003/y(33)/y(9)+T694*T2033+T689*(-(y(33)*(-y(81))/y(84)*2*y(30)))/(T693*T693)+T700*params(43)*T1999+params(43)*T153*y(9)*(-((-y(27))*2*y(30)))/(T693*T693)/y(6)+y(78)*T2018/y(81)/y(27)-(T708*T1611*T1994+T675*params(32)*params(22)*getPowerDeriv(params(22)*y(30),T470,1));
  g1(26,81)=T694*T2089+T689*y(33)*(-1)/y(84)/T693+(y(81)*y(78)*T2081-y(78)*T648)/(y(81)*y(81))/y(27);
  g1(26,12)=(params(44)*T163+y(12)*params(44)*T2391)/y(33)/y(9);
  g1(26,33)=(y(33)*y(12)*params(44)*T2429-y(12)*params(44)*T163)/(y(33)*y(33))/y(9)+T694*T2461+T689*(-y(81))/y(84)/T693-T708*T1611*T2424;
  g1(26,84)=T694*T2512+T689*y(33)*y(81)/(y(84)*y(84))/T693;
  g1(26,48)=1;
  g1(26,62)=T694*params(44)*T688+y(78)*params(43)*T647/y(81)/y(27);
  g1(27,6)=T716*params(45)*T1529+params(45)*T172*y(27)*y(12)/(y(6)*y(6))/T715;
  g1(27,27)=T716*params(45)*T1571+params(45)*T172*(-y(12))/y(6)/T715+T719*T1600+T667*(-(y(78)/y(84)))/(y(27)*y(27))-T733*T1560*T1611;
  g1(27,78)=T719*T1656+T667*1/y(84)/y(27);
  g1(27,9)=T725*params(44)*T1966+params(44)*T163*(-(y(12)*(-y(30))/T715))/(y(9)*y(9));
  g1(27,30)=T725*params(44)*T2003+params(44)*T163*y(12)*(-1)/T715/y(9)+(y(30)*y(81)*T2033/y(84)-y(81)*T689/y(84))/(y(30)*y(30))-T733*T1611*T1994;
  g1(27,81)=(T689+y(81)*T2089)/y(84)/y(30);
  g1(27,12)=T716*params(45)*T2395+params(45)*T172*y(27)*(-1)/y(6)/T715+T725*params(44)*T2391+params(44)*T163*(-y(30))/T715/y(9);
  g1(27,33)=T716*params(45)*T2435+params(45)*T172*(-(y(27)*(-y(12))/y(6)*2*y(33)))/(T715*T715)+T719*params(45)*y(62)*T719+T725*params(44)*T2429+params(44)*T163*y(12)*(-((-y(30))*2*y(33)))/(T715*T715)/y(9)+y(81)*T2461/y(84)/y(30)-(T733*T1611*T2424+T675*params(33)*getPowerDeriv(y(33),T470,1));
  g1(27,84)=T719*T2502+T667*(-y(78))/(y(84)*y(84))/y(27)+(y(84)*y(81)*T2512-y(81)*T689)/(y(84)*y(84))/y(30);
  g1(27,51)=1;
  g1(27,62)=T719*params(45)*T666+y(81)*params(44)*T688/y(84)/y(30);
  g1(28,19)=(-(T746*y(64)*y(52)*params(1)*getPowerDeriv(y(19),params(1)-1,1)));
  g1(28,22)=(-(T744*T1144));
  g1(28,34)=1;
  g1(28,52)=(-(T746*T743*y(64)*params(1)));
  g1(28,64)=(-(T746*T743*y(52)*params(1)));
  g1(29,19)=(-(T753*y(64)*y(52)*(1-params(1))*T1035));
  g1(29,22)=(-(y(64)*y(52)*(1-params(1))*T750*getPowerDeriv(y(22),(-params(1)),1)));
  g1(29,37)=1;
  g1(29,52)=(-(T753*T750*y(64)*(1-params(1))));
  g1(29,64)=(-(T753*T750*y(52)*(1-params(1))));
  g1(30,20)=(-(T763*params(1)*y(65)*y(56)*getPowerDeriv(y(20),params(1)-1,1)));
  g1(30,23)=(-(T762*T1178));
  g1(30,35)=1;
  g1(30,56)=(-(T763*T761*params(1)*y(65)));
  g1(30,65)=(-(T763*T761*params(1)*y(56)));
  g1(31,20)=(-(T769*(1-params(1))*y(65)*y(56)*T1079));
  g1(31,23)=(-((1-params(1))*y(65)*y(56)*T767*getPowerDeriv(y(23),(-params(1)),1)));
  g1(31,38)=1;
  g1(31,56)=(-(T769*T767*(1-params(1))*y(65)));
  g1(31,65)=(-(T769*T767*(1-params(1))*y(56)));
  g1(32,21)=(-(T779*params(1)*y(66)*y(60)*getPowerDeriv(y(21),params(1)-1,1)));
  g1(32,24)=(-(T778*T1212));
  g1(32,36)=1;
  g1(32,60)=(-(T779*T777*params(1)*y(66)));
  g1(32,66)=(-(T779*T777*params(1)*y(60)));
  g1(33,21)=(-(T785*(1-params(1))*y(66)*y(60)*T1123));
  g1(33,24)=(-((1-params(1))*y(66)*y(60)*T783*getPowerDeriv(y(24),(-params(1)),1)));
  g1(33,39)=1;
  g1(33,60)=(-(T785*T783*(1-params(1))*y(66)));
  g1(33,66)=(-(T785*T783*(1-params(1))*y(60)));
  g1(34,43)=(-1);
  g1(34,52)=1;
  g1(35,44)=1;
  g1(35,53)=(-((1+params(13))/params(19)));
  g1(36,45)=1;
  g1(36,54)=(-((1+params(14))/params(20)));
  g1(37,46)=1;
  g1(37,55)=(-((1+params(15))/params(21)));
  g1(38,47)=(-1);
  g1(38,56)=1;
  g1(39,48)=1;
  g1(39,57)=(-((1+params(16))/params(22)));
  g1(40,49)=1;
  g1(40,58)=(-((1+params(17))/params(23)));
  g1(41,50)=1;
  g1(41,59)=(-((1+params(16))/params(22)));
  g1(42,51)=(-1);
  g1(42,60)=1;
  g1(43,40)=(-y(53));
  g1(43,52)=1;
  g1(43,53)=(-y(40));
  g1(44,40)=(-y(56));
  g1(44,55)=1;
  g1(44,56)=(-y(40));
  g1(45,40)=(-y(59));
  g1(45,58)=1;
  g1(45,59)=(-y(40));
  g1(46,41)=(-y(54));
  g1(46,52)=1;
  g1(46,54)=(-y(41));
  g1(47,41)=(-y(57));
  g1(47,55)=1;
  g1(47,57)=(-y(41));
  g1(48,41)=(-y(60));
  g1(48,58)=1;
  g1(48,60)=(-y(41));
  g1(49,19)=(-(params(7)*y(64)*T746*T1035));
  g1(49,22)=(-(params(7)*y(64)*T750*T1144));
  g1(49,25)=params(7);
  g1(49,26)=params(8);
  g1(49,27)=params(9);
  g1(49,64)=(-(params(7)*T746*T750));
  g1(50,20)=(-(params(8)*y(65)*T763*T1079));
  g1(50,23)=(-(params(8)*y(65)*T767*T1178));
  g1(50,28)=params(7);
  g1(50,29)=params(8);
  g1(50,30)=params(9);
  g1(50,65)=(-(params(8)*T763*T767));
  g1(51,21)=(-(params(9)*y(66)*T779*T1123));
  g1(51,24)=(-(params(9)*y(66)*T783*T1212));
  g1(51,31)=params(7);
  g1(51,32)=params(8);
  g1(51,33)=params(9);
  g1(51,66)=(-(params(9)*T779*T783));
  g1(52,13)=(-(params(10)*1/y(13)));
  g1(52,64)=1/y(64);
  g1(52,91)=(-1);
  g1(53,14)=(-(params(11)*1/y(14)));
  g1(53,65)=1/y(65);
  g1(53,92)=(-1);
  g1(54,15)=(-(params(12)*1/y(15)));
  g1(54,66)=1/y(66);
  g1(54,93)=(-1);

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],54,8649);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],54,804357);
end
end
end
end
