function [residual, g1, g2, g3] = BKK3C_aut_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 54, 1);

%
% Model equations
%

T16 = (params(4)-1)/params(4);
T32 = params(25)*y(10)^T16+params(26)*(params(21)*y(13))^T16+params(27)*(params(23)*y(16))^T16;
T33 = params(4)/(params(4)-1);
T38 = y(13)/y(10);
T41 = y(10)*T38/y(13)-1;
T50 = y(16)*y(13)/y(16)/y(13)-1;
T59 = y(10)*y(16)/y(10)/y(16)-1;
T85 = params(28)*(params(19)*y(11))^T16+params(29)*y(14)^T16+params(30)*(params(24)*y(17))^T16;
T93 = y(14)*y(11)/y(14)/y(11)-1;
T99 = y(17)/y(14);
T102 = y(14)*T99/y(17)-1;
T111 = y(17)*y(11)/y(17)/y(11)-1;
T137 = params(31)*(params(20)*y(12))^T16+params(32)*(params(22)*y(15))^T16+params(33)*y(18)^T16;
T145 = y(15)*y(12)/y(15)/y(12)-1;
T154 = y(18)*y(15)/y(18)/y(15)-1;
T160 = y(12)/y(18);
T163 = y(18)*T160/y(12)-1;
T179 = (y(52)/y(4)-params(3))^2;
T191 = (y(53)/y(5)-params(3))^2;
T203 = (y(54)/y(6)-params(3))^2;
T211 = y(1)^params(6);
T216 = (params(34)-y(7))^(1-params(6));
T217 = T211*T216;
T220 = T217^(1-params(2));
T223 = 1-params(46)*(y(52)/y(4)-params(3));
T224 = params(5)*params(6)/y(1)*T220/T223;
T228 = params(46)/2;
T229 = params(3)^2;
T233 = 1+y(19)-params(3)-T228*(T229-(y(52)/y(4))^2);
T241 = y(2)^params(6);
T244 = (params(34)-y(8))^(1-params(6));
T245 = T241*T244;
T246 = T245^(1-params(2));
T249 = 1-params(46)*(y(53)/y(5)-params(3));
T250 = params(5)*params(6)/y(2)*T246/T249;
T257 = 1+y(20)-params(3)-T228*(T229-(y(53)/y(5))^2);
T265 = y(3)^params(6);
T268 = (params(34)-y(9))^(1-params(6));
T269 = T265*T268;
T270 = T269^(1-params(2));
T273 = 1-params(46)*(y(54)/y(6)-params(3));
T274 = params(5)*params(6)/y(3)*T270/T273;
T281 = 1+y(21)-params(3)-T228*(T229-(y(54)/y(6))^2);
T362 = T220*1/y(1);
T368 = T246*1/y(2);
T374 = T270*1/y(3);
T381 = y(10)^2;
T389 = T38/y(13);
T396 = y(10)*(-y(16))/T381/y(16);
T405 = (-1)/params(4);
T407 = params(25)*y(10)^T405;
T408 = 1/(params(4)-1);
T409 = T32^T408;
T422 = y(13)^2;
T423 = y(16)*(-y(13))/y(16)/T422;
T427 = y(10)/y(13)/y(10);
T432 = y(10)*(-y(13))/y(10)/T422;
T436 = params(26)*(params(21)*y(13))^T405;
T446 = y(16)^2;
T447 = y(10)*(-y(16))/y(10)/T446;
T452 = y(16)*(-y(13))/T446/y(13);
T460 = params(27)*(params(23)*y(16))^T405;
T474 = y(11)^2;
T475 = y(14)*(-y(11))/y(14)/T474;
T480 = y(17)/y(11)/y(17);
T488 = y(11)*(-y(17))/T474/y(17);
T492 = params(28)*(params(19)*y(11))^T405;
T493 = T85^T408;
T498 = y(14)^2;
T501 = y(14)*(-y(17))/T498/y(17);
T506 = T99/y(17);
T511 = y(14)*(-y(11))/T498/y(11);
T519 = params(29)*y(14)^T405;
T525 = y(17)^2;
T526 = y(11)*(-y(17))/y(11)/T525;
T534 = y(14)/y(17)/y(14);
T539 = y(14)*(-y(17))/y(14)/T525;
T543 = params(30)*(params(24)*y(17))^T405;
T557 = y(12)^2;
T558 = y(15)*(-y(12))/y(15)/T557;
T569 = y(18)*(-y(12))/y(18)/T557;
T573 = params(31)*(params(20)*y(12))^T405;
T574 = T137^T408;
T588 = y(15)^2;
T589 = y(18)*(-y(15))/y(18)/T588;
T594 = y(15)*(-y(12))/T588/y(12);
T602 = params(32)*(params(22)*y(15))^T405;
T609 = y(18)^2;
T610 = y(12)*(-y(18))/y(12)/T609;
T613 = T160/y(12);
T618 = y(18)*(-y(15))/T609/y(15);
T626 = params(33)*y(18)^T405;
T635 = y(4)^(params(1)-1);
T636 = y(49)*y(37)*params(1)*T635;
T638 = y(7)^(1-params(1));
T642 = y(4)^params(1);
T645 = y(7)^(-params(1));
T652 = y(5)^(params(1)-1);
T653 = params(1)*y(50)*y(41)*T652;
T654 = y(8)^(1-params(1));
T658 = y(5)^params(1);
T660 = y(8)^(-params(1));
T667 = y(6)^(params(1)-1);
T668 = params(1)*y(51)*y(45)*T667;
T669 = y(9)^(1-params(1));
T673 = y(6)^params(1);
T675 = y(9)^(-params(1));
residual(1) = (-y(1))-y(52)+T32^T33-params(37)/2*T41^2-params(38)/2*T50^2-params(39)/2*T59^2;
residual(2) = (-y(2))-y(53)+T85^T33-params(40)/2*T93^2-params(41)/2*T102^2-params(42)/2*T111^2;
residual(3) = (-y(3))-y(54)+T137^T33-params(43)/2*T145^2-params(44)/2*T154^2-params(45)/2*T163^2;
residual(4) = y(52)+(-y(4))+y(4)*(1-params(3))-y(4)*params(46)*T179;
residual(5) = y(53)+(-y(5))+(1-params(3))*y(5)-params(46)*y(5)*T191;
residual(6) = y(54)+(-y(6))+(1-params(3))*y(6)-params(46)*y(6)*T203;
residual(7) = T224*T233-T220*params(6)/y(1)/T223;
residual(8) = T250*T257-T246*params(6)/y(2)/T249;
residual(9) = T274*T281-T270*params(6)/y(3)/T273;
residual(10) = y(1)*(1-params(6))-params(6)*(params(34)-y(7))*y(22);
residual(11) = y(2)*(1-params(6))-params(6)*(params(34)-y(8))*y(23);
residual(12) = y(3)*(1-params(6))-params(6)*(params(34)-y(9))*y(24);
lhs =0;
rhs =params(7)*(y(13)*(-y(40))-y(16)*y(43))+y(11)*params(8)*y(25)*y(38)+y(12)*params(9)*y(26)*y(39);
residual(13)= lhs-rhs;
lhs =0;
rhs =params(8)*(y(11)*(-y(38))-y(17)*y(44))+y(13)*params(7)*y(40)/y(25)+y(15)*params(9)*y(27)*y(42);
residual(14)= lhs-rhs;
lhs =0;
rhs =params(9)*(y(12)*(-y(39))-y(15)*y(42))+y(16)*params(7)*y(43)/y(26)+y(17)*params(8)*y(44)/y(27);
residual(15)= lhs-rhs;
lhs =y(46);
rhs =params(5)*T362/T362;
residual(16)= lhs-rhs;
lhs =y(47);
rhs =params(5)*T368/T368;
residual(17)= lhs-rhs;
lhs =y(48);
rhs =params(5)*T374/T374;
residual(18)= lhs-rhs;
lhs =y(28)+y(10)*params(37)*T41*(-y(13))/T381/y(13)+T41*params(37)*y(46)*T389+params(39)*T59*T396+y(16)*T59*params(39)*y(46)/y(10)/y(16);
rhs =T407*T409;
residual(19)= lhs-rhs;
lhs =y(31)+y(16)*params(38)*T50/y(16)/y(13)+T50*params(38)*y(46)*T423+params(37)*T41*T427+T41*params(37)*y(46)*T432;
rhs =T409*T436;
residual(20)= lhs-rhs;
lhs =y(34)+y(10)*params(39)*T59/y(10)/y(16)+T59*params(39)*y(46)*T447+params(38)*T50*T452+y(13)*T50*params(38)*y(46)/y(16)/y(13);
rhs =T409*T460;
residual(21)= lhs-rhs;
lhs =y(29)+y(14)*params(40)*T93/y(14)/y(11)+T93*params(40)*y(47)*T475+params(42)*T111*T480+T111*params(42)*y(47)*T488;
rhs =T492*T493;
residual(22)= lhs-rhs;
lhs =y(32)+params(41)*T102*T501+T102*params(41)*y(47)*T506+params(40)*T93*T511+y(11)*T93*params(40)*y(47)/y(14)/y(11);
rhs =T493*T519;
residual(23)= lhs-rhs;
lhs =y(35)+params(42)*T111*T526+y(17)*y(11)*T111*params(42)*y(47)/y(17)+params(41)*T102*T534+T102*params(41)*y(47)*T539;
rhs =T493*T543;
residual(24)= lhs-rhs;
lhs =y(30)+y(15)*params(43)*T145/y(15)/y(12)+T145*params(43)*y(47)*T558+params(45)*T163*T160/y(18)+T163*params(45)*y(47)*T569;
rhs =T573*T574;
residual(25)= lhs-rhs;
lhs =y(33)+y(18)*params(44)*T154/y(18)/y(15)+T154*params(44)*y(47)*T589+params(43)*T145*T594+y(12)*T145*params(43)*y(47)/y(15)/y(12);
rhs =T574*T602;
residual(26)= lhs-rhs;
lhs =y(36)+params(45)*T163*T610+T163*params(45)*y(47)*T613+params(44)*T154*T618+y(15)*T154*params(44)*y(47)/y(18)/y(15);
rhs =T574*T626;
residual(27)= lhs-rhs;
lhs =y(19);
rhs =T636*T638;
residual(28)= lhs-rhs;
lhs =y(22);
rhs =y(49)*y(37)*(1-params(1))*T642*T645;
residual(29)= lhs-rhs;
lhs =y(20);
rhs =T653*T654;
residual(30)= lhs-rhs;
lhs =y(23);
rhs =(1-params(1))*y(50)*y(41)*T658*T660;
residual(31)= lhs-rhs;
lhs =y(21);
rhs =T668*T669;
residual(32)= lhs-rhs;
lhs =y(24);
rhs =(1-params(1))*y(51)*y(45)*T673*T675;
residual(33)= lhs-rhs;
lhs =y(37);
rhs =y(28);
residual(34)= lhs-rhs;
lhs =y(29);
rhs =y(38)*(1+params(13))/params(19);
residual(35)= lhs-rhs;
lhs =y(30);
rhs =y(39)*(1+params(14))/params(20);
residual(36)= lhs-rhs;
lhs =y(31);
rhs =y(40)*(1+params(15))/params(21);
residual(37)= lhs-rhs;
lhs =y(41);
rhs =y(32);
residual(38)= lhs-rhs;
lhs =y(33);
rhs =y(42)*(1+params(16))/params(22);
residual(39)= lhs-rhs;
lhs =y(34);
rhs =y(43)*(1+params(17))/params(23);
residual(40)= lhs-rhs;
lhs =y(35);
rhs =y(44)*(1+params(16))/params(22);
residual(41)= lhs-rhs;
lhs =y(45);
rhs =y(36);
residual(42)= lhs-rhs;
lhs =y(37);
rhs =y(25)*y(38);
residual(43)= lhs-rhs;
lhs =y(40);
rhs =y(25)*y(41);
residual(44)= lhs-rhs;
lhs =y(43);
rhs =y(25)*y(44);
residual(45)= lhs-rhs;
lhs =y(37);
rhs =y(26)*y(39);
residual(46)= lhs-rhs;
lhs =y(40);
rhs =y(26)*y(42);
residual(47)= lhs-rhs;
lhs =y(43);
rhs =y(26)*y(45);
residual(48)= lhs-rhs;
lhs =y(10)*params(7)+y(11)*params(8)+y(12)*params(9);
rhs =params(7)*y(49)*T638*T642;
residual(49)= lhs-rhs;
lhs =y(13)*params(7)+y(14)*params(8)+y(15)*params(9);
rhs =params(8)*y(50)*T654*T658;
residual(50)= lhs-rhs;
lhs =y(16)*params(7)+y(17)*params(8)+y(18)*params(9);
rhs =params(9)*y(51)*T669*T673;
residual(51)= lhs-rhs;
lhs =log(y(49));
rhs =log(y(49))*params(10)+x(1);
residual(52)= lhs-rhs;
lhs =log(y(50));
rhs =log(y(50))*params(11)+x(2);
residual(53)= lhs-rhs;
lhs =log(y(51));
rhs =log(y(51))*params(12)+x(3);
residual(54)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(54, 54);

  %
  % Jacobian matrix
  %

T771 = getPowerDeriv(T217,1-params(2),1);
T772 = T216*getPowerDeriv(y(1),params(6),1)*T771;
T788 = 1/y(1)*T772+T220*(-1)/(y(1)*y(1));
T800 = getPowerDeriv(T245,1-params(2),1);
T801 = T244*getPowerDeriv(y(2),params(6),1)*T800;
T816 = 1/y(2)*T801+T246*(-1)/(y(2)*y(2));
T828 = getPowerDeriv(T269,1-params(2),1);
T829 = T268*getPowerDeriv(y(3),params(6),1)*T828;
T844 = 1/y(3)*T829+T270*(-1)/(y(3)*y(3));
T884 = getPowerDeriv(y(4),params(1),1);
T922 = getPowerDeriv(y(5),params(1),1);
T960 = getPowerDeriv(y(6),params(1),1);
T970 = T771*T211*(-(getPowerDeriv(params(34)-y(7),1-params(6),1)));
T986 = getPowerDeriv(y(7),1-params(1),1);
T998 = T800*T241*(-(getPowerDeriv(params(34)-y(8),1-params(6),1)));
T1014 = getPowerDeriv(y(8),1-params(1),1);
T1026 = T828*T265*(-(getPowerDeriv(params(34)-y(9),1-params(6),1)));
T1042 = getPowerDeriv(y(9),1-params(1),1);
T1052 = params(25)*getPowerDeriv(y(10),T16,1);
T1053 = getPowerDeriv(T32,T33,1);
T1059 = (T38+y(10)*(-y(13))/(y(10)*y(10)))/y(13);
T1067 = (y(16)/y(10)+y(10)*(-y(16))/(y(10)*y(10)))/y(16);
T1110 = getPowerDeriv(T32,T408,1);
T1151 = params(28)*params(19)*getPowerDeriv(params(19)*y(11),T16,1);
T1152 = getPowerDeriv(T85,T33,1);
T1159 = (y(11)*y(14)*1/y(14)-y(14)*y(11)/y(14))/(y(11)*y(11));
T1168 = (y(11)*y(17)*1/y(17)-y(17)*y(11)/y(17))/(y(11)*y(11));
T1216 = getPowerDeriv(T85,T408,1);
T1255 = params(31)*params(20)*getPowerDeriv(params(20)*y(12),T16,1);
T1256 = getPowerDeriv(T137,T33,1);
T1263 = (y(12)*y(15)*1/y(15)-y(15)*y(12)/y(15))/(y(12)*y(12));
T1272 = (y(12)*y(18)*1/y(18)-y(18)*T160)/(y(12)*y(12));
T1319 = getPowerDeriv(T137,T408,1);
T1360 = params(26)*params(21)*getPowerDeriv(params(21)*y(13),T16,1);
T1367 = (y(13)*y(10)*1/y(10)-y(10)*T38)/(y(13)*y(13));
T1375 = (y(13)*y(16)*1/y(16)-y(16)*y(13)/y(16))/(y(13)*y(13));
T1465 = params(29)*getPowerDeriv(y(14),T16,1);
T1471 = (y(11)/y(14)+y(14)*(-y(11))/(y(14)*y(14)))/y(11);
T1478 = (T99+y(14)*(-y(17))/(y(14)*y(14)))/y(17);
T1560 = params(32)*params(22)*getPowerDeriv(params(22)*y(15),T16,1);
T1566 = (y(12)/y(15)+y(15)*(-y(12))/(y(15)*y(15)))/y(12);
T1572 = (y(15)*y(18)*1/y(18)-y(18)*y(15)/y(18))/(y(15)*y(15));
T1659 = params(27)*params(23)*getPowerDeriv(params(23)*y(16),T16,1);
T1665 = (y(13)/y(16)+y(16)*(-y(13))/(y(16)*y(16)))/y(13);
T1671 = (y(16)*y(10)*1/y(10)-y(10)*y(16)/y(10))/(y(16)*y(16));
T1757 = params(30)*params(24)*getPowerDeriv(params(24)*y(17),T16,1);
T1762 = (y(17)*y(14)*1/y(14)-y(14)*T99)/(y(17)*y(17));
T1769 = (y(11)/y(17)+y(17)*(-y(11))/(y(17)*y(17)))/y(11);
T1857 = params(33)*getPowerDeriv(y(18),T16,1);
T1863 = (y(15)/y(18)+y(18)*(-y(15))/(y(18)*y(18)))/y(15);
T1870 = (T160+y(18)*(-y(12))/(y(18)*y(18)))/y(12);
  g1(1,1)=(-1);
  g1(1,10)=T1052*T1053-params(37)/2*T1059*2*T41-params(39)/2*T1067*2*T59;
  g1(1,13)=T1053*T1360-params(37)/2*2*T41*T1367-params(38)/2*T1375*2*T50;
  g1(1,16)=T1053*T1659-params(38)/2*2*T50*T1665-params(39)/2*2*T59*T1671;
  g1(1,52)=(-1);
  g1(2,2)=(-1);
  g1(2,11)=T1151*T1152-params(40)/2*T1159*2*T93-params(42)/2*T1168*2*T111;
  g1(2,14)=T1152*T1465-params(40)/2*2*T93*T1471-params(41)/2*T1478*2*T102;
  g1(2,17)=T1152*T1757-params(41)/2*2*T102*T1762-params(42)/2*2*T111*T1769;
  g1(2,53)=(-1);
  g1(3,3)=(-1);
  g1(3,12)=T1255*T1256-params(43)/2*T1263*2*T145-params(45)/2*T1272*2*T163;
  g1(3,15)=T1256*T1560-params(43)/2*2*T145*T1566-params(44)/2*T1572*2*T154;
  g1(3,18)=T1256*T1857-params(44)/2*2*T154*T1863-params(45)/2*2*T163*T1870;
  g1(3,54)=(-1);
  g1(4,4)=(-1)+1-params(3)-(params(46)*T179+y(4)*params(46)*(-y(52))/(y(4)*y(4))*2*(y(52)/y(4)-params(3)));
  g1(4,52)=1-y(4)*params(46)*2*(y(52)/y(4)-params(3))*1/y(4);
  g1(5,5)=(-1)+1-params(3)-(params(46)*T191+params(46)*y(5)*(-y(53))/(y(5)*y(5))*2*(y(53)/y(5)-params(3)));
  g1(5,53)=1-params(46)*y(5)*2*(y(53)/y(5)-params(3))*1/y(5);
  g1(6,6)=(-1)+1-params(3)-(params(46)*T203+params(46)*y(6)*(-y(54))/(y(6)*y(6))*2*(y(54)/y(6)-params(3)));
  g1(6,54)=1-params(46)*y(6)*2*(y(54)/y(6)-params(3))*1/y(6);
  g1(7,1)=T233*(T220*(-(params(5)*params(6)))/(y(1)*y(1))+params(5)*params(6)/y(1)*T772)/T223-(params(6)/y(1)*T772+T220*(-params(6))/(y(1)*y(1)))/T223;
  g1(7,4)=T233*(-(params(5)*params(6)/y(1)*T220*(-(params(46)*(-y(52))/(y(4)*y(4))))))/(T223*T223)+T224*(-(T228*(-((-y(52))/(y(4)*y(4))*2*y(52)/y(4)))))-(-(T220*params(6)/y(1)*(-(params(46)*(-y(52))/(y(4)*y(4))))))/(T223*T223);
  g1(7,7)=T233*params(5)*params(6)/y(1)*T970/T223-params(6)/y(1)*T970/T223;
  g1(7,19)=T224;
  g1(7,52)=T233*(-(params(5)*params(6)/y(1)*T220*(-(params(46)*1/y(4)))))/(T223*T223)+T224*(-(T228*(-(2*y(52)/y(4)*1/y(4)))))-(-(T220*params(6)/y(1)*(-(params(46)*1/y(4)))))/(T223*T223);
  g1(8,2)=T257*(T246*(-(params(5)*params(6)))/(y(2)*y(2))+params(5)*params(6)/y(2)*T801)/T249-(params(6)/y(2)*T801+T246*(-params(6))/(y(2)*y(2)))/T249;
  g1(8,5)=T257*(-(params(5)*params(6)/y(2)*T246*(-(params(46)*(-y(53))/(y(5)*y(5))))))/(T249*T249)+T250*(-(T228*(-((-y(53))/(y(5)*y(5))*2*y(53)/y(5)))))-(-(T246*params(6)/y(2)*(-(params(46)*(-y(53))/(y(5)*y(5))))))/(T249*T249);
  g1(8,8)=T257*params(5)*params(6)/y(2)*T998/T249-params(6)/y(2)*T998/T249;
  g1(8,20)=T250;
  g1(8,53)=T257*(-(params(5)*params(6)/y(2)*T246*(-(params(46)*1/y(5)))))/(T249*T249)+T250*(-(T228*(-(2*y(53)/y(5)*1/y(5)))))-(-(T246*params(6)/y(2)*(-(params(46)*1/y(5)))))/(T249*T249);
  g1(9,3)=T281*(T270*(-(params(5)*params(6)))/(y(3)*y(3))+params(5)*params(6)/y(3)*T829)/T273-(params(6)/y(3)*T829+T270*(-params(6))/(y(3)*y(3)))/T273;
  g1(9,6)=T281*(-(params(5)*params(6)/y(3)*T270*(-(params(46)*(-y(54))/(y(6)*y(6))))))/(T273*T273)+T274*(-(T228*(-((-y(54))/(y(6)*y(6))*2*y(54)/y(6)))))-(-(T270*params(6)/y(3)*(-(params(46)*(-y(54))/(y(6)*y(6))))))/(T273*T273);
  g1(9,9)=T281*params(5)*params(6)/y(3)*T1026/T273-params(6)/y(3)*T1026/T273;
  g1(9,21)=T274;
  g1(9,54)=T281*(-(params(5)*params(6)/y(3)*T270*(-(params(46)*1/y(6)))))/(T273*T273)+T274*(-(T228*(-(2*y(54)/y(6)*1/y(6)))))-(-(T270*params(6)/y(3)*(-(params(46)*1/y(6)))))/(T273*T273);
  g1(10,1)=1-params(6);
  g1(10,7)=(-(y(22)*(-params(6))));
  g1(10,22)=(-(params(6)*(params(34)-y(7))));
  g1(11,2)=1-params(6);
  g1(11,8)=(-(y(23)*(-params(6))));
  g1(11,23)=(-(params(6)*(params(34)-y(8))));
  g1(12,3)=1-params(6);
  g1(12,9)=(-(y(24)*(-params(6))));
  g1(12,24)=(-(params(6)*(params(34)-y(9))));
  g1(13,11)=(-(params(8)*y(25)*y(38)));
  g1(13,12)=(-(params(9)*y(26)*y(39)));
  g1(13,13)=(-(params(7)*(-y(40))));
  g1(13,16)=(-(params(7)*(-y(43))));
  g1(13,25)=(-(y(11)*params(8)*y(38)));
  g1(13,26)=(-(y(12)*params(9)*y(39)));
  g1(13,38)=(-(y(11)*params(8)*y(25)));
  g1(13,39)=(-(y(12)*params(9)*y(26)));
  g1(13,40)=(-(params(7)*(-y(13))));
  g1(13,43)=(-(params(7)*(-y(16))));
  g1(14,11)=(-(params(8)*(-y(38))));
  g1(14,13)=(-(params(7)*y(40)/y(25)));
  g1(14,15)=(-(params(9)*y(27)*y(42)));
  g1(14,17)=(-(params(8)*(-y(44))));
  g1(14,25)=(-((-(y(13)*params(7)*y(40)))/(y(25)*y(25))));
  g1(14,27)=(-(y(15)*params(9)*y(42)));
  g1(14,38)=(-(params(8)*(-y(11))));
  g1(14,40)=(-(y(13)*params(7)/y(25)));
  g1(14,42)=(-(y(15)*params(9)*y(27)));
  g1(14,44)=(-(params(8)*(-y(17))));
  g1(15,12)=(-(params(9)*(-y(39))));
  g1(15,15)=(-(params(9)*(-y(42))));
  g1(15,16)=(-(params(7)*y(43)/y(26)));
  g1(15,17)=(-(params(8)*y(44)/y(27)));
  g1(15,26)=(-((-(y(16)*params(7)*y(43)))/(y(26)*y(26))));
  g1(15,27)=(-((-(y(17)*params(8)*y(44)))/(y(27)*y(27))));
  g1(15,39)=(-(params(9)*(-y(12))));
  g1(15,42)=(-(params(9)*(-y(15))));
  g1(15,43)=(-(y(16)*params(7)/y(26)));
  g1(15,44)=(-(y(17)*params(8)/y(27)));
  g1(16,1)=(-((T362*params(5)*T788-params(5)*T362*T788)/(T362*T362)));
  g1(16,7)=(-((T362*params(5)*1/y(1)*T970-params(5)*T362*1/y(1)*T970)/(T362*T362)));
  g1(16,46)=1;
  g1(17,2)=(-((T368*params(5)*T816-params(5)*T368*T816)/(T368*T368)));
  g1(17,8)=(-((T368*params(5)*1/y(2)*T998-params(5)*T368*1/y(2)*T998)/(T368*T368)));
  g1(17,47)=1;
  g1(18,3)=(-((T374*params(5)*T844-params(5)*T374*T844)/(T374*T374)));
  g1(18,9)=(-((T374*params(5)*1/y(3)*T1026-params(5)*T374*1/y(3)*T1026)/(T374*T374)));
  g1(18,48)=1;
  g1(19,10)=(params(37)*T41*(-y(13))/T381+y(10)*((-y(13))/T381*params(37)*T1059+params(37)*T41*(-((-y(13))*2*y(10)))/(T381*T381)))/y(13)+T389*params(37)*y(46)*T1059+T41*params(37)*y(46)*(-y(13))/(y(10)*y(10))/y(13)+T396*params(39)*T1067+params(39)*T59*((-y(16))/T381+y(10)*(-((-y(16))*2*y(10)))/(T381*T381))/y(16)+(y(10)*y(16)*params(39)*y(46)*T1067-y(16)*T59*params(39)*y(46))/(y(10)*y(10))/y(16)-(T409*params(25)*getPowerDeriv(y(10),T405,1)+T407*T1052*T1110);
  g1(19,13)=(y(13)*y(10)*((-y(13))/T381*params(37)*T1367+params(37)*T41*(-1)/T381)-y(10)*params(37)*T41*(-y(13))/T381)/(y(13)*y(13))+T389*params(37)*y(46)*T1367+T41*params(37)*y(46)*(y(13)*1/y(10)-T38)/(y(13)*y(13))-T407*T1110*T1360;
  g1(19,16)=T396*params(39)*T1671+params(39)*T59*(y(16)*y(10)*(-1)/T381-y(10)*(-y(16))/T381)/(y(16)*y(16))+(y(16)*(T59*params(39)*y(46)+y(16)*params(39)*y(46)*T1671)/y(10)-y(16)*T59*params(39)*y(46)/y(10))/(y(16)*y(16))-T407*T1110*T1659;
  g1(19,28)=1;
  g1(19,46)=params(37)*T41*T389+y(16)*params(39)*T59/y(10)/y(16);
  g1(20,10)=T427*params(37)*T1059+params(37)*T41*(y(10)*1/y(13)-y(10)/y(13))/(y(10)*y(10))+T432*params(37)*y(46)*T1059+T41*params(37)*y(46)*((-y(13))/y(10)+y(10)*y(13)/(y(10)*y(10)))/T422-T436*T1052*T1110;
  g1(20,13)=(y(13)*y(16)*params(38)*T1375/y(16)-y(16)*params(38)*T50/y(16))/(y(13)*y(13))+T423*params(38)*y(46)*T1375+T50*params(38)*y(46)*(T422*y(16)*(-1)/y(16)-y(16)*(-y(13))/y(16)*2*y(13))/(T422*T422)+T427*params(37)*T1367+params(37)*T41*(-y(10))/(y(13)*y(13))/y(10)+T432*params(37)*y(46)*T1367+T41*params(37)*y(46)*(T422*y(10)*(-1)/y(10)-y(10)*(-y(13))/y(10)*2*y(13))/(T422*T422)-(T436*T1110*T1360+T409*params(26)*params(21)*getPowerDeriv(params(21)*y(13),T405,1));
  g1(20,16)=(y(16)*(params(38)*T50+y(16)*params(38)*T1665)-y(16)*params(38)*T50)/(y(16)*y(16))/y(13)+T423*params(38)*y(46)*T1665+T50*params(38)*y(46)*((-y(13))/y(16)+y(16)*y(13)/(y(16)*y(16)))/T422-T436*T1110*T1659;
  g1(20,31)=1;
  g1(20,46)=params(38)*T50*T423+params(37)*T41*T432;
  g1(21,10)=(y(10)*(params(39)*T59+y(10)*params(39)*T1067)-y(10)*params(39)*T59)/(y(10)*y(10))/y(16)+T447*params(39)*y(46)*T1067+T59*params(39)*y(46)*((-y(16))/y(10)+y(10)*y(16)/(y(10)*y(10)))/T446-T460*T1052*T1110;
  g1(21,13)=T452*params(38)*T1375+params(38)*T50*(y(13)*y(16)*(-1)/T446-y(16)*(-y(13))/T446)/(y(13)*y(13))+(y(13)*(T50*params(38)*y(46)+y(13)*params(38)*y(46)*T1375)/y(16)-y(13)*T50*params(38)*y(46)/y(16))/(y(13)*y(13))-T460*T1110*T1360;
  g1(21,16)=(y(16)*y(10)*params(39)*T1671/y(10)-y(10)*params(39)*T59/y(10))/(y(16)*y(16))+T447*params(39)*y(46)*T1671+T59*params(39)*y(46)*(T446*y(10)*(-1)/y(10)-y(10)*(-y(16))/y(10)*2*y(16))/(T446*T446)+T452*params(38)*T1665+params(38)*T50*((-y(13))/T446+y(16)*(-((-y(13))*2*y(16)))/(T446*T446))/y(13)+(y(16)*y(13)*params(38)*y(46)*T1665-y(13)*T50*params(38)*y(46))/(y(16)*y(16))/y(13)-(T460*T1110*T1659+T409*params(27)*params(23)*getPowerDeriv(params(23)*y(16),T405,1));
  g1(21,34)=1;
  g1(21,46)=params(39)*T59*T447+y(13)*params(38)*T50/y(16)/y(13);
  g1(22,11)=(y(11)*y(14)*params(40)*T1159/y(14)-y(14)*params(40)*T93/y(14))/(y(11)*y(11))+T475*params(40)*y(47)*T1159+T93*params(40)*y(47)*(T474*y(14)*(-1)/y(14)-y(14)*(-y(11))/y(14)*2*y(11))/(T474*T474)+T480*params(42)*T1168+params(42)*T111*(-y(17))/(y(11)*y(11))/y(17)+T488*params(42)*y(47)*T1168+T111*params(42)*y(47)*((-y(17))/T474+y(11)*(-((-y(17))*2*y(11)))/(T474*T474))/y(17)-(T493*params(28)*params(19)*getPowerDeriv(params(19)*y(11),T405,1)+T492*T1151*T1216);
  g1(22,14)=(y(14)*(params(40)*T93+y(14)*params(40)*T1471)-y(14)*params(40)*T93)/(y(14)*y(14))/y(11)+T475*params(40)*y(47)*T1471+T93*params(40)*y(47)*((-y(11))/y(14)+y(14)*y(11)/(y(14)*y(14)))/T474-T492*T1216*T1465;
  g1(22,17)=T480*params(42)*T1769+params(42)*T111*(y(17)*1/y(11)-y(17)/y(11))/(y(17)*y(17))+T488*params(42)*y(47)*T1769+T111*params(42)*y(47)*(y(17)*y(11)*(-1)/T474-y(11)*(-y(17))/T474)/(y(17)*y(17))-T492*T1216*T1757;
  g1(22,29)=1;
  g1(22,47)=params(40)*T93*T475+params(42)*T111*T488;
  g1(23,11)=T511*params(40)*T1159+params(40)*T93*(y(11)*y(14)*(-1)/T498-y(14)*(-y(11))/T498)/(y(11)*y(11))+(y(11)*(T93*params(40)*y(47)+y(11)*params(40)*y(47)*T1159)/y(14)-y(11)*T93*params(40)*y(47)/y(14))/(y(11)*y(11))-T519*T1151*T1216;
  g1(23,14)=T501*params(41)*T1478+params(41)*T102*((-y(17))/T498+y(14)*(-((-y(17))*2*y(14)))/(T498*T498))/y(17)+T506*params(41)*y(47)*T1478+T102*params(41)*y(47)*(-y(17))/(y(14)*y(14))/y(17)+T511*params(40)*T1471+params(40)*T93*((-y(11))/T498+y(14)*(-((-y(11))*2*y(14)))/(T498*T498))/y(11)+(y(14)*y(11)*params(40)*y(47)*T1471-y(11)*T93*params(40)*y(47))/(y(14)*y(14))/y(11)-(T519*T1216*T1465+T493*params(29)*getPowerDeriv(y(14),T405,1));
  g1(23,17)=T501*params(41)*T1762+params(41)*T102*(y(17)*y(14)*(-1)/T498-y(14)*(-y(17))/T498)/(y(17)*y(17))+T506*params(41)*y(47)*T1762+T102*params(41)*y(47)*(y(17)*1/y(14)-T99)/(y(17)*y(17))-T519*T1216*T1757;
  g1(23,32)=1;
  g1(23,47)=params(41)*T102*T506+y(11)*params(40)*T93/y(14)/y(11);
  g1(24,11)=T526*params(42)*T1168+params(42)*T111*((-y(17))/y(11)+y(11)*y(17)/(y(11)*y(11)))/T525+y(17)*(T111*params(42)*y(47)+y(11)*params(42)*y(47)*T1168)/y(17)-T543*T1151*T1216;
  g1(24,14)=T534*params(41)*T1478+params(41)*T102*(y(14)*1/y(17)-y(14)/y(17))/(y(14)*y(14))+T539*params(41)*y(47)*T1478+T102*params(41)*y(47)*((-y(17))/y(14)+y(14)*y(17)/(y(14)*y(14)))/T525-T543*T1216*T1465;
  g1(24,17)=T526*params(42)*T1769+params(42)*T111*(T525*y(11)*(-1)/y(11)-y(11)*(-y(17))/y(11)*2*y(17))/(T525*T525)+y(11)*T111*params(42)*y(47)/y(17)+y(17)*(y(17)*y(11)*params(42)*y(47)*T1769-y(11)*T111*params(42)*y(47))/(y(17)*y(17))+T534*params(41)*T1762+params(41)*T102*(-y(14))/(y(17)*y(17))/y(14)+T539*params(41)*y(47)*T1762+T102*params(41)*y(47)*(T525*y(14)*(-1)/y(14)-y(14)*(-y(17))/y(14)*2*y(17))/(T525*T525)-(T543*T1216*T1757+T493*params(30)*params(24)*getPowerDeriv(params(24)*y(17),T405,1));
  g1(24,35)=1;
  g1(24,47)=y(17)*y(11)*params(42)*T111/y(17)+params(41)*T102*T539;
  g1(25,12)=(y(12)*y(15)*params(43)*T1263/y(15)-y(15)*params(43)*T145/y(15))/(y(12)*y(12))+T558*params(43)*y(47)*T1263+T145*params(43)*y(47)*(T557*y(15)*(-1)/y(15)-y(15)*(-y(12))/y(15)*2*y(12))/(T557*T557)+T160/y(18)*params(45)*T1272+params(45)*T163*1/y(18)/y(18)+T569*params(45)*y(47)*T1272+T163*params(45)*y(47)*(T557*y(18)*(-1)/y(18)-y(18)*(-y(12))/y(18)*2*y(12))/(T557*T557)-(T574*params(31)*params(20)*getPowerDeriv(params(20)*y(12),T405,1)+T573*T1255*T1319);
  g1(25,15)=(y(15)*(params(43)*T145+y(15)*params(43)*T1566)-y(15)*params(43)*T145)/(y(15)*y(15))/y(12)+T558*params(43)*y(47)*T1566+T145*params(43)*y(47)*((-y(12))/y(15)+y(15)*y(12)/(y(15)*y(15)))/T557-T573*T1319*T1560;
  g1(25,18)=T160/y(18)*params(45)*T1870+params(45)*T163*(y(18)*(-y(12))/(y(18)*y(18))-T160)/(y(18)*y(18))+T569*params(45)*y(47)*T1870+T163*params(45)*y(47)*((-y(12))/y(18)+y(18)*y(12)/(y(18)*y(18)))/T557-T573*T1319*T1857;
  g1(25,30)=1;
  g1(25,47)=params(43)*T145*T558+params(45)*T163*T569;
  g1(26,12)=T594*params(43)*T1263+params(43)*T145*(y(12)*y(15)*(-1)/T588-y(15)*(-y(12))/T588)/(y(12)*y(12))+(y(12)*(T145*params(43)*y(47)+y(12)*params(43)*y(47)*T1263)/y(15)-y(12)*T145*params(43)*y(47)/y(15))/(y(12)*y(12))-T602*T1255*T1319;
  g1(26,15)=(y(15)*y(18)*params(44)*T1572/y(18)-y(18)*params(44)*T154/y(18))/(y(15)*y(15))+T589*params(44)*y(47)*T1572+T154*params(44)*y(47)*(T588*y(18)*(-1)/y(18)-y(18)*(-y(15))/y(18)*2*y(15))/(T588*T588)+T594*params(43)*T1566+params(43)*T145*((-y(12))/T588+y(15)*(-((-y(12))*2*y(15)))/(T588*T588))/y(12)+(y(15)*y(12)*params(43)*y(47)*T1566-y(12)*T145*params(43)*y(47))/(y(15)*y(15))/y(12)-(T602*T1319*T1560+T574*params(32)*params(22)*getPowerDeriv(params(22)*y(15),T405,1));
  g1(26,18)=(y(18)*(params(44)*T154+y(18)*params(44)*T1863)-y(18)*params(44)*T154)/(y(18)*y(18))/y(15)+T589*params(44)*y(47)*T1863+T154*params(44)*y(47)*((-y(15))/y(18)+y(18)*y(15)/(y(18)*y(18)))/T588-T602*T1319*T1857;
  g1(26,33)=1;
  g1(26,47)=params(44)*T154*T589+y(12)*params(43)*T145/y(15)/y(12);
  g1(27,12)=T610*params(45)*T1272+params(45)*T163*((-y(18))/y(12)+y(12)*y(18)/(y(12)*y(12)))/T609+T613*params(45)*y(47)*T1272+T163*params(45)*y(47)*(y(12)*1/y(18)-T160)/(y(12)*y(12))-T626*T1255*T1319;
  g1(27,15)=T618*params(44)*T1572+params(44)*T154*(y(15)*y(18)*(-1)/T609-y(18)*(-y(15))/T609)/(y(15)*y(15))+(y(15)*(T154*params(44)*y(47)+y(15)*params(44)*y(47)*T1572)/y(18)-y(15)*T154*params(44)*y(47)/y(18))/(y(15)*y(15))-T626*T1319*T1560;
  g1(27,18)=T610*params(45)*T1870+params(45)*T163*(T609*y(12)*(-1)/y(12)-y(12)*(-y(18))/y(12)*2*y(18))/(T609*T609)+T613*params(45)*y(47)*T1870+T163*params(45)*y(47)*(-y(12))/(y(18)*y(18))/y(12)+T618*params(44)*T1863+params(44)*T154*((-y(15))/T609+y(18)*(-((-y(15))*2*y(18)))/(T609*T609))/y(15)+(y(18)*y(15)*params(44)*y(47)*T1863-y(15)*T154*params(44)*y(47))/(y(18)*y(18))/y(15)-(T626*T1319*T1857+T574*params(33)*getPowerDeriv(y(18),T405,1));
  g1(27,36)=1;
  g1(27,47)=params(45)*T163*T613+y(15)*params(44)*T154/y(18)/y(15);
  g1(28,4)=(-(T638*y(49)*y(37)*params(1)*getPowerDeriv(y(4),params(1)-1,1)));
  g1(28,7)=(-(T636*T986));
  g1(28,19)=1;
  g1(28,37)=(-(T638*T635*y(49)*params(1)));
  g1(28,49)=(-(T638*T635*y(37)*params(1)));
  g1(29,4)=(-(T645*y(49)*y(37)*(1-params(1))*T884));
  g1(29,7)=(-(y(49)*y(37)*(1-params(1))*T642*getPowerDeriv(y(7),(-params(1)),1)));
  g1(29,22)=1;
  g1(29,37)=(-(T645*T642*y(49)*(1-params(1))));
  g1(29,49)=(-(T645*T642*y(37)*(1-params(1))));
  g1(30,5)=(-(T654*params(1)*y(50)*y(41)*getPowerDeriv(y(5),params(1)-1,1)));
  g1(30,8)=(-(T653*T1014));
  g1(30,20)=1;
  g1(30,41)=(-(T654*T652*params(1)*y(50)));
  g1(30,50)=(-(T654*T652*params(1)*y(41)));
  g1(31,5)=(-(T660*(1-params(1))*y(50)*y(41)*T922));
  g1(31,8)=(-((1-params(1))*y(50)*y(41)*T658*getPowerDeriv(y(8),(-params(1)),1)));
  g1(31,23)=1;
  g1(31,41)=(-(T660*T658*(1-params(1))*y(50)));
  g1(31,50)=(-(T660*T658*(1-params(1))*y(41)));
  g1(32,6)=(-(T669*params(1)*y(51)*y(45)*getPowerDeriv(y(6),params(1)-1,1)));
  g1(32,9)=(-(T668*T1042));
  g1(32,21)=1;
  g1(32,45)=(-(T669*T667*params(1)*y(51)));
  g1(32,51)=(-(T669*T667*params(1)*y(45)));
  g1(33,6)=(-(T675*(1-params(1))*y(51)*y(45)*T960));
  g1(33,9)=(-((1-params(1))*y(51)*y(45)*T673*getPowerDeriv(y(9),(-params(1)),1)));
  g1(33,24)=1;
  g1(33,45)=(-(T675*T673*(1-params(1))*y(51)));
  g1(33,51)=(-(T675*T673*(1-params(1))*y(45)));
  g1(34,28)=(-1);
  g1(34,37)=1;
  g1(35,29)=1;
  g1(35,38)=(-((1+params(13))/params(19)));
  g1(36,30)=1;
  g1(36,39)=(-((1+params(14))/params(20)));
  g1(37,31)=1;
  g1(37,40)=(-((1+params(15))/params(21)));
  g1(38,32)=(-1);
  g1(38,41)=1;
  g1(39,33)=1;
  g1(39,42)=(-((1+params(16))/params(22)));
  g1(40,34)=1;
  g1(40,43)=(-((1+params(17))/params(23)));
  g1(41,35)=1;
  g1(41,44)=(-((1+params(16))/params(22)));
  g1(42,36)=(-1);
  g1(42,45)=1;
  g1(43,25)=(-y(38));
  g1(43,37)=1;
  g1(43,38)=(-y(25));
  g1(44,25)=(-y(41));
  g1(44,40)=1;
  g1(44,41)=(-y(25));
  g1(45,25)=(-y(44));
  g1(45,43)=1;
  g1(45,44)=(-y(25));
  g1(46,26)=(-y(39));
  g1(46,37)=1;
  g1(46,39)=(-y(26));
  g1(47,26)=(-y(42));
  g1(47,40)=1;
  g1(47,42)=(-y(26));
  g1(48,26)=(-y(45));
  g1(48,43)=1;
  g1(48,45)=(-y(26));
  g1(49,4)=(-(params(7)*y(49)*T638*T884));
  g1(49,7)=(-(params(7)*y(49)*T642*T986));
  g1(49,10)=params(7);
  g1(49,11)=params(8);
  g1(49,12)=params(9);
  g1(49,49)=(-(params(7)*T638*T642));
  g1(50,5)=(-(params(8)*y(50)*T654*T922));
  g1(50,8)=(-(params(8)*y(50)*T658*T1014));
  g1(50,13)=params(7);
  g1(50,14)=params(8);
  g1(50,15)=params(9);
  g1(50,50)=(-(params(8)*T654*T658));
  g1(51,6)=(-(params(9)*y(51)*T669*T960));
  g1(51,9)=(-(params(9)*y(51)*T673*T1042));
  g1(51,16)=params(7);
  g1(51,17)=params(8);
  g1(51,18)=params(9);
  g1(51,51)=(-(params(9)*T669*T673));
  g1(52,49)=1/y(49)-params(10)*1/y(49);
  g1(53,50)=1/y(50)-params(11)*1/y(50);
  g1(54,51)=1/y(51)-params(12)*1/y(51);
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],54,2916);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],54,157464);
end
end
end
end
