function [residual, g1, g2, g3] = BKK3C_fg2_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 54, 1);

%
% Model equations
%

T16 = (params(4)-1)/params(4);
T32 = params(25)*y(10)^T16+params(26)*(params(21)*y(13))^T16+params(27)*(params(23)*y(16))^T16;
T33 = params(4)/(params(4)-1);
T38 = y(13)/y(10);
T41 = y(10)*T38/y(13)-1;
T50 = y(16)*y(13)/y(16)/y(13)-1;
T59 = y(10)*y(16)/y(10)/y(16)-1;
T85 = params(28)*(params(19)*y(11))^T16+params(29)*y(14)^T16+params(30)*(params(24)*y(17))^T16;
T93 = y(14)*y(11)/y(14)/y(11)-1;
T99 = y(17)/y(14);
T102 = y(14)*T99/y(17)-1;
T111 = y(17)*y(11)/y(17)/y(11)-1;
T137 = params(31)*(params(20)*y(12))^T16+params(32)*(params(22)*y(15))^T16+params(33)*y(18)^T16;
T145 = y(15)*y(12)/y(15)/y(12)-1;
T154 = y(18)*y(15)/y(18)/y(15)-1;
T160 = y(12)/y(18);
T163 = y(18)*T160/y(12)-1;
T179 = (y(52)/y(4)-params(3))^2;
T191 = (y(53)/y(5)-params(3))^2;
T203 = (y(54)/y(6)-params(3))^2;
T211 = y(1)^params(6);
T216 = (params(34)-y(7))^(1-params(6));
T217 = T211*T216;
T220 = T217^(1-params(2));
T223 = 1-params(46)*(y(52)/y(4)-params(3));
T224 = params(5)*params(6)/y(1)*T220/T223;
T228 = params(46)/2;
T229 = params(3)^2;
T233 = 1+y(19)-params(3)-T228*(T229-(y(52)/y(4))^2);
T241 = y(2)^params(6);
T244 = (params(34)-y(8))^(1-params(6));
T245 = T241*T244;
T246 = T245^(1-params(2));
T249 = 1-params(46)*(y(53)/y(5)-params(3));
T250 = params(5)*params(6)/y(2)*T246/T249;
T257 = 1+y(20)-params(3)-T228*(T229-(y(53)/y(5))^2);
T265 = y(3)^params(6);
T268 = (params(34)-y(9))^(1-params(6));
T269 = T265*T268;
T270 = T269^(1-params(2));
T273 = 1-params(46)*(y(54)/y(6)-params(3));
T274 = params(5)*params(6)/y(3)*T270/T273;
T281 = 1+y(21)-params(3)-T228*(T229-(y(54)/y(6))^2);
T308 = T246*1/y(2);
T310 = T220*1/y(1);
T317 = T270*1/y(3);
T340 = y(10)^2;
T348 = T38/y(13);
T355 = y(10)*(-y(16))/T340/y(16);
T364 = (-1)/params(4);
T366 = params(25)*y(10)^T364;
T367 = 1/(params(4)-1);
T368 = T32^T367;
T381 = y(13)^2;
T382 = y(16)*(-y(13))/y(16)/T381;
T386 = y(10)/y(13)/y(10);
T391 = y(10)*(-y(13))/y(10)/T381;
T395 = params(26)*(params(21)*y(13))^T364;
T405 = y(16)^2;
T406 = y(10)*(-y(16))/y(10)/T405;
T411 = y(16)*(-y(13))/T405/y(13);
T419 = params(27)*(params(23)*y(16))^T364;
T433 = y(11)^2;
T434 = y(14)*(-y(11))/y(14)/T433;
T439 = y(17)/y(11)/y(17);
T447 = y(11)*(-y(17))/T433/y(17);
T451 = params(28)*(params(19)*y(11))^T364;
T452 = T85^T367;
T457 = y(14)^2;
T460 = y(14)*(-y(17))/T457/y(17);
T465 = T99/y(17);
T470 = y(14)*(-y(11))/T457/y(11);
T478 = params(29)*y(14)^T364;
T484 = y(17)^2;
T485 = y(11)*(-y(17))/y(11)/T484;
T493 = y(14)/y(17)/y(14);
T498 = y(14)*(-y(17))/y(14)/T484;
T502 = params(30)*(params(24)*y(17))^T364;
T516 = y(12)^2;
T517 = y(15)*(-y(12))/y(15)/T516;
T528 = y(18)*(-y(12))/y(18)/T516;
T532 = params(31)*(params(20)*y(12))^T364;
T533 = T137^T367;
T547 = y(15)^2;
T548 = y(18)*(-y(15))/y(18)/T547;
T553 = y(15)*(-y(12))/T547/y(12);
T561 = params(32)*(params(22)*y(15))^T364;
T568 = y(18)^2;
T569 = y(12)*(-y(18))/y(12)/T568;
T572 = T160/y(12);
T577 = y(18)*(-y(15))/T568/y(15);
T585 = params(33)*y(18)^T364;
T594 = y(4)^(params(1)-1);
T595 = y(49)*y(37)*params(1)*T594;
T597 = y(7)^(1-params(1));
T601 = y(4)^params(1);
T604 = y(7)^(-params(1));
T611 = y(5)^(params(1)-1);
T612 = params(1)*y(50)*y(41)*T611;
T613 = y(8)^(1-params(1));
T617 = y(5)^params(1);
T619 = y(8)^(-params(1));
T626 = y(6)^(params(1)-1);
T627 = params(1)*y(51)*y(45)*T626;
T628 = y(9)^(1-params(1));
T632 = y(6)^params(1);
T634 = y(9)^(-params(1));
residual(1) = (-y(1))-y(52)+T32^T33-params(37)/2*T41^2-params(38)/2*T50^2-params(39)/2*T59^2;
residual(2) = (-y(2))-y(53)+T85^T33-params(40)/2*T93^2-params(41)/2*T102^2-params(42)/2*T111^2;
residual(3) = (-y(3))-y(54)+T137^T33-params(43)/2*T145^2-params(44)/2*T154^2-params(45)/2*T163^2;
residual(4) = y(52)+(-y(4))+y(4)*(1-params(3))-y(4)*params(46)*T179;
residual(5) = y(53)+(-y(5))+(1-params(3))*y(5)-params(46)*y(5)*T191;
residual(6) = y(54)+(-y(6))+(1-params(3))*y(6)-params(46)*y(6)*T203;
residual(7) = T224*T233-T220*params(6)/y(1)/T223;
residual(8) = T250*T257-T246*params(6)/y(2)/T249;
residual(9) = T274*T281-T270*params(6)/y(3)/T273;
residual(10) = y(1)*(1-params(6))-params(6)*(params(34)-y(7))*y(22);
residual(11) = y(2)*(1-params(6))-params(6)*(params(34)-y(8))*y(23);
residual(12) = y(3)*(1-params(6))-params(6)*(params(34)-y(9))*y(24);
lhs =y(25);
rhs =T308/T310*params(35);
residual(13)= lhs-rhs;
lhs =y(26);
rhs =T317/T310*params(36);
residual(14)= lhs-rhs;
lhs =y(27);
rhs =y(26)/y(25);
residual(15)= lhs-rhs;
lhs =y(46);
rhs =params(5)*T310/T310;
residual(16)= lhs-rhs;
lhs =y(47);
rhs =params(5)*T308/T308;
residual(17)= lhs-rhs;
lhs =y(48);
rhs =params(5)*T317/T317;
residual(18)= lhs-rhs;
lhs =y(28)+y(10)*params(37)*T41*(-y(13))/T340/y(13)+T41*params(37)*y(46)*T348+params(39)*T59*T355+y(16)*T59*params(39)*y(46)/y(10)/y(16);
rhs =T366*T368;
residual(19)= lhs-rhs;
lhs =y(31)+y(16)*params(38)*T50/y(16)/y(13)+T50*params(38)*y(46)*T382+params(37)*T41*T386+T41*params(37)*y(46)*T391;
rhs =T368*T395;
residual(20)= lhs-rhs;
lhs =y(34)+y(10)*params(39)*T59/y(10)/y(16)+T59*params(39)*y(46)*T406+params(38)*T50*T411+y(13)*T50*params(38)*y(46)/y(16)/y(13);
rhs =T368*T419;
residual(21)= lhs-rhs;
lhs =y(29)+y(14)*params(40)*T93/y(14)/y(11)+T93*params(40)*y(47)*T434+params(42)*T111*T439+T111*params(42)*y(47)*T447;
rhs =T451*T452;
residual(22)= lhs-rhs;
lhs =y(32)+params(41)*T102*T460+T102*params(41)*y(47)*T465+params(40)*T93*T470+y(11)*T93*params(40)*y(47)/y(14)/y(11);
rhs =T452*T478;
residual(23)= lhs-rhs;
lhs =y(35)+params(42)*T111*T485+y(17)*y(11)*T111*params(42)*y(47)/y(17)+params(41)*T102*T493+T102*params(41)*y(47)*T498;
rhs =T452*T502;
residual(24)= lhs-rhs;
lhs =y(30)+y(15)*params(43)*T145/y(15)/y(12)+T145*params(43)*y(47)*T517+params(45)*T163*T160/y(18)+T163*params(45)*y(47)*T528;
rhs =T532*T533;
residual(25)= lhs-rhs;
lhs =y(33)+y(18)*params(44)*T154/y(18)/y(15)+T154*params(44)*y(47)*T548+params(43)*T145*T553+y(12)*T145*params(43)*y(47)/y(15)/y(12);
rhs =T533*T561;
residual(26)= lhs-rhs;
lhs =y(36)+params(45)*T163*T569+T163*params(45)*y(47)*T572+params(44)*T154*T577+y(15)*T154*params(44)*y(47)/y(18)/y(15);
rhs =T533*T585;
residual(27)= lhs-rhs;
lhs =y(19);
rhs =T595*T597;
residual(28)= lhs-rhs;
lhs =y(22);
rhs =y(49)*y(37)*(1-params(1))*T601*T604;
residual(29)= lhs-rhs;
lhs =y(20);
rhs =T612*T613;
residual(30)= lhs-rhs;
lhs =y(23);
rhs =(1-params(1))*y(50)*y(41)*T617*T619;
residual(31)= lhs-rhs;
lhs =y(21);
rhs =T627*T628;
residual(32)= lhs-rhs;
lhs =y(24);
rhs =(1-params(1))*y(51)*y(45)*T632*T634;
residual(33)= lhs-rhs;
lhs =y(37);
rhs =y(28);
residual(34)= lhs-rhs;
lhs =y(29);
rhs =(1+params(13))*y(38)/params(19);
residual(35)= lhs-rhs;
lhs =y(30);
rhs =(1+params(14))*y(39)/params(20);
residual(36)= lhs-rhs;
lhs =y(31);
rhs =(1+params(15))*y(40)/params(21);
residual(37)= lhs-rhs;
lhs =y(41);
rhs =y(32);
residual(38)= lhs-rhs;
lhs =y(33);
rhs =(1+params(16))*y(42)/params(22);
residual(39)= lhs-rhs;
lhs =y(34);
rhs =(1+params(17))*y(43)/params(23);
residual(40)= lhs-rhs;
lhs =y(35);
rhs =(1+params(16))*y(44)/params(22);
residual(41)= lhs-rhs;
lhs =y(45);
rhs =y(36);
residual(42)= lhs-rhs;
lhs =y(37);
rhs =y(25)*y(38);
residual(43)= lhs-rhs;
lhs =y(40);
rhs =y(25)*y(41);
residual(44)= lhs-rhs;
lhs =y(43);
rhs =y(25)*y(44);
residual(45)= lhs-rhs;
lhs =y(37);
rhs =y(26)*y(39);
residual(46)= lhs-rhs;
lhs =y(40);
rhs =y(26)*y(42);
residual(47)= lhs-rhs;
lhs =y(43);
rhs =y(26)*y(45);
residual(48)= lhs-rhs;
lhs =y(10)*params(7)+y(11)*params(8)+y(12)*params(9);
rhs =y(49)*params(7)*T597*T601;
residual(49)= lhs-rhs;
lhs =y(13)*params(7)+y(14)*params(8)+y(15)*params(9);
rhs =y(50)*params(8)*T613*T617;
residual(50)= lhs-rhs;
lhs =y(16)*params(7)+y(17)*params(8)+y(18)*params(9);
rhs =y(51)*params(9)*T628*T632;
residual(51)= lhs-rhs;
lhs =log(y(49));
rhs =log(y(49))*params(10)+x(1);
residual(52)= lhs-rhs;
lhs =log(y(50));
rhs =log(y(50))*params(11)+x(2);
residual(53)= lhs-rhs;
lhs =log(y(51));
rhs =log(y(51))*params(12)+x(3);
residual(54)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(54, 54);

  %
  % Jacobian matrix
  %

T739 = getPowerDeriv(T217,1-params(2),1);
T740 = T216*getPowerDeriv(y(1),params(6),1)*T739;
T756 = 1/y(1)*T740+T220*(-1)/(y(1)*y(1));
T778 = getPowerDeriv(T245,1-params(2),1);
T779 = T244*getPowerDeriv(y(2),params(6),1)*T778;
T794 = 1/y(2)*T779+T246*(-1)/(y(2)*y(2));
T809 = getPowerDeriv(T269,1-params(2),1);
T810 = T268*getPowerDeriv(y(3),params(6),1)*T809;
T825 = 1/y(3)*T810+T270*(-1)/(y(3)*y(3));
T868 = getPowerDeriv(y(4),params(1),1);
T906 = getPowerDeriv(y(5),params(1),1);
T944 = getPowerDeriv(y(6),params(1),1);
T954 = T739*T211*(-(getPowerDeriv(params(34)-y(7),1-params(6),1)));
T963 = 1/y(1)*T954;
T980 = getPowerDeriv(y(7),1-params(1),1);
T992 = T778*T241*(-(getPowerDeriv(params(34)-y(8),1-params(6),1)));
T1011 = getPowerDeriv(y(8),1-params(1),1);
T1023 = T809*T265*(-(getPowerDeriv(params(34)-y(9),1-params(6),1)));
T1042 = getPowerDeriv(y(9),1-params(1),1);
T1052 = params(25)*getPowerDeriv(y(10),T16,1);
T1053 = getPowerDeriv(T32,T33,1);
T1059 = (T38+y(10)*(-y(13))/(y(10)*y(10)))/y(13);
T1067 = (y(16)/y(10)+y(10)*(-y(16))/(y(10)*y(10)))/y(16);
T1110 = getPowerDeriv(T32,T367,1);
T1151 = params(28)*params(19)*getPowerDeriv(params(19)*y(11),T16,1);
T1152 = getPowerDeriv(T85,T33,1);
T1159 = (y(11)*y(14)*1/y(14)-y(14)*y(11)/y(14))/(y(11)*y(11));
T1168 = (y(11)*y(17)*1/y(17)-y(17)*y(11)/y(17))/(y(11)*y(11));
T1213 = getPowerDeriv(T85,T367,1);
T1252 = params(31)*params(20)*getPowerDeriv(params(20)*y(12),T16,1);
T1253 = getPowerDeriv(T137,T33,1);
T1260 = (y(12)*y(15)*1/y(15)-y(15)*y(12)/y(15))/(y(12)*y(12));
T1269 = (y(12)*y(18)*1/y(18)-y(18)*T160)/(y(12)*y(12));
T1313 = getPowerDeriv(T137,T367,1);
T1354 = params(26)*params(21)*getPowerDeriv(params(21)*y(13),T16,1);
T1361 = (y(13)*y(10)*1/y(10)-y(10)*T38)/(y(13)*y(13));
T1369 = (y(13)*y(16)*1/y(16)-y(16)*y(13)/y(16))/(y(13)*y(13));
T1455 = params(29)*getPowerDeriv(y(14),T16,1);
T1461 = (y(11)/y(14)+y(14)*(-y(11))/(y(14)*y(14)))/y(11);
T1468 = (T99+y(14)*(-y(17))/(y(14)*y(14)))/y(17);
T1550 = params(32)*params(22)*getPowerDeriv(params(22)*y(15),T16,1);
T1556 = (y(12)/y(15)+y(15)*(-y(12))/(y(15)*y(15)))/y(12);
T1562 = (y(15)*y(18)*1/y(18)-y(18)*y(15)/y(18))/(y(15)*y(15));
T1645 = params(27)*params(23)*getPowerDeriv(params(23)*y(16),T16,1);
T1651 = (y(13)/y(16)+y(16)*(-y(13))/(y(16)*y(16)))/y(13);
T1657 = (y(16)*y(10)*1/y(10)-y(10)*y(16)/y(10))/(y(16)*y(16));
T1738 = params(30)*params(24)*getPowerDeriv(params(24)*y(17),T16,1);
T1743 = (y(17)*y(14)*1/y(14)-y(14)*T99)/(y(17)*y(17));
T1750 = (y(11)/y(17)+y(17)*(-y(11))/(y(17)*y(17)))/y(11);
T1833 = params(33)*getPowerDeriv(y(18),T16,1);
T1839 = (y(15)/y(18)+y(18)*(-y(15))/(y(18)*y(18)))/y(15);
T1846 = (T160+y(18)*(-y(12))/(y(18)*y(18)))/y(12);
  g1(1,1)=(-1);
  g1(1,10)=T1052*T1053-params(37)/2*T1059*2*T41-params(39)/2*T1067*2*T59;
  g1(1,13)=T1053*T1354-params(37)/2*2*T41*T1361-params(38)/2*T1369*2*T50;
  g1(1,16)=T1053*T1645-params(38)/2*2*T50*T1651-params(39)/2*2*T59*T1657;
  g1(1,52)=(-1);
  g1(2,2)=(-1);
  g1(2,11)=T1151*T1152-params(40)/2*T1159*2*T93-params(42)/2*T1168*2*T111;
  g1(2,14)=T1152*T1455-params(40)/2*2*T93*T1461-params(41)/2*T1468*2*T102;
  g1(2,17)=T1152*T1738-params(41)/2*2*T102*T1743-params(42)/2*2*T111*T1750;
  g1(2,53)=(-1);
  g1(3,3)=(-1);
  g1(3,12)=T1252*T1253-params(43)/2*T1260*2*T145-params(45)/2*T1269*2*T163;
  g1(3,15)=T1253*T1550-params(43)/2*2*T145*T1556-params(44)/2*T1562*2*T154;
  g1(3,18)=T1253*T1833-params(44)/2*2*T154*T1839-params(45)/2*2*T163*T1846;
  g1(3,54)=(-1);
  g1(4,4)=(-1)+1-params(3)-(params(46)*T179+y(4)*params(46)*(-y(52))/(y(4)*y(4))*2*(y(52)/y(4)-params(3)));
  g1(4,52)=1-y(4)*params(46)*2*(y(52)/y(4)-params(3))*1/y(4);
  g1(5,5)=(-1)+1-params(3)-(params(46)*T191+params(46)*y(5)*(-y(53))/(y(5)*y(5))*2*(y(53)/y(5)-params(3)));
  g1(5,53)=1-params(46)*y(5)*2*(y(53)/y(5)-params(3))*1/y(5);
  g1(6,6)=(-1)+1-params(3)-(params(46)*T203+params(46)*y(6)*(-y(54))/(y(6)*y(6))*2*(y(54)/y(6)-params(3)));
  g1(6,54)=1-params(46)*y(6)*2*(y(54)/y(6)-params(3))*1/y(6);
  g1(7,1)=T233*(T220*(-(params(5)*params(6)))/(y(1)*y(1))+params(5)*params(6)/y(1)*T740)/T223-(params(6)/y(1)*T740+T220*(-params(6))/(y(1)*y(1)))/T223;
  g1(7,4)=T233*(-(params(5)*params(6)/y(1)*T220*(-(params(46)*(-y(52))/(y(4)*y(4))))))/(T223*T223)+T224*(-(T228*(-((-y(52))/(y(4)*y(4))*2*y(52)/y(4)))))-(-(T220*params(6)/y(1)*(-(params(46)*(-y(52))/(y(4)*y(4))))))/(T223*T223);
  g1(7,7)=T233*params(5)*params(6)/y(1)*T954/T223-params(6)/y(1)*T954/T223;
  g1(7,19)=T224;
  g1(7,52)=T233*(-(params(5)*params(6)/y(1)*T220*(-(params(46)*1/y(4)))))/(T223*T223)+T224*(-(T228*(-(2*y(52)/y(4)*1/y(4)))))-(-(T220*params(6)/y(1)*(-(params(46)*1/y(4)))))/(T223*T223);
  g1(8,2)=T257*(T246*(-(params(5)*params(6)))/(y(2)*y(2))+params(5)*params(6)/y(2)*T779)/T249-(params(6)/y(2)*T779+T246*(-params(6))/(y(2)*y(2)))/T249;
  g1(8,5)=T257*(-(params(5)*params(6)/y(2)*T246*(-(params(46)*(-y(53))/(y(5)*y(5))))))/(T249*T249)+T250*(-(T228*(-((-y(53))/(y(5)*y(5))*2*y(53)/y(5)))))-(-(T246*params(6)/y(2)*(-(params(46)*(-y(53))/(y(5)*y(5))))))/(T249*T249);
  g1(8,8)=T257*params(5)*params(6)/y(2)*T992/T249-params(6)/y(2)*T992/T249;
  g1(8,20)=T250;
  g1(8,53)=T257*(-(params(5)*params(6)/y(2)*T246*(-(params(46)*1/y(5)))))/(T249*T249)+T250*(-(T228*(-(2*y(53)/y(5)*1/y(5)))))-(-(T246*params(6)/y(2)*(-(params(46)*1/y(5)))))/(T249*T249);
  g1(9,3)=T281*(T270*(-(params(5)*params(6)))/(y(3)*y(3))+params(5)*params(6)/y(3)*T810)/T273-(params(6)/y(3)*T810+T270*(-params(6))/(y(3)*y(3)))/T273;
  g1(9,6)=T281*(-(params(5)*params(6)/y(3)*T270*(-(params(46)*(-y(54))/(y(6)*y(6))))))/(T273*T273)+T274*(-(T228*(-((-y(54))/(y(6)*y(6))*2*y(54)/y(6)))))-(-(T270*params(6)/y(3)*(-(params(46)*(-y(54))/(y(6)*y(6))))))/(T273*T273);
  g1(9,9)=T281*params(5)*params(6)/y(3)*T1023/T273-params(6)/y(3)*T1023/T273;
  g1(9,21)=T274;
  g1(9,54)=T281*(-(params(5)*params(6)/y(3)*T270*(-(params(46)*1/y(6)))))/(T273*T273)+T274*(-(T228*(-(2*y(54)/y(6)*1/y(6)))))-(-(T270*params(6)/y(3)*(-(params(46)*1/y(6)))))/(T273*T273);
  g1(10,1)=1-params(6);
  g1(10,7)=(-(y(22)*(-params(6))));
  g1(10,22)=(-(params(6)*(params(34)-y(7))));
  g1(11,2)=1-params(6);
  g1(11,8)=(-(y(23)*(-params(6))));
  g1(11,23)=(-(params(6)*(params(34)-y(8))));
  g1(12,3)=1-params(6);
  g1(12,9)=(-(y(24)*(-params(6))));
  g1(12,24)=(-(params(6)*(params(34)-y(9))));
  g1(13,1)=(-(params(35)*(-(T308*T756))/(T310*T310)));
  g1(13,2)=(-(params(35)*T794/T310));
  g1(13,7)=(-(params(35)*(-(T308*T963))/(T310*T310)));
  g1(13,8)=(-(params(35)*1/y(2)*T992/T310));
  g1(13,25)=1;
  g1(14,1)=(-(params(36)*(-(T317*T756))/(T310*T310)));
  g1(14,3)=(-(params(36)*T825/T310));
  g1(14,7)=(-(params(36)*(-(T317*T963))/(T310*T310)));
  g1(14,9)=(-(params(36)*1/y(3)*T1023/T310));
  g1(14,26)=1;
  g1(15,25)=(-((-y(26))/(y(25)*y(25))));
  g1(15,26)=(-(1/y(25)));
  g1(15,27)=1;
  g1(16,1)=(-((T310*params(5)*T756-params(5)*T310*T756)/(T310*T310)));
  g1(16,7)=(-((T310*params(5)*T963-params(5)*T310*T963)/(T310*T310)));
  g1(16,46)=1;
  g1(17,2)=(-((T308*params(5)*T794-params(5)*T308*T794)/(T308*T308)));
  g1(17,8)=(-((T308*params(5)*1/y(2)*T992-params(5)*T308*1/y(2)*T992)/(T308*T308)));
  g1(17,47)=1;
  g1(18,3)=(-((T317*params(5)*T825-params(5)*T317*T825)/(T317*T317)));
  g1(18,9)=(-((T317*params(5)*1/y(3)*T1023-params(5)*T317*1/y(3)*T1023)/(T317*T317)));
  g1(18,48)=1;
  g1(19,10)=(params(37)*T41*(-y(13))/T340+y(10)*((-y(13))/T340*params(37)*T1059+params(37)*T41*(-((-y(13))*2*y(10)))/(T340*T340)))/y(13)+T348*params(37)*y(46)*T1059+T41*params(37)*y(46)*(-y(13))/(y(10)*y(10))/y(13)+T355*params(39)*T1067+params(39)*T59*((-y(16))/T340+y(10)*(-((-y(16))*2*y(10)))/(T340*T340))/y(16)+(y(10)*y(16)*params(39)*y(46)*T1067-y(16)*T59*params(39)*y(46))/(y(10)*y(10))/y(16)-(T368*params(25)*getPowerDeriv(y(10),T364,1)+T366*T1052*T1110);
  g1(19,13)=(y(13)*y(10)*((-y(13))/T340*params(37)*T1361+params(37)*T41*(-1)/T340)-y(10)*params(37)*T41*(-y(13))/T340)/(y(13)*y(13))+T348*params(37)*y(46)*T1361+T41*params(37)*y(46)*(y(13)*1/y(10)-T38)/(y(13)*y(13))-T366*T1110*T1354;
  g1(19,16)=T355*params(39)*T1657+params(39)*T59*(y(16)*y(10)*(-1)/T340-y(10)*(-y(16))/T340)/(y(16)*y(16))+(y(16)*(T59*params(39)*y(46)+y(16)*params(39)*y(46)*T1657)/y(10)-y(16)*T59*params(39)*y(46)/y(10))/(y(16)*y(16))-T366*T1110*T1645;
  g1(19,28)=1;
  g1(19,46)=params(37)*T41*T348+y(16)*params(39)*T59/y(10)/y(16);
  g1(20,10)=T386*params(37)*T1059+params(37)*T41*(y(10)*1/y(13)-y(10)/y(13))/(y(10)*y(10))+T391*params(37)*y(46)*T1059+T41*params(37)*y(46)*((-y(13))/y(10)+y(10)*y(13)/(y(10)*y(10)))/T381-T395*T1052*T1110;
  g1(20,13)=(y(13)*y(16)*params(38)*T1369/y(16)-y(16)*params(38)*T50/y(16))/(y(13)*y(13))+T382*params(38)*y(46)*T1369+T50*params(38)*y(46)*(T381*y(16)*(-1)/y(16)-y(16)*(-y(13))/y(16)*2*y(13))/(T381*T381)+T386*params(37)*T1361+params(37)*T41*(-y(10))/(y(13)*y(13))/y(10)+T391*params(37)*y(46)*T1361+T41*params(37)*y(46)*(T381*y(10)*(-1)/y(10)-y(10)*(-y(13))/y(10)*2*y(13))/(T381*T381)-(T395*T1110*T1354+T368*params(26)*params(21)*getPowerDeriv(params(21)*y(13),T364,1));
  g1(20,16)=(y(16)*(params(38)*T50+y(16)*params(38)*T1651)-y(16)*params(38)*T50)/(y(16)*y(16))/y(13)+T382*params(38)*y(46)*T1651+T50*params(38)*y(46)*((-y(13))/y(16)+y(16)*y(13)/(y(16)*y(16)))/T381-T395*T1110*T1645;
  g1(20,31)=1;
  g1(20,46)=params(38)*T50*T382+params(37)*T41*T391;
  g1(21,10)=(y(10)*(params(39)*T59+y(10)*params(39)*T1067)-y(10)*params(39)*T59)/(y(10)*y(10))/y(16)+T406*params(39)*y(46)*T1067+T59*params(39)*y(46)*((-y(16))/y(10)+y(10)*y(16)/(y(10)*y(10)))/T405-T419*T1052*T1110;
  g1(21,13)=T411*params(38)*T1369+params(38)*T50*(y(13)*y(16)*(-1)/T405-y(16)*(-y(13))/T405)/(y(13)*y(13))+(y(13)*(T50*params(38)*y(46)+y(13)*params(38)*y(46)*T1369)/y(16)-y(13)*T50*params(38)*y(46)/y(16))/(y(13)*y(13))-T419*T1110*T1354;
  g1(21,16)=(y(16)*y(10)*params(39)*T1657/y(10)-y(10)*params(39)*T59/y(10))/(y(16)*y(16))+T406*params(39)*y(46)*T1657+T59*params(39)*y(46)*(T405*y(10)*(-1)/y(10)-y(10)*(-y(16))/y(10)*2*y(16))/(T405*T405)+T411*params(38)*T1651+params(38)*T50*((-y(13))/T405+y(16)*(-((-y(13))*2*y(16)))/(T405*T405))/y(13)+(y(16)*y(13)*params(38)*y(46)*T1651-y(13)*T50*params(38)*y(46))/(y(16)*y(16))/y(13)-(T419*T1110*T1645+T368*params(27)*params(23)*getPowerDeriv(params(23)*y(16),T364,1));
  g1(21,34)=1;
  g1(21,46)=params(39)*T59*T406+y(13)*params(38)*T50/y(16)/y(13);
  g1(22,11)=(y(11)*y(14)*params(40)*T1159/y(14)-y(14)*params(40)*T93/y(14))/(y(11)*y(11))+T434*params(40)*y(47)*T1159+T93*params(40)*y(47)*(T433*y(14)*(-1)/y(14)-y(14)*(-y(11))/y(14)*2*y(11))/(T433*T433)+T439*params(42)*T1168+params(42)*T111*(-y(17))/(y(11)*y(11))/y(17)+T447*params(42)*y(47)*T1168+T111*params(42)*y(47)*((-y(17))/T433+y(11)*(-((-y(17))*2*y(11)))/(T433*T433))/y(17)-(T452*params(28)*params(19)*getPowerDeriv(params(19)*y(11),T364,1)+T451*T1151*T1213);
  g1(22,14)=(y(14)*(params(40)*T93+y(14)*params(40)*T1461)-y(14)*params(40)*T93)/(y(14)*y(14))/y(11)+T434*params(40)*y(47)*T1461+T93*params(40)*y(47)*((-y(11))/y(14)+y(14)*y(11)/(y(14)*y(14)))/T433-T451*T1213*T1455;
  g1(22,17)=T439*params(42)*T1750+params(42)*T111*(y(17)*1/y(11)-y(17)/y(11))/(y(17)*y(17))+T447*params(42)*y(47)*T1750+T111*params(42)*y(47)*(y(17)*y(11)*(-1)/T433-y(11)*(-y(17))/T433)/(y(17)*y(17))-T451*T1213*T1738;
  g1(22,29)=1;
  g1(22,47)=params(40)*T93*T434+params(42)*T111*T447;
  g1(23,11)=T470*params(40)*T1159+params(40)*T93*(y(11)*y(14)*(-1)/T457-y(14)*(-y(11))/T457)/(y(11)*y(11))+(y(11)*(T93*params(40)*y(47)+y(11)*params(40)*y(47)*T1159)/y(14)-y(11)*T93*params(40)*y(47)/y(14))/(y(11)*y(11))-T478*T1151*T1213;
  g1(23,14)=T460*params(41)*T1468+params(41)*T102*((-y(17))/T457+y(14)*(-((-y(17))*2*y(14)))/(T457*T457))/y(17)+T465*params(41)*y(47)*T1468+T102*params(41)*y(47)*(-y(17))/(y(14)*y(14))/y(17)+T470*params(40)*T1461+params(40)*T93*((-y(11))/T457+y(14)*(-((-y(11))*2*y(14)))/(T457*T457))/y(11)+(y(14)*y(11)*params(40)*y(47)*T1461-y(11)*T93*params(40)*y(47))/(y(14)*y(14))/y(11)-(T478*T1213*T1455+T452*params(29)*getPowerDeriv(y(14),T364,1));
  g1(23,17)=T460*params(41)*T1743+params(41)*T102*(y(17)*y(14)*(-1)/T457-y(14)*(-y(17))/T457)/(y(17)*y(17))+T465*params(41)*y(47)*T1743+T102*params(41)*y(47)*(y(17)*1/y(14)-T99)/(y(17)*y(17))-T478*T1213*T1738;
  g1(23,32)=1;
  g1(23,47)=params(41)*T102*T465+y(11)*params(40)*T93/y(14)/y(11);
  g1(24,11)=T485*params(42)*T1168+params(42)*T111*((-y(17))/y(11)+y(11)*y(17)/(y(11)*y(11)))/T484+y(17)*(T111*params(42)*y(47)+y(11)*params(42)*y(47)*T1168)/y(17)-T502*T1151*T1213;
  g1(24,14)=T493*params(41)*T1468+params(41)*T102*(y(14)*1/y(17)-y(14)/y(17))/(y(14)*y(14))+T498*params(41)*y(47)*T1468+T102*params(41)*y(47)*((-y(17))/y(14)+y(14)*y(17)/(y(14)*y(14)))/T484-T502*T1213*T1455;
  g1(24,17)=T485*params(42)*T1750+params(42)*T111*(T484*y(11)*(-1)/y(11)-y(11)*(-y(17))/y(11)*2*y(17))/(T484*T484)+y(11)*T111*params(42)*y(47)/y(17)+y(17)*(y(17)*y(11)*params(42)*y(47)*T1750-y(11)*T111*params(42)*y(47))/(y(17)*y(17))+T493*params(41)*T1743+params(41)*T102*(-y(14))/(y(17)*y(17))/y(14)+T498*params(41)*y(47)*T1743+T102*params(41)*y(47)*(T484*y(14)*(-1)/y(14)-y(14)*(-y(17))/y(14)*2*y(17))/(T484*T484)-(T502*T1213*T1738+T452*params(30)*params(24)*getPowerDeriv(params(24)*y(17),T364,1));
  g1(24,35)=1;
  g1(24,47)=y(17)*y(11)*params(42)*T111/y(17)+params(41)*T102*T498;
  g1(25,12)=(y(12)*y(15)*params(43)*T1260/y(15)-y(15)*params(43)*T145/y(15))/(y(12)*y(12))+T517*params(43)*y(47)*T1260+T145*params(43)*y(47)*(T516*y(15)*(-1)/y(15)-y(15)*(-y(12))/y(15)*2*y(12))/(T516*T516)+T160/y(18)*params(45)*T1269+params(45)*T163*1/y(18)/y(18)+T528*params(45)*y(47)*T1269+T163*params(45)*y(47)*(T516*y(18)*(-1)/y(18)-y(18)*(-y(12))/y(18)*2*y(12))/(T516*T516)-(T533*params(31)*params(20)*getPowerDeriv(params(20)*y(12),T364,1)+T532*T1252*T1313);
  g1(25,15)=(y(15)*(params(43)*T145+y(15)*params(43)*T1556)-y(15)*params(43)*T145)/(y(15)*y(15))/y(12)+T517*params(43)*y(47)*T1556+T145*params(43)*y(47)*((-y(12))/y(15)+y(15)*y(12)/(y(15)*y(15)))/T516-T532*T1313*T1550;
  g1(25,18)=T160/y(18)*params(45)*T1846+params(45)*T163*(y(18)*(-y(12))/(y(18)*y(18))-T160)/(y(18)*y(18))+T528*params(45)*y(47)*T1846+T163*params(45)*y(47)*((-y(12))/y(18)+y(18)*y(12)/(y(18)*y(18)))/T516-T532*T1313*T1833;
  g1(25,30)=1;
  g1(25,47)=params(43)*T145*T517+params(45)*T163*T528;
  g1(26,12)=T553*params(43)*T1260+params(43)*T145*(y(12)*y(15)*(-1)/T547-y(15)*(-y(12))/T547)/(y(12)*y(12))+(y(12)*(T145*params(43)*y(47)+y(12)*params(43)*y(47)*T1260)/y(15)-y(12)*T145*params(43)*y(47)/y(15))/(y(12)*y(12))-T561*T1252*T1313;
  g1(26,15)=(y(15)*y(18)*params(44)*T1562/y(18)-y(18)*params(44)*T154/y(18))/(y(15)*y(15))+T548*params(44)*y(47)*T1562+T154*params(44)*y(47)*(T547*y(18)*(-1)/y(18)-y(18)*(-y(15))/y(18)*2*y(15))/(T547*T547)+T553*params(43)*T1556+params(43)*T145*((-y(12))/T547+y(15)*(-((-y(12))*2*y(15)))/(T547*T547))/y(12)+(y(15)*y(12)*params(43)*y(47)*T1556-y(12)*T145*params(43)*y(47))/(y(15)*y(15))/y(12)-(T561*T1313*T1550+T533*params(32)*params(22)*getPowerDeriv(params(22)*y(15),T364,1));
  g1(26,18)=(y(18)*(params(44)*T154+y(18)*params(44)*T1839)-y(18)*params(44)*T154)/(y(18)*y(18))/y(15)+T548*params(44)*y(47)*T1839+T154*params(44)*y(47)*((-y(15))/y(18)+y(18)*y(15)/(y(18)*y(18)))/T547-T561*T1313*T1833;
  g1(26,33)=1;
  g1(26,47)=params(44)*T154*T548+y(12)*params(43)*T145/y(15)/y(12);
  g1(27,12)=T569*params(45)*T1269+params(45)*T163*((-y(18))/y(12)+y(12)*y(18)/(y(12)*y(12)))/T568+T572*params(45)*y(47)*T1269+T163*params(45)*y(47)*(y(12)*1/y(18)-T160)/(y(12)*y(12))-T585*T1252*T1313;
  g1(27,15)=T577*params(44)*T1562+params(44)*T154*(y(15)*y(18)*(-1)/T568-y(18)*(-y(15))/T568)/(y(15)*y(15))+(y(15)*(T154*params(44)*y(47)+y(15)*params(44)*y(47)*T1562)/y(18)-y(15)*T154*params(44)*y(47)/y(18))/(y(15)*y(15))-T585*T1313*T1550;
  g1(27,18)=T569*params(45)*T1846+params(45)*T163*(T568*y(12)*(-1)/y(12)-y(12)*(-y(18))/y(12)*2*y(18))/(T568*T568)+T572*params(45)*y(47)*T1846+T163*params(45)*y(47)*(-y(12))/(y(18)*y(18))/y(12)+T577*params(44)*T1839+params(44)*T154*((-y(15))/T568+y(18)*(-((-y(15))*2*y(18)))/(T568*T568))/y(15)+(y(18)*y(15)*params(44)*y(47)*T1839-y(15)*T154*params(44)*y(47))/(y(18)*y(18))/y(15)-(T585*T1313*T1833+T533*params(33)*getPowerDeriv(y(18),T364,1));
  g1(27,36)=1;
  g1(27,47)=params(45)*T163*T572+y(15)*params(44)*T154/y(18)/y(15);
  g1(28,4)=(-(T597*y(49)*y(37)*params(1)*getPowerDeriv(y(4),params(1)-1,1)));
  g1(28,7)=(-(T595*T980));
  g1(28,19)=1;
  g1(28,37)=(-(T597*T594*y(49)*params(1)));
  g1(28,49)=(-(T597*T594*y(37)*params(1)));
  g1(29,4)=(-(T604*y(49)*y(37)*(1-params(1))*T868));
  g1(29,7)=(-(y(49)*y(37)*(1-params(1))*T601*getPowerDeriv(y(7),(-params(1)),1)));
  g1(29,22)=1;
  g1(29,37)=(-(T604*T601*y(49)*(1-params(1))));
  g1(29,49)=(-(T604*T601*y(37)*(1-params(1))));
  g1(30,5)=(-(T613*params(1)*y(50)*y(41)*getPowerDeriv(y(5),params(1)-1,1)));
  g1(30,8)=(-(T612*T1011));
  g1(30,20)=1;
  g1(30,41)=(-(T613*T611*params(1)*y(50)));
  g1(30,50)=(-(T613*T611*params(1)*y(41)));
  g1(31,5)=(-(T619*(1-params(1))*y(50)*y(41)*T906));
  g1(31,8)=(-((1-params(1))*y(50)*y(41)*T617*getPowerDeriv(y(8),(-params(1)),1)));
  g1(31,23)=1;
  g1(31,41)=(-(T619*T617*(1-params(1))*y(50)));
  g1(31,50)=(-(T619*T617*(1-params(1))*y(41)));
  g1(32,6)=(-(T628*params(1)*y(51)*y(45)*getPowerDeriv(y(6),params(1)-1,1)));
  g1(32,9)=(-(T627*T1042));
  g1(32,21)=1;
  g1(32,45)=(-(T628*T626*params(1)*y(51)));
  g1(32,51)=(-(T628*T626*params(1)*y(45)));
  g1(33,6)=(-(T634*(1-params(1))*y(51)*y(45)*T944));
  g1(33,9)=(-((1-params(1))*y(51)*y(45)*T632*getPowerDeriv(y(9),(-params(1)),1)));
  g1(33,24)=1;
  g1(33,45)=(-(T634*T632*(1-params(1))*y(51)));
  g1(33,51)=(-(T634*T632*(1-params(1))*y(45)));
  g1(34,28)=(-1);
  g1(34,37)=1;
  g1(35,29)=1;
  g1(35,38)=(-((1+params(13))/params(19)));
  g1(36,30)=1;
  g1(36,39)=(-((1+params(14))/params(20)));
  g1(37,31)=1;
  g1(37,40)=(-((1+params(15))/params(21)));
  g1(38,32)=(-1);
  g1(38,41)=1;
  g1(39,33)=1;
  g1(39,42)=(-((1+params(16))/params(22)));
  g1(40,34)=1;
  g1(40,43)=(-((1+params(17))/params(23)));
  g1(41,35)=1;
  g1(41,44)=(-((1+params(16))/params(22)));
  g1(42,36)=(-1);
  g1(42,45)=1;
  g1(43,25)=(-y(38));
  g1(43,37)=1;
  g1(43,38)=(-y(25));
  g1(44,25)=(-y(41));
  g1(44,40)=1;
  g1(44,41)=(-y(25));
  g1(45,25)=(-y(44));
  g1(45,43)=1;
  g1(45,44)=(-y(25));
  g1(46,26)=(-y(39));
  g1(46,37)=1;
  g1(46,39)=(-y(26));
  g1(47,26)=(-y(42));
  g1(47,40)=1;
  g1(47,42)=(-y(26));
  g1(48,26)=(-y(45));
  g1(48,43)=1;
  g1(48,45)=(-y(26));
  g1(49,4)=(-(y(49)*params(7)*T597*T868));
  g1(49,7)=(-(y(49)*params(7)*T601*T980));
  g1(49,10)=params(7);
  g1(49,11)=params(8);
  g1(49,12)=params(9);
  g1(49,49)=(-(params(7)*T597*T601));
  g1(50,5)=(-(y(50)*params(8)*T613*T906));
  g1(50,8)=(-(y(50)*params(8)*T617*T1011));
  g1(50,13)=params(7);
  g1(50,14)=params(8);
  g1(50,15)=params(9);
  g1(50,50)=(-(params(8)*T613*T617));
  g1(51,6)=(-(y(51)*params(9)*T628*T944));
  g1(51,9)=(-(y(51)*params(9)*T632*T1042));
  g1(51,16)=params(7);
  g1(51,17)=params(8);
  g1(51,18)=params(9);
  g1(51,51)=(-(params(9)*T628*T632));
  g1(52,49)=1/y(49)-params(10)*1/y(49);
  g1(53,50)=1/y(50)-params(11)*1/y(50);
  g1(54,51)=1/y(51)-params(12)*1/y(51);
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],54,2916);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],54,157464);
end
end
end
end
