function [residual, g1, g2, g3] = BKK3C_fg2nf_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(54, 1);
T16 = (params(4)-1)/params(4);
T32 = params(25)*y(25)^T16+params(26)*(params(21)*y(28))^T16+params(27)*(params(23)*y(31))^T16;
T33 = params(4)/(params(4)-1);
T37 = params(37)/2;
T43 = y(28)/y(25)*y(4)/y(7)-1;
T48 = params(38)/2;
T53 = y(28)/y(31)*y(10)/y(7)-1;
T58 = params(39)/2;
T62 = y(4)*y(31)/y(25)/y(10)-1;
T88 = params(28)*(params(19)*y(26))^T16+params(29)*y(29)^T16+params(30)*(params(24)*y(32))^T16;
T92 = params(40)/2;
T98 = y(26)/y(29)*y(8)/y(5)-1;
T103 = params(41)/2;
T108 = y(8)*y(32)/y(29)/y(11)-1;
T113 = params(42)/2;
T117 = y(11)*y(26)/y(32)/y(5)-1;
T143 = params(31)*(params(20)*y(27))^T16+params(32)*(params(22)*y(30))^T16+params(33)*y(33)^T16;
T147 = params(43)/2;
T153 = y(27)/y(30)*y(9)/y(6)-1;
T158 = params(44)/2;
T163 = y(30)/y(33)*y(12)/y(9)-1;
T168 = params(45)/2;
T172 = y(12)*y(27)/y(33)/y(6)-1;
T189 = (y(67)/y(1)-params(3))^2;
T202 = (y(68)/y(2)-params(3))^2;
T215 = (y(69)/y(3)-params(3))^2;
T224 = y(70)^params(6);
T229 = (params(34)-y(73))^(1-params(6));
T230 = T224*T229;
T233 = T230^(1-params(2));
T239 = 1-params(46)*(y(88)/y(19)-params(3));
T240 = params(5)*params(6)/y(70)*T233/T239;
T244 = params(46)/2;
T245 = params(3)^2;
T249 = 1+y(85)-params(3)-T244*(T245-(y(88)/y(19))^2);
T252 = y(16)^params(6);
T255 = (params(34)-y(22))^(1-params(6));
T256 = T252*T255;
T257 = T256^(1-params(2));
T260 = 1-params(46)*(y(67)/y(1)-params(3));
T266 = y(71)^params(6);
T269 = (params(34)-y(74))^(1-params(6));
T270 = T266*T269;
T271 = T270^(1-params(2));
T277 = 1-params(46)*(y(89)/y(20)-params(3));
T278 = params(5)*params(6)/y(71)*T271/T277;
T285 = 1+y(86)-params(3)-T244*(T245-(y(89)/y(20))^2);
T288 = y(17)^params(6);
T291 = (params(34)-y(23))^(1-params(6));
T292 = T288*T291;
T293 = T292^(1-params(2));
T296 = 1-params(46)*(y(68)/y(2)-params(3));
T302 = y(72)^params(6);
T305 = (params(34)-y(75))^(1-params(6));
T306 = T302*T305;
T307 = T306^(1-params(2));
T313 = 1-params(46)*(y(90)/y(21)-params(3));
T314 = params(5)*params(6)/y(72)*T307/T313;
T321 = 1+y(87)-params(3)-T244*(T245-(y(90)/y(21))^2);
T324 = y(18)^params(6);
T327 = (params(34)-y(24))^(1-params(6));
T328 = T324*T327;
T329 = T328^(1-params(2));
T332 = 1-params(46)*(y(69)/y(3)-params(3));
T356 = T293*1/y(17);
T358 = T257*1/y(16);
T365 = T329*1/y(18);
T394 = y(25)^2;
T395 = (-y(28))/T394;
T406 = y(25)*y(79)/y(76)/y(28)-1;
T407 = params(37)*y(61)*T406;
T408 = y(79)/y(76)/y(28);
T415 = y(4)*(-y(31))/T394/y(10);
T423 = y(25)*y(82)/y(76)/y(31)-1;
T424 = params(39)*y(61)*T423;
T429 = (-1)/params(4);
T431 = params(25)*y(25)^T429;
T432 = 1/(params(4)-1);
T433 = T32^T432;
T446 = y(31)*y(79)/y(82)/y(28)-1;
T447 = params(38)*y(61)*T446;
T451 = y(28)^2;
T452 = y(31)*(-y(79))/y(82)/T451;
T456 = y(4)/y(7)/y(25);
T461 = y(25)*(-y(79))/y(76)/T451;
T465 = params(26)*(params(21)*y(28))^T429;
T476 = y(31)^2;
T477 = y(25)*(-y(82))/y(76)/T476;
T482 = y(10)*(-y(28))/T476/y(7);
T490 = params(27)*(params(23)*y(31))^T429;
T505 = y(29)*y(77)/y(80)/y(26)-1;
T506 = params(40)*y(62)*T505;
T510 = y(26)^2;
T511 = y(29)*(-y(77))/y(80)/T510;
T516 = y(11)/y(5)/y(32);
T524 = y(32)*y(77)/y(83)/y(26)-1;
T525 = params(42)*y(62)*T524;
T529 = y(77)*(-y(32))/T510/y(83);
T533 = params(28)*(params(19)*y(26))^T429;
T534 = T88^T432;
T539 = y(29)^2;
T542 = y(8)*(-y(32))/T539/y(11);
T549 = y(29)*y(83)/y(80)/y(32)-1;
T550 = params(41)*y(62)*T549;
T551 = y(83)/y(80)/y(32);
T557 = y(8)*(-y(26))/T539/y(5);
T565 = params(29)*y(29)^T429;
T572 = y(32)^2;
T573 = y(26)*(-y(11))/y(5)/T572;
T581 = y(8)/y(11)/y(29);
T587 = y(29)*(-y(83))/y(80)/T572;
T591 = params(30)*(params(24)*y(32))^T429;
T606 = y(30)*y(78)/y(81)/y(27)-1;
T607 = params(43)*y(62)*T606;
T611 = y(27)^2;
T612 = y(30)*(-y(78))/y(81)/T611;
T617 = y(6)/y(12)/y(33);
T625 = y(33)*y(78)/y(84)/y(27)-1;
T626 = params(45)*y(62)*T625;
T629 = y(33)*(-y(78))/y(84)/T611;
T633 = params(31)*(params(20)*y(27))^T429;
T634 = T143^T432;
T647 = y(33)*y(81)/y(84)/y(30)-1;
T648 = params(44)*y(62)*T647;
T652 = y(30)^2;
T653 = y(33)*(-y(81))/y(84)/T652;
T659 = y(9)*(-y(27))/T652/y(6);
T667 = params(32)*(params(22)*y(30))^T429;
T674 = y(33)^2;
T675 = y(27)*(-y(12))/y(6)/T674;
T678 = y(78)/y(84)/y(27);
T684 = y(12)*(-y(30))/T674/y(9);
T692 = params(33)*y(33)^T429;
T702 = y(19)^(params(1)-1);
T703 = y(64)*y(52)*params(1)*T702;
T705 = y(22)^(1-params(1));
T709 = y(19)^params(1);
T712 = y(22)^(-params(1));
T720 = y(20)^(params(1)-1);
T721 = params(1)*y(65)*y(56)*T720;
T722 = y(23)^(1-params(1));
T726 = y(20)^params(1);
T728 = y(23)^(-params(1));
T736 = y(21)^(params(1)-1);
T737 = params(1)*y(66)*y(60)*T736;
T738 = y(24)^(1-params(1));
T742 = y(21)^params(1);
T744 = y(24)^(-params(1));
residual(1) = (-y(16))-y(67)+T32^T33-T37*T43^2-T48*T53^2-T58*T62^2;
residual(2) = (-y(17))-y(68)+T88^T33-T92*T98^2-T103*T108^2-T113*T117^2;
residual(3) = (-y(18))-y(69)+T143^T33-T147*T153^2-T158*T163^2-T168*T172^2;
residual(4) = y(67)+(-y(19))+(1-params(3))*y(1)-y(1)*params(46)*T189;
residual(5) = y(68)+(-y(20))+(1-params(3))*y(2)-params(46)*y(2)*T202;
residual(6) = y(69)+(-y(21))+(1-params(3))*y(3)-params(46)*y(3)*T215;
residual(7) = T240*T249-params(6)/y(16)*T257/T260;
residual(8) = T278*T285-params(6)/y(17)*T293/T296;
residual(9) = T314*T321-params(6)/y(18)*T329/T332;
residual(10) = y(16)*(1-params(6))-params(6)*(params(34)-y(22))*y(37);
residual(11) = y(17)*(1-params(6))-params(6)*(params(34)-y(23))*y(38);
residual(12) = y(18)*(1-params(6))-params(6)*(params(34)-y(24))*y(39);
lhs =y(40);
rhs =T356/T358*params(35);
residual(13)= lhs-rhs;
lhs =y(41);
rhs =T365/T358*params(36);
residual(14)= lhs-rhs;
lhs =y(42);
rhs =y(41)/y(40);
residual(15)= lhs-rhs;
lhs =y(61);
rhs =params(5)*T233*1/y(70)/T358;
residual(16)= lhs-rhs;
lhs =y(62);
rhs =params(5)*T271*1/y(71)/T356;
residual(17)= lhs-rhs;
lhs =y(63);
rhs =params(5)*T307*1/y(72)/T365;
residual(18)= lhs-rhs;
lhs =y(43)+y(4)*params(37)*T43*T395/y(7)+T407*T408+params(39)*T62*T415+y(82)*T424/y(76)/y(31);
rhs =T431*T433;
residual(19)= lhs-rhs;
lhs =y(46)+y(10)*params(38)*T53/y(31)/y(7)+T447*T452+params(37)*T43*T456+T407*T461;
rhs =T433*T465;
residual(20)= lhs-rhs;
lhs =y(49)+y(4)*params(39)*T62/y(25)/y(10)+T424*T477+params(38)*T53*T482+y(79)*T447/y(82)/y(28);
rhs =T433*T490;
residual(21)= lhs-rhs;
lhs =y(44)+y(8)*params(40)*T98/y(29)/y(5)+T506*T511+params(42)*T117*T516+T525*T529;
rhs =T533*T534;
residual(22)= lhs-rhs;
lhs =y(47)+params(41)*T108*T542+T550*T551+params(40)*T98*T557+y(77)*T506/y(80)/y(26);
rhs =T534*T565;
residual(23)= lhs-rhs;
lhs =y(50)+params(42)*T117*T573+y(32)*y(77)*T525/y(83)+params(41)*T108*T581+T550*T587;
rhs =T534*T591;
residual(24)= lhs-rhs;
lhs =y(45)+y(9)*params(43)*T153/y(30)/y(6)+T607*T612+params(45)*T172*T617+T626*T629;
rhs =T633*T634;
residual(25)= lhs-rhs;
lhs =y(48)+y(12)*params(44)*T163/y(33)/y(9)+T648*T653+params(43)*T153*T659+y(78)*T607/y(81)/y(27);
rhs =T634*T667;
residual(26)= lhs-rhs;
lhs =y(51)+params(45)*T172*T675+T626*T678+params(44)*T163*T684+y(81)*T648/y(84)/y(30);
rhs =T634*T692;
residual(27)= lhs-rhs;
lhs =y(34);
rhs =T703*T705;
residual(28)= lhs-rhs;
lhs =y(37);
rhs =y(64)*y(52)*(1-params(1))*T709*T712;
residual(29)= lhs-rhs;
lhs =y(35);
rhs =T721*T722;
residual(30)= lhs-rhs;
lhs =y(38);
rhs =(1-params(1))*y(65)*y(56)*T726*T728;
residual(31)= lhs-rhs;
lhs =y(36);
rhs =T737*T738;
residual(32)= lhs-rhs;
lhs =y(39);
rhs =(1-params(1))*y(66)*y(60)*T742*T744;
residual(33)= lhs-rhs;
lhs =y(52);
rhs =y(43);
residual(34)= lhs-rhs;
lhs =y(44);
rhs =(1+params(13))*y(53)/params(19);
residual(35)= lhs-rhs;
lhs =y(45);
rhs =(1+params(14))*y(54)/params(20);
residual(36)= lhs-rhs;
lhs =y(46);
rhs =(1+params(15))*y(55)/params(21);
residual(37)= lhs-rhs;
lhs =y(56);
rhs =y(47);
residual(38)= lhs-rhs;
lhs =y(48);
rhs =(1+params(16))*y(57)/params(22);
residual(39)= lhs-rhs;
lhs =y(49);
rhs =(1+params(17))*y(58)/params(23);
residual(40)= lhs-rhs;
lhs =y(50);
rhs =(1+params(16))*y(59)/params(22);
residual(41)= lhs-rhs;
lhs =y(60);
rhs =y(51);
residual(42)= lhs-rhs;
lhs =y(52);
rhs =y(40)*y(53);
residual(43)= lhs-rhs;
lhs =y(55);
rhs =y(40)*y(56);
residual(44)= lhs-rhs;
lhs =y(58);
rhs =y(40)*y(59);
residual(45)= lhs-rhs;
lhs =y(52);
rhs =y(41)*y(54);
residual(46)= lhs-rhs;
lhs =y(55);
rhs =y(41)*y(57);
residual(47)= lhs-rhs;
lhs =y(58);
rhs =y(41)*y(60);
residual(48)= lhs-rhs;
lhs =y(25)*params(7)+y(26)*params(8)+y(27)*params(9);
rhs =y(64)*params(7)*T705*T709;
residual(49)= lhs-rhs;
lhs =y(28)*params(7)+y(29)*params(8)+y(30)*params(9);
rhs =y(65)*params(8)*T722*T726;
residual(50)= lhs-rhs;
lhs =y(31)*params(7)+y(32)*params(8)+y(33)*params(9);
rhs =y(66)*params(9)*T738*T742;
residual(51)= lhs-rhs;
lhs =log(y(64));
rhs =params(10)*log(y(13))+x(it_, 1);
residual(52)= lhs-rhs;
lhs =log(y(65));
rhs =params(11)*log(y(14))+x(it_, 2);
residual(53)= lhs-rhs;
lhs =log(y(66));
rhs =params(12)*log(y(15))+x(it_, 3);
residual(54)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(54, 93);

  %
  % Jacobian matrix
  %

T855 = getPowerDeriv(T256,1-params(2),1);
T856 = T255*getPowerDeriv(y(16),params(6),1)*T855;
T865 = 1/y(16)*T856+T257*(-1)/(y(16)*y(16));
T886 = getPowerDeriv(T230,1-params(2),1);
T887 = T229*getPowerDeriv(y(70),params(6),1)*T886;
T904 = getPowerDeriv(T292,1-params(2),1);
T905 = T291*getPowerDeriv(y(17),params(6),1)*T904;
T914 = 1/y(17)*T905+T293*(-1)/(y(17)*y(17));
T927 = getPowerDeriv(T270,1-params(2),1);
T928 = T269*getPowerDeriv(y(71),params(6),1)*T927;
T945 = getPowerDeriv(T328,1-params(2),1);
T946 = T327*getPowerDeriv(y(18),params(6),1)*T945;
T955 = 1/y(18)*T946+T329*(-1)/(y(18)*y(18));
T968 = getPowerDeriv(T306,1-params(2),1);
T969 = T305*getPowerDeriv(y(72),params(6),1)*T968;
T1019 = getPowerDeriv(y(19),params(1),1);
T1063 = getPowerDeriv(y(20),params(1),1);
T1107 = getPowerDeriv(y(21),params(1),1);
T1117 = T855*T252*(-(getPowerDeriv(params(34)-y(22),1-params(6),1)));
T1138 = getPowerDeriv(y(22),1-params(1),1);
T1150 = T886*T224*(-(getPowerDeriv(params(34)-y(73),1-params(6),1)));
T1161 = T904*T288*(-(getPowerDeriv(params(34)-y(23),1-params(6),1)));
T1175 = getPowerDeriv(y(23),1-params(1),1);
T1187 = T927*T266*(-(getPowerDeriv(params(34)-y(74),1-params(6),1)));
T1198 = T945*T324*(-(getPowerDeriv(params(34)-y(24),1-params(6),1)));
T1212 = getPowerDeriv(y(24),1-params(1),1);
T1224 = T968*T302*(-(getPowerDeriv(params(34)-y(75),1-params(6),1)));
T1232 = y(28)/y(25)/y(7);
T1237 = y(31)/y(25)/y(10);
T1263 = params(25)*getPowerDeriv(y(25),T16,1);
T1264 = getPowerDeriv(T32,T33,1);
T1269 = y(4)*(-y(28))/(y(25)*y(25))/y(7);
T1275 = y(4)*(-y(31))/(y(25)*y(25))/y(10);
T1304 = params(39)*y(61)*y(82)/y(76)/y(31);
T1311 = getPowerDeriv(T32,T432,1);
T1345 = params(37)*y(61)*y(25)*(-y(79))/(y(76)*y(76))/y(28);
T1353 = params(39)*y(61)*y(25)*(-y(82))/(y(76)*y(76))/y(31);
T1374 = (-(y(26)/y(29)*y(8)))/(y(5)*y(5));
T1380 = (-(y(11)*y(26)/y(32)))/(y(5)*y(5));
T1411 = params(28)*params(19)*getPowerDeriv(params(19)*y(26),T16,1);
T1412 = getPowerDeriv(T88,T33,1);
T1416 = y(8)*1/y(29)/y(5);
T1422 = y(11)*1/y(32)/y(5);
T1433 = params(40)*y(62)*(-(y(29)*y(77)/y(80)))/(y(26)*y(26));
T1448 = params(42)*y(62)*(-(y(32)*y(77)/y(83)))/(y(26)*y(26));
T1461 = getPowerDeriv(T88,T432,1);
T1494 = params(40)*y(62)*y(29)*1/y(80)/y(26);
T1504 = params(42)*y(62)*y(32)*1/y(83)/y(26);
T1520 = (-(y(27)/y(30)*y(9)))/(y(6)*y(6));
T1526 = (-(y(12)*y(27)/y(33)))/(y(6)*y(6));
T1557 = params(31)*params(20)*getPowerDeriv(params(20)*y(27),T16,1);
T1558 = getPowerDeriv(T143,T33,1);
T1562 = y(9)*1/y(30)/y(6);
T1568 = y(12)*1/y(33)/y(6);
T1579 = params(43)*y(62)*(-(y(30)*y(78)/y(81)))/(y(27)*y(27));
T1594 = params(45)*y(62)*(-(y(33)*y(78)/y(84)))/(y(27)*y(27));
T1605 = getPowerDeriv(T143,T432,1);
T1640 = params(43)*y(62)*y(30)*1/y(81)/y(27);
T1650 = params(45)*y(62)*y(33)*1/y(84)/y(27);
T1668 = (-(y(28)/y(25)*y(4)))/(y(7)*y(7));
T1673 = (-(y(28)/y(31)*y(10)))/(y(7)*y(7));
T1704 = params(26)*params(21)*getPowerDeriv(params(21)*y(28),T16,1);
T1708 = y(4)*1/y(25)/y(7);
T1714 = y(10)*1/y(31)/y(7);
T1728 = params(37)*y(61)*(-(y(25)*y(79)/y(76)))/(y(28)*y(28));
T1744 = params(38)*y(61)*(-(y(31)*y(79)/y(82)))/(y(28)*y(28));
T1787 = params(37)*y(61)*y(25)*1/y(76)/y(28);
T1795 = params(38)*y(61)*y(31)*1/y(82)/y(28);
T1813 = y(26)/y(29)/y(5);
T1817 = y(32)/y(29)/y(11);
T1843 = params(29)*getPowerDeriv(y(29),T16,1);
T1848 = y(8)*(-y(26))/(y(29)*y(29))/y(5);
T1854 = y(8)*(-y(32))/(y(29)*y(29))/y(11);
T1865 = params(40)*y(62)*y(77)/y(80)/y(26);
T1923 = params(40)*y(62)*y(29)*(-y(77))/(y(80)*y(80))/y(26);
T1933 = params(41)*y(62)*y(29)*(-y(83))/(y(80)*y(80))/y(32);
T1950 = y(27)/y(30)/y(6);
T1956 = (-(y(30)/y(33)*y(12)))/(y(9)*y(9));
T1984 = params(32)*params(22)*getPowerDeriv(params(22)*y(30),T16,1);
T1989 = y(9)*(-y(27))/(y(30)*y(30))/y(6);
T1993 = y(12)*1/y(33)/y(9);
T2004 = params(43)*y(62)*y(78)/y(81)/y(27);
T2019 = params(44)*y(62)*(-(y(33)*y(81)/y(84)))/(y(30)*y(30));
T2067 = params(43)*y(62)*y(30)*(-y(78))/(y(81)*y(81))/y(27);
T2075 = params(44)*y(62)*y(33)*1/y(84)/y(30);
T2090 = y(28)/y(31)/y(7);
T2096 = (-(y(4)*y(31)/y(25)))/(y(10)*y(10));
T2123 = params(27)*params(23)*getPowerDeriv(params(23)*y(31),T16,1);
T2128 = y(10)*(-y(28))/(y(31)*y(31))/y(7);
T2132 = y(4)*1/y(25)/y(10);
T2144 = params(39)*y(61)*(-(y(25)*y(82)/y(76)))/(y(31)*y(31));
T2161 = params(38)*y(61)*y(79)/y(82)/y(28);
T2202 = params(39)*y(61)*y(25)*1/y(76)/y(31);
T2211 = params(38)*y(61)*y(31)*(-y(79))/(y(82)*y(82))/y(28);
T2230 = (-(y(8)*y(32)/y(29)))/(y(11)*y(11));
T2234 = y(26)/y(32)/y(5);
T2265 = params(30)*params(24)*getPowerDeriv(params(24)*y(32),T16,1);
T2267 = y(8)*1/y(29)/y(11);
T2274 = y(11)*(-y(26))/(y(32)*y(32))/y(5);
T2285 = params(42)*y(62)*y(77)/y(83)/y(26);
T2303 = params(41)*y(62)*(-(y(29)*y(83)/y(80)))/(y(32)*y(32));
T2345 = params(42)*y(62)*y(32)*(-y(77))/(y(83)*y(83))/y(26);
T2352 = params(41)*y(62)*y(29)*1/y(80)/y(32);
T2367 = y(30)/y(33)/y(9);
T2371 = y(27)/y(33)/y(6);
T2400 = params(33)*getPowerDeriv(y(33),T16,1);
T2405 = y(12)*(-y(30))/(y(33)*y(33))/y(9);
T2411 = y(12)*(-y(27))/(y(33)*y(33))/y(6);
T2437 = params(44)*y(62)*y(81)/y(84)/y(30);
T2478 = params(45)*y(62)*y(33)*(-y(78))/(y(84)*y(84))/y(27);
T2488 = params(44)*y(62)*y(33)*(-y(81))/(y(84)*y(84))/y(30);
  g1(1,16)=(-1);
  g1(1,4)=(-(T37*T1232*2*T43))-T58*T1237*2*T62;
  g1(1,25)=T1263*T1264-T37*2*T43*T1269-T58*2*T62*T1275;
  g1(1,7)=(-(T37*2*T43*T1668))-T48*T1673*2*T53;
  g1(1,28)=T1264*T1704-T37*2*T43*T1708-T48*2*T53*T1714;
  g1(1,10)=(-(T48*2*T53*T2090))-T58*2*T62*T2096;
  g1(1,31)=T1264*T2123-T48*2*T53*T2128-T58*2*T62*T2132;
  g1(1,67)=(-1);
  g1(2,17)=(-1);
  g1(2,5)=(-(T92*T1374*2*T98))-T113*T1380*2*T117;
  g1(2,26)=T1411*T1412-T92*2*T98*T1416-T113*2*T117*T1422;
  g1(2,8)=(-(T92*2*T98*T1813))-T103*T1817*2*T108;
  g1(2,29)=T1412*T1843-T92*2*T98*T1848-T103*2*T108*T1854;
  g1(2,11)=(-(T103*2*T108*T2230))-T113*2*T117*T2234;
  g1(2,32)=T1412*T2265-T103*2*T108*T2267-T113*2*T117*T2274;
  g1(2,68)=(-1);
  g1(3,18)=(-1);
  g1(3,6)=(-(T147*T1520*2*T153))-T168*T1526*2*T172;
  g1(3,27)=T1557*T1558-T147*2*T153*T1562-T168*2*T172*T1568;
  g1(3,9)=(-(T147*2*T153*T1950))-T158*T1956*2*T163;
  g1(3,30)=T1558*T1984-T147*2*T153*T1989-T158*2*T163*T1993;
  g1(3,12)=(-(T158*2*T163*T2367))-T168*2*T172*T2371;
  g1(3,33)=T1558*T2400-T158*2*T163*T2405-T168*2*T172*T2411;
  g1(3,69)=(-1);
  g1(4,1)=1-params(3)-(params(46)*T189+y(1)*params(46)*(-y(67))/(y(1)*y(1))*2*(y(67)/y(1)-params(3)));
  g1(4,19)=(-1);
  g1(4,67)=1-y(1)*params(46)*2*(y(67)/y(1)-params(3))*1/y(1);
  g1(5,2)=1-params(3)-(params(46)*T202+params(46)*y(2)*(-y(68))/(y(2)*y(2))*2*(y(68)/y(2)-params(3)));
  g1(5,20)=(-1);
  g1(5,68)=1-params(46)*y(2)*2*(y(68)/y(2)-params(3))*1/y(2);
  g1(6,3)=1-params(3)-(params(46)*T215+params(46)*y(3)*(-y(69))/(y(3)*y(3))*2*(y(69)/y(3)-params(3)));
  g1(6,21)=(-1);
  g1(6,69)=1-params(46)*y(3)*2*(y(69)/y(3)-params(3))*1/y(3);
  g1(7,16)=(-((T257*(-params(6))/(y(16)*y(16))+params(6)/y(16)*T856)/T260));
  g1(7,70)=T249*(T233*(-(params(5)*params(6)))/(y(70)*y(70))+params(5)*params(6)/y(70)*T887)/T239;
  g1(7,1)=(-((-(params(6)/y(16)*T257*(-(params(46)*(-y(67))/(y(1)*y(1))))))/(T260*T260)));
  g1(7,19)=T249*(-(params(5)*params(6)/y(70)*T233*(-(params(46)*(-y(88))/(y(19)*y(19))))))/(T239*T239)+T240*(-(T244*(-((-y(88))/(y(19)*y(19))*2*y(88)/y(19)))));
  g1(7,22)=(-(params(6)/y(16)*T1117/T260));
  g1(7,73)=T249*params(5)*params(6)/y(70)*T1150/T239;
  g1(7,85)=T240;
  g1(7,67)=(-((-(params(6)/y(16)*T257*(-(params(46)*1/y(1)))))/(T260*T260)));
  g1(7,88)=T249*(-(params(5)*params(6)/y(70)*T233*(-(params(46)*1/y(19)))))/(T239*T239)+T240*(-(T244*(-(2*y(88)/y(19)*1/y(19)))));
  g1(8,17)=(-((T293*(-params(6))/(y(17)*y(17))+params(6)/y(17)*T905)/T296));
  g1(8,71)=T285*(T271*(-(params(5)*params(6)))/(y(71)*y(71))+params(5)*params(6)/y(71)*T928)/T277;
  g1(8,2)=(-((-(params(6)/y(17)*T293*(-(params(46)*(-y(68))/(y(2)*y(2))))))/(T296*T296)));
  g1(8,20)=T285*(-(params(5)*params(6)/y(71)*T271*(-(params(46)*(-y(89))/(y(20)*y(20))))))/(T277*T277)+T278*(-(T244*(-((-y(89))/(y(20)*y(20))*2*y(89)/y(20)))));
  g1(8,23)=(-(params(6)/y(17)*T1161/T296));
  g1(8,74)=T285*params(5)*params(6)/y(71)*T1187/T277;
  g1(8,86)=T278;
  g1(8,68)=(-((-(params(6)/y(17)*T293*(-(params(46)*1/y(2)))))/(T296*T296)));
  g1(8,89)=T285*(-(params(5)*params(6)/y(71)*T271*(-(params(46)*1/y(20)))))/(T277*T277)+T278*(-(T244*(-(2*y(89)/y(20)*1/y(20)))));
  g1(9,18)=(-((T329*(-params(6))/(y(18)*y(18))+params(6)/y(18)*T946)/T332));
  g1(9,72)=T321*(T307*(-(params(5)*params(6)))/(y(72)*y(72))+params(5)*params(6)/y(72)*T969)/T313;
  g1(9,3)=(-((-(params(6)/y(18)*T329*(-(params(46)*(-y(69))/(y(3)*y(3))))))/(T332*T332)));
  g1(9,21)=T321*(-(params(5)*params(6)/y(72)*T307*(-(params(46)*(-y(90))/(y(21)*y(21))))))/(T313*T313)+T314*(-(T244*(-((-y(90))/(y(21)*y(21))*2*y(90)/y(21)))));
  g1(9,24)=(-(params(6)/y(18)*T1198/T332));
  g1(9,75)=T321*params(5)*params(6)/y(72)*T1224/T313;
  g1(9,87)=T314;
  g1(9,69)=(-((-(params(6)/y(18)*T329*(-(params(46)*1/y(3)))))/(T332*T332)));
  g1(9,90)=T321*(-(params(5)*params(6)/y(72)*T307*(-(params(46)*1/y(21)))))/(T313*T313)+T314*(-(T244*(-(2*y(90)/y(21)*1/y(21)))));
  g1(10,16)=1-params(6);
  g1(10,22)=(-(y(37)*(-params(6))));
  g1(10,37)=(-(params(6)*(params(34)-y(22))));
  g1(11,17)=1-params(6);
  g1(11,23)=(-(y(38)*(-params(6))));
  g1(11,38)=(-(params(6)*(params(34)-y(23))));
  g1(12,18)=1-params(6);
  g1(12,24)=(-(y(39)*(-params(6))));
  g1(12,39)=(-(params(6)*(params(34)-y(24))));
  g1(13,16)=(-(params(35)*(-(T356*T865))/(T358*T358)));
  g1(13,17)=(-(params(35)*T914/T358));
  g1(13,22)=(-(params(35)*(-(T356*1/y(16)*T1117))/(T358*T358)));
  g1(13,23)=(-(params(35)*1/y(17)*T1161/T358));
  g1(13,40)=1;
  g1(14,16)=(-(params(36)*(-(T365*T865))/(T358*T358)));
  g1(14,18)=(-(params(36)*T955/T358));
  g1(14,22)=(-(params(36)*(-(T365*1/y(16)*T1117))/(T358*T358)));
  g1(14,24)=(-(params(36)*1/y(18)*T1198/T358));
  g1(14,41)=1;
  g1(15,40)=(-((-y(41))/(y(40)*y(40))));
  g1(15,41)=(-(1/y(40)));
  g1(15,42)=1;
  g1(16,16)=(-((-(params(5)*T233*1/y(70)*T865))/(T358*T358)));
  g1(16,70)=(-(params(5)*(1/y(70)*T887+T233*(-1)/(y(70)*y(70)))/T358));
  g1(16,22)=(-((-(params(5)*T233*1/y(70)*1/y(16)*T1117))/(T358*T358)));
  g1(16,73)=(-(params(5)*1/y(70)*T1150/T358));
  g1(16,61)=1;
  g1(17,17)=(-((-(params(5)*T271*1/y(71)*T914))/(T356*T356)));
  g1(17,71)=(-(params(5)*(1/y(71)*T928+T271*(-1)/(y(71)*y(71)))/T356));
  g1(17,23)=(-((-(params(5)*T271*1/y(71)*1/y(17)*T1161))/(T356*T356)));
  g1(17,74)=(-(params(5)*1/y(71)*T1187/T356));
  g1(17,62)=1;
  g1(18,18)=(-((-(params(5)*T307*1/y(72)*T955))/(T365*T365)));
  g1(18,72)=(-(params(5)*(1/y(72)*T969+T307*(-1)/(y(72)*y(72)))/T365));
  g1(18,24)=(-((-(params(5)*T307*1/y(72)*1/y(18)*T1198))/(T365*T365)));
  g1(18,75)=(-(params(5)*1/y(72)*T1224/T365));
  g1(18,63)=1;
  g1(19,4)=(params(37)*T43*T395+y(4)*T395*params(37)*T1232)/y(7)+T415*params(39)*T1237+params(39)*T62*(-y(31))/T394/y(10);
  g1(19,25)=y(4)*(T395*params(37)*T1269+params(37)*T43*(-((-y(28))*2*y(25)))/(T394*T394))/y(7)+T408*params(37)*y(61)*T408+T415*params(39)*T1275+params(39)*T62*y(4)*(-((-y(31))*2*y(25)))/(T394*T394)/y(10)+y(82)*T1304/y(76)/y(31)-(T433*params(25)*getPowerDeriv(y(25),T429,1)+T431*T1263*T1311);
  g1(19,76)=T408*T1345+T407*(-y(79))/(y(76)*y(76))/y(28)+(y(76)*y(82)*T1353-y(82)*T424)/(y(76)*y(76))/y(31);
  g1(19,7)=(y(7)*y(4)*T395*params(37)*T1668-y(4)*params(37)*T43*T395)/(y(7)*y(7));
  g1(19,28)=y(4)*(T395*params(37)*T1708+params(37)*T43*(-1)/T394)/y(7)+T408*T1728+T407*(-(y(79)/y(76)))/(y(28)*y(28))-T431*T1311*T1704;
  g1(19,79)=T408*T1787+T407*1/y(76)/y(28);
  g1(19,10)=T415*params(39)*T2096+params(39)*T62*(-(y(4)*(-y(31))/T394))/(y(10)*y(10));
  g1(19,31)=T415*params(39)*T2132+params(39)*T62*y(4)*(-1)/T394/y(10)+(y(31)*y(82)*T2144/y(76)-y(82)*T424/y(76))/(y(31)*y(31))-T431*T1311*T2123;
  g1(19,82)=(T424+y(82)*T2202)/y(76)/y(31);
  g1(19,43)=1;
  g1(19,61)=T408*params(37)*T406+y(82)*params(39)*T423/y(76)/y(31);
  g1(20,4)=T456*params(37)*T1232+params(37)*T43*1/y(7)/y(25);
  g1(20,25)=T456*params(37)*T1269+params(37)*T43*(-(y(4)/y(7)))/(y(25)*y(25))+T461*params(37)*y(61)*T408+T407*(-y(79))/y(76)/T451-T465*T1263*T1311;
  g1(20,76)=T461*T1345+T407*y(25)*y(79)/(y(76)*y(76))/T451;
  g1(20,7)=(y(7)*y(10)*params(38)*T1673/y(31)-y(10)*params(38)*T53/y(31))/(y(7)*y(7))+T456*params(37)*T1668+params(37)*T43*(-y(4))/(y(7)*y(7))/y(25);
  g1(20,28)=y(10)*params(38)*T1714/y(31)/y(7)+T452*T1744+T447*(-(y(31)*(-y(79))/y(82)*2*y(28)))/(T451*T451)+T456*params(37)*T1708+T461*T1728+T407*(-(y(25)*(-y(79))/y(76)*2*y(28)))/(T451*T451)-(T465*T1311*T1704+T433*params(26)*params(21)*getPowerDeriv(params(21)*y(28),T429,1));
  g1(20,79)=T452*T1795+T447*y(31)*(-1)/y(82)/T451+T461*T1787+T407*y(25)*(-1)/y(76)/T451;
  g1(20,10)=(params(38)*T53+y(10)*params(38)*T2090)/y(31)/y(7);
  g1(20,31)=(y(31)*y(10)*params(38)*T2128-y(10)*params(38)*T53)/(y(31)*y(31))/y(7)+T452*T2161+T447*(-y(79))/y(82)/T451-T465*T1311*T2123;
  g1(20,82)=T452*T2211+T447*y(31)*y(79)/(y(82)*y(82))/T451;
  g1(20,46)=1;
  g1(20,61)=T452*params(38)*T446+T461*params(37)*T406;
  g1(21,4)=(params(39)*T62+y(4)*params(39)*T1237)/y(25)/y(10);
  g1(21,25)=(y(25)*y(4)*params(39)*T1275-y(4)*params(39)*T62)/(y(25)*y(25))/y(10)+T477*T1304+T424*(-y(82))/y(76)/T476-T490*T1263*T1311;
  g1(21,76)=T477*T1353+T424*y(25)*y(82)/(y(76)*y(76))/T476;
  g1(21,7)=T482*params(38)*T1673+params(38)*T53*(-(y(10)*(-y(28))/T476))/(y(7)*y(7));
  g1(21,28)=T482*params(38)*T1714+params(38)*T53*y(10)*(-1)/T476/y(7)+(y(28)*y(79)*T1744/y(82)-y(79)*T447/y(82))/(y(28)*y(28))-T490*T1311*T1704;
  g1(21,79)=(T447+y(79)*T1795)/y(82)/y(28);
  g1(21,10)=(y(10)*y(4)*params(39)*T2096/y(25)-y(4)*params(39)*T62/y(25))/(y(10)*y(10))+T482*params(38)*T2090+params(38)*T53*(-y(28))/T476/y(7);
  g1(21,31)=y(4)*params(39)*T2132/y(25)/y(10)+T477*T2144+T424*(-(y(25)*(-y(82))/y(76)*2*y(31)))/(T476*T476)+T482*params(38)*T2128+params(38)*T53*y(10)*(-((-y(28))*2*y(31)))/(T476*T476)/y(7)+y(79)*T2161/y(82)/y(28)-(T490*T1311*T2123+T433*params(27)*params(23)*getPowerDeriv(params(23)*y(31),T429,1));
  g1(21,82)=T477*T2202+T424*y(25)*(-1)/y(76)/T476+(y(82)*y(79)*T2211-y(79)*T447)/(y(82)*y(82))/y(28);
  g1(21,49)=1;
  g1(21,61)=T477*params(39)*T423+y(79)*params(38)*T446/y(82)/y(28);
  g1(22,5)=(y(5)*y(8)*params(40)*T1374/y(29)-y(8)*params(40)*T98/y(29))/(y(5)*y(5))+T516*params(42)*T1380+params(42)*T117*(-y(11))/(y(5)*y(5))/y(32);
  g1(22,26)=y(8)*params(40)*T1416/y(29)/y(5)+T511*T1433+T506*(-(y(29)*(-y(77))/y(80)*2*y(26)))/(T510*T510)+T516*params(42)*T1422+T529*T1448+T525*y(77)*(-((-y(32))*2*y(26)))/(T510*T510)/y(83)-(T534*params(28)*params(19)*getPowerDeriv(params(19)*y(26),T429,1)+T533*T1411*T1461);
  g1(22,77)=T511*T1494+T506*y(29)*(-1)/y(80)/T510+T529*T1504+T525*(-y(32))/T510/y(83);
  g1(22,8)=(params(40)*T98+y(8)*params(40)*T1813)/y(29)/y(5);
  g1(22,29)=(y(29)*y(8)*params(40)*T1848-y(8)*params(40)*T98)/(y(29)*y(29))/y(5)+T511*T1865+T506*(-y(77))/y(80)/T510-T533*T1461*T1843;
  g1(22,80)=T511*T1923+T506*y(29)*y(77)/(y(80)*y(80))/T510;
  g1(22,11)=T516*params(42)*T2234+params(42)*T117*1/y(5)/y(32);
  g1(22,32)=T516*params(42)*T2274+params(42)*T117*(-(y(11)/y(5)))/(y(32)*y(32))+T529*T2285+T525*y(77)*(-1)/T510/y(83)-T533*T1461*T2265;
  g1(22,83)=T529*T2345+T525*(-(y(77)*(-y(32))/T510))/(y(83)*y(83));
  g1(22,44)=1;
  g1(22,62)=T511*params(40)*T505+T529*params(42)*T524;
  g1(23,5)=T557*params(40)*T1374+params(40)*T98*(-(y(8)*(-y(26))/T539))/(y(5)*y(5));
  g1(23,26)=T557*params(40)*T1416+params(40)*T98*y(8)*(-1)/T539/y(5)+(y(26)*y(77)*T1433/y(80)-y(77)*T506/y(80))/(y(26)*y(26))-T565*T1411*T1461;
  g1(23,77)=(T506+y(77)*T1494)/y(80)/y(26);
  g1(23,8)=T542*params(41)*T1817+params(41)*T108*(-y(32))/T539/y(11)+T557*params(40)*T1813+params(40)*T98*(-y(26))/T539/y(5);
  g1(23,29)=T542*params(41)*T1854+params(41)*T108*y(8)*(-((-y(32))*2*y(29)))/(T539*T539)/y(11)+T551*params(41)*y(62)*T551+T557*params(40)*T1848+params(40)*T98*y(8)*(-((-y(26))*2*y(29)))/(T539*T539)/y(5)+y(77)*T1865/y(80)/y(26)-(T565*T1461*T1843+T534*params(29)*getPowerDeriv(y(29),T429,1));
  g1(23,80)=T551*T1933+T550*(-y(83))/(y(80)*y(80))/y(32)+(y(80)*y(77)*T1923-y(77)*T506)/(y(80)*y(80))/y(26);
  g1(23,11)=T542*params(41)*T2230+params(41)*T108*(-(y(8)*(-y(32))/T539))/(y(11)*y(11));
  g1(23,32)=T542*params(41)*T2267+params(41)*T108*y(8)*(-1)/T539/y(11)+T551*T2303+T550*(-(y(83)/y(80)))/(y(32)*y(32))-T565*T1461*T2265;
  g1(23,83)=T551*T2352+T550*1/y(80)/y(32);
  g1(23,47)=1;
  g1(23,62)=T551*params(41)*T549+y(77)*params(40)*T505/y(80)/y(26);
  g1(24,5)=T573*params(42)*T1380+params(42)*T117*y(26)*y(11)/(y(5)*y(5))/T572;
  g1(24,26)=T573*params(42)*T1422+params(42)*T117*(-y(11))/y(5)/T572+y(32)*y(77)*T1448/y(83)-T591*T1411*T1461;
  g1(24,77)=y(32)*(T525+y(77)*T1504)/y(83);
  g1(24,8)=T581*params(41)*T1817+params(41)*T108*1/y(11)/y(29);
  g1(24,29)=T581*params(41)*T1854+params(41)*T108*(-(y(8)/y(11)))/(y(29)*y(29))+T587*params(41)*y(62)*T551+T550*(-y(83))/y(80)/T572-T591*T1461*T1843;
  g1(24,80)=T587*T1933+T550*y(29)*y(83)/(y(80)*y(80))/T572;
  g1(24,11)=T573*params(42)*T2234+params(42)*T117*y(26)*(-1)/y(5)/T572+T581*params(41)*T2230+params(41)*T108*(-y(8))/(y(11)*y(11))/y(29);
  g1(24,32)=T573*params(42)*T2274+params(42)*T117*(-(y(26)*(-y(11))/y(5)*2*y(32)))/(T572*T572)+y(77)*T525/y(83)+y(32)*y(77)*T2285/y(83)+T581*params(41)*T2267+T587*T2303+T550*(-(y(29)*(-y(83))/y(80)*2*y(32)))/(T572*T572)-(T591*T1461*T2265+T534*params(30)*params(24)*getPowerDeriv(params(24)*y(32),T429,1));
  g1(24,83)=y(32)*(y(83)*y(77)*T2345-y(77)*T525)/(y(83)*y(83))+T587*T2352+T550*y(29)*(-1)/y(80)/T572;
  g1(24,50)=1;
  g1(24,62)=y(32)*y(77)*params(42)*T524/y(83)+T587*params(41)*T549;
  g1(25,6)=(y(6)*y(9)*params(43)*T1520/y(30)-y(9)*params(43)*T153/y(30))/(y(6)*y(6))+T617*params(45)*T1526+params(45)*T172*1/y(12)/y(33);
  g1(25,27)=y(9)*params(43)*T1562/y(30)/y(6)+T612*T1579+T607*(-(y(30)*(-y(78))/y(81)*2*y(27)))/(T611*T611)+T617*params(45)*T1568+T629*T1594+T626*(-(y(33)*(-y(78))/y(84)*2*y(27)))/(T611*T611)-(T634*params(31)*params(20)*getPowerDeriv(params(20)*y(27),T429,1)+T633*T1557*T1605);
  g1(25,78)=T612*T1640+T607*y(30)*(-1)/y(81)/T611+T629*T1650+T626*y(33)*(-1)/y(84)/T611;
  g1(25,9)=(params(43)*T153+y(9)*params(43)*T1950)/y(30)/y(6);
  g1(25,30)=(y(30)*y(9)*params(43)*T1989-y(9)*params(43)*T153)/(y(30)*y(30))/y(6)+T612*T2004+T607*(-y(78))/y(81)/T611-T633*T1605*T1984;
  g1(25,81)=T612*T2067+T607*y(30)*y(78)/(y(81)*y(81))/T611;
  g1(25,12)=T617*params(45)*T2371+params(45)*T172*(-y(6))/(y(12)*y(12))/y(33);
  g1(25,33)=T617*params(45)*T2411+params(45)*T172*(-(y(6)/y(12)))/(y(33)*y(33))+T629*params(45)*y(62)*T678+T626*(-y(78))/y(84)/T611-T633*T1605*T2400;
  g1(25,84)=T629*T2478+T626*y(33)*y(78)/(y(84)*y(84))/T611;
  g1(25,45)=1;
  g1(25,62)=T612*params(43)*T606+T629*params(45)*T625;
  g1(26,6)=T659*params(43)*T1520+params(43)*T153*(-(y(9)*(-y(27))/T652))/(y(6)*y(6));
  g1(26,27)=T659*params(43)*T1562+params(43)*T153*y(9)*(-1)/T652/y(6)+(y(27)*y(78)*T1579/y(81)-y(78)*T607/y(81))/(y(27)*y(27))-T667*T1557*T1605;
  g1(26,78)=(T607+y(78)*T1640)/y(81)/y(27);
  g1(26,9)=(y(9)*y(12)*params(44)*T1956/y(33)-y(12)*params(44)*T163/y(33))/(y(9)*y(9))+T659*params(43)*T1950+params(43)*T153*(-y(27))/T652/y(6);
  g1(26,30)=y(12)*params(44)*T1993/y(33)/y(9)+T653*T2019+T648*(-(y(33)*(-y(81))/y(84)*2*y(30)))/(T652*T652)+T659*params(43)*T1989+params(43)*T153*y(9)*(-((-y(27))*2*y(30)))/(T652*T652)/y(6)+y(78)*T2004/y(81)/y(27)-(T667*T1605*T1984+T634*params(32)*params(22)*getPowerDeriv(params(22)*y(30),T429,1));
  g1(26,81)=T653*T2075+T648*y(33)*(-1)/y(84)/T652+(y(81)*y(78)*T2067-y(78)*T607)/(y(81)*y(81))/y(27);
  g1(26,12)=(params(44)*T163+y(12)*params(44)*T2367)/y(33)/y(9);
  g1(26,33)=(y(33)*y(12)*params(44)*T2405-y(12)*params(44)*T163)/(y(33)*y(33))/y(9)+T653*T2437+T648*(-y(81))/y(84)/T652-T667*T1605*T2400;
  g1(26,84)=T653*T2488+T648*y(33)*y(81)/(y(84)*y(84))/T652;
  g1(26,48)=1;
  g1(26,62)=T653*params(44)*T647+y(78)*params(43)*T606/y(81)/y(27);
  g1(27,6)=T675*params(45)*T1526+params(45)*T172*y(27)*y(12)/(y(6)*y(6))/T674;
  g1(27,27)=T675*params(45)*T1568+params(45)*T172*(-y(12))/y(6)/T674+T678*T1594+T626*(-(y(78)/y(84)))/(y(27)*y(27))-T692*T1557*T1605;
  g1(27,78)=T678*T1650+T626*1/y(84)/y(27);
  g1(27,9)=T684*params(44)*T1956+params(44)*T163*(-(y(12)*(-y(30))/T674))/(y(9)*y(9));
  g1(27,30)=T684*params(44)*T1993+params(44)*T163*y(12)*(-1)/T674/y(9)+(y(30)*y(81)*T2019/y(84)-y(81)*T648/y(84))/(y(30)*y(30))-T692*T1605*T1984;
  g1(27,81)=(T648+y(81)*T2075)/y(84)/y(30);
  g1(27,12)=T675*params(45)*T2371+params(45)*T172*y(27)*(-1)/y(6)/T674+T684*params(44)*T2367+params(44)*T163*(-y(30))/T674/y(9);
  g1(27,33)=T675*params(45)*T2411+params(45)*T172*(-(y(27)*(-y(12))/y(6)*2*y(33)))/(T674*T674)+T678*params(45)*y(62)*T678+T684*params(44)*T2405+params(44)*T163*y(12)*(-((-y(30))*2*y(33)))/(T674*T674)/y(9)+y(81)*T2437/y(84)/y(30)-(T692*T1605*T2400+T634*params(33)*getPowerDeriv(y(33),T429,1));
  g1(27,84)=T678*T2478+T626*(-y(78))/(y(84)*y(84))/y(27)+(y(84)*y(81)*T2488-y(81)*T648)/(y(84)*y(84))/y(30);
  g1(27,51)=1;
  g1(27,62)=T678*params(45)*T625+y(81)*params(44)*T647/y(84)/y(30);
  g1(28,19)=(-(T705*y(64)*y(52)*params(1)*getPowerDeriv(y(19),params(1)-1,1)));
  g1(28,22)=(-(T703*T1138));
  g1(28,34)=1;
  g1(28,52)=(-(T705*T702*y(64)*params(1)));
  g1(28,64)=(-(T705*T702*y(52)*params(1)));
  g1(29,19)=(-(T712*y(64)*y(52)*(1-params(1))*T1019));
  g1(29,22)=(-(y(64)*y(52)*(1-params(1))*T709*getPowerDeriv(y(22),(-params(1)),1)));
  g1(29,37)=1;
  g1(29,52)=(-(T712*T709*y(64)*(1-params(1))));
  g1(29,64)=(-(T712*T709*y(52)*(1-params(1))));
  g1(30,20)=(-(T722*params(1)*y(65)*y(56)*getPowerDeriv(y(20),params(1)-1,1)));
  g1(30,23)=(-(T721*T1175));
  g1(30,35)=1;
  g1(30,56)=(-(T722*T720*params(1)*y(65)));
  g1(30,65)=(-(T722*T720*params(1)*y(56)));
  g1(31,20)=(-(T728*(1-params(1))*y(65)*y(56)*T1063));
  g1(31,23)=(-((1-params(1))*y(65)*y(56)*T726*getPowerDeriv(y(23),(-params(1)),1)));
  g1(31,38)=1;
  g1(31,56)=(-(T728*T726*(1-params(1))*y(65)));
  g1(31,65)=(-(T728*T726*(1-params(1))*y(56)));
  g1(32,21)=(-(T738*params(1)*y(66)*y(60)*getPowerDeriv(y(21),params(1)-1,1)));
  g1(32,24)=(-(T737*T1212));
  g1(32,36)=1;
  g1(32,60)=(-(T738*T736*params(1)*y(66)));
  g1(32,66)=(-(T738*T736*params(1)*y(60)));
  g1(33,21)=(-(T744*(1-params(1))*y(66)*y(60)*T1107));
  g1(33,24)=(-((1-params(1))*y(66)*y(60)*T742*getPowerDeriv(y(24),(-params(1)),1)));
  g1(33,39)=1;
  g1(33,60)=(-(T744*T742*(1-params(1))*y(66)));
  g1(33,66)=(-(T744*T742*(1-params(1))*y(60)));
  g1(34,43)=(-1);
  g1(34,52)=1;
  g1(35,44)=1;
  g1(35,53)=(-((1+params(13))/params(19)));
  g1(36,45)=1;
  g1(36,54)=(-((1+params(14))/params(20)));
  g1(37,46)=1;
  g1(37,55)=(-((1+params(15))/params(21)));
  g1(38,47)=(-1);
  g1(38,56)=1;
  g1(39,48)=1;
  g1(39,57)=(-((1+params(16))/params(22)));
  g1(40,49)=1;
  g1(40,58)=(-((1+params(17))/params(23)));
  g1(41,50)=1;
  g1(41,59)=(-((1+params(16))/params(22)));
  g1(42,51)=(-1);
  g1(42,60)=1;
  g1(43,40)=(-y(53));
  g1(43,52)=1;
  g1(43,53)=(-y(40));
  g1(44,40)=(-y(56));
  g1(44,55)=1;
  g1(44,56)=(-y(40));
  g1(45,40)=(-y(59));
  g1(45,58)=1;
  g1(45,59)=(-y(40));
  g1(46,41)=(-y(54));
  g1(46,52)=1;
  g1(46,54)=(-y(41));
  g1(47,41)=(-y(57));
  g1(47,55)=1;
  g1(47,57)=(-y(41));
  g1(48,41)=(-y(60));
  g1(48,58)=1;
  g1(48,60)=(-y(41));
  g1(49,19)=(-(y(64)*params(7)*T705*T1019));
  g1(49,22)=(-(y(64)*params(7)*T709*T1138));
  g1(49,25)=params(7);
  g1(49,26)=params(8);
  g1(49,27)=params(9);
  g1(49,64)=(-(params(7)*T705*T709));
  g1(50,20)=(-(y(65)*params(8)*T722*T1063));
  g1(50,23)=(-(y(65)*params(8)*T726*T1175));
  g1(50,28)=params(7);
  g1(50,29)=params(8);
  g1(50,30)=params(9);
  g1(50,65)=(-(params(8)*T722*T726));
  g1(51,21)=(-(y(66)*params(9)*T738*T1107));
  g1(51,24)=(-(y(66)*params(9)*T742*T1212));
  g1(51,31)=params(7);
  g1(51,32)=params(8);
  g1(51,33)=params(9);
  g1(51,66)=(-(params(9)*T738*T742));
  g1(52,13)=(-(params(10)*1/y(13)));
  g1(52,64)=1/y(64);
  g1(52,91)=(-1);
  g1(53,14)=(-(params(11)*1/y(14)));
  g1(53,65)=1/y(65);
  g1(53,92)=(-1);
  g1(54,15)=(-(params(12)*1/y(15)));
  g1(54,66)=1/y(66);
  g1(54,93)=(-1);

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],54,8649);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],54,804357);
end
end
end
end
