set more off

**
// STEP-1: Prepare Data
// Merge all the datasets for business cycle correlations:
use "gdp_data_long.dta",clear
merge 1:1 id year quarter using "consumption_long.dta", nogen
merge 1:1 id year quarter using "labor_long.dta", nogen
merge 1:1 id year quarter using "capital_long.dta", nogen
merge 1:1 id year quarter using "volatility_ratio_data_inputs.dta", nogen
// Filter data:
keep if year>=1980 & year<=2011
gen time=year*4+quarter
sort id time
// Generate TFP, TOT, and Current Account:
gen tfp=log(gdp)-0.36*log(cap)-0.64*log(lab)
bysort id: gen inv = cap[_n+1] - 0.975 * cap   
gen tot = (exp_chp/exp_cup)/(imp_chp/imp_cup)
gen curracc = (exp_cup - imp_cup) / gdp_cup
// Create logs when necessary:
gen log_gdp=log(gdp)
gen log_inv=log(inv)
gen log_con=log(con)
gen log_lab=log(lab)
gen log_tot=log(tot)

// Reshape wide:
replace id=id+10
keep year quarter time id log_gdp tfp log_lab inv log_inv log_con curracc log_tot 
reshape wide log_gdp tfp log_lab inv log_inv log_con curracc log_tot, i(time) j(id)
tsset time   

**
// STEP-2: HP-Filter All Time Series:
// Iterate by country:
local variables log_gdp tfp log_lab inv log_inv log_con curracc log_tot
local countries 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30
foreach var of local variables {
	foreach varc of local countries{
		tsfilter hp hp_`var'`varc' = `var'`varc', smooth(1600)
	}
}

save "HP_filtered_business_cycle_data.dta",replace
