set more off

**
** STEP-1: Compute Pairwise Correlations:
clear
gen dummy = 0
save "business_cycle_correlations.dta", replace
local variables tfp log_gdp log_con log_lab inv log_inv
foreach var of local variables {
	use "HP_filtered_business_cycle_data.dta", clear
	keep hp_`var'*
	local countries 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30
	//compute pairwise GDP correlation (requires ssc install egenmore)
	foreach var1 of local countries{
		foreach var2 of local countries{
			egen corr_`var1'`var2' = corr(hp_`var'`var1' hp_`var'`var2')
		}
	}
	keep corr_*
	// Reshape correlations from wide to long form:
	keep if _n == _N-1
	// Create an auxilliary variable to simplify data manipulation:
	gen temporary_variable = 80 
	reshape long corr_11 corr_12 corr_13 corr_14 corr_15 corr_16 corr_17 corr_18 ///
	corr_19 corr_20 corr_21 corr_22 corr_23 corr_24 corr_25 corr_26 corr_27 /// 
	corr_28 corr_29 corr_30, i(temporary_variable) j(id_h)
	reshape long corr_, i(id_h) j(id_f)
	keep if id_h < id_f 
	keep if corr_ < .
	collapse (p50) corr_
	rename corr_ corr_`var'
	append using "business_cycle_correlations.dta"
	save "business_cycle_correlations.dta", replace
}
collapse (min) *
replace dummy = 0
reshape long corr_, i(dummy) j(var) string
drop dummy
format corr_ %8.3f
rename corr_ corr_domestic_with_foreign
sort var
save "business_cycle_correlations.dta", replace

**
** STEP-2: Compute Correlations with GPP/TOT:
clear
gen dummy = 0
save "business_cycle_corr_with_gdp.dta", replace
local variables log_con log_lab log_inv curracc

local countries 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30
foreach var of local variables {
	use "HP_filtered_business_cycle_data.dta", clear
	keep hp_`var'* hp_log_gdp* time
	foreach varc of local countries{
		egen corr_gdp_with_`var'`varc'=corr(hp_log_gdp`varc' hp_`var'`varc')
	}
	keep corr_gdp_with_`var'*
	keep if _n==_N-1
	// Create an auxilliary variable to simplify data manipulation:
	gen temporary_variable = 80 
	reshape long corr_gdp_with_`var', i(temporary_variable) j(id)
	collapse (median) corr_gdp_with_`var'	
	append using "business_cycle_corr_with_gdp.dta"
	save "business_cycle_corr_with_gdp.dta", replace
}
* Treat TOT with GDP correlation separately:
	use "HP_filtered_business_cycle_data.dta", clear
	keep hp_curracc* hp_log_tot* time
	foreach varc of local countries{
		egen corr_tot_with_curracc`varc'=corr(hp_log_tot`varc' hp_curracc`varc')
	}
	keep corr_tot_with_currac*
	keep if _n==_N-1
	// Create an auxilliary variable to simplify data manipulation:
	gen temporary_variable = 80 
	reshape long corr_tot_with_curracc, i(temporary_variable) j(id)
	collapse (median) corr_tot_with_currac	
	append using "business_cycle_corr_with_gdp.dta"
	save "business_cycle_corr_with_gdp.dta", replace
collapse (min) *
reshape long corr_, i(dummy) j(var) string
drop dummy
format corr_ %8.3f
sort var
save "business_cycle_corr_with_gdp.dta", replace

**
** STEP-3: Compute Volatility Relative to GDP:
clear
gen dummy = 0
save "business_cycle_vol_rel_gdp.dta", replace
local variables log_con log_lab log_inv curracc 
foreach var of local variables {
	use "HP_filtered_business_cycle_data.dta", clear
	keep hp_`var'* hp_log_gdp* time
	sum hp_`var'* 
	reshape long hp_`var' hp_log_gdp, i(time) j(id)
	collapse (sd) hp_*, by(id)
	gen vol_relative_gdp_`var' = hp_`var' / hp_log_gdp
	collapse (median) vol_relative_gdp_`var'
	append using "business_cycle_vol_rel_gdp.dta"
	save "business_cycle_vol_rel_gdp.dta", replace
}
collapse (min) *
reshape long vol_relative_gdp_, i(dummy) j(var) string
drop dummy
format vol_relative_gdp_ %8.3f
sort var
save "business_cycle_vol_rel_gdp.dta", replace

**
** STEP-4: Report Results:
use "business_cycle_correlations.dta", clear
list var corr_, separator(8) abbreviate(35)
erase "business_cycle_correlations.dta"
use "business_cycle_corr_with_gdp.dta", clear
list var corr_, separator(8) abbreviate(35)
erase "business_cycle_corr_with_gdp.dta"
use "business_cycle_vol_rel_gdp.dta", clear
list var vol_relative_gdp_, separator(8) abbreviate(35)
erase "business_cycle_vol_rel_gdp.dta"
erase "HP_filtered_business_cycle_data.dta"
