set more off

// Compute pairwise GDP correlations:
use "gdp_data_long.dta",clear

gen time=year*4+quarter
// change ids temporarily to simplify data manipulation:
replace id=id+10
drop country
reshape wide gdp ,i(time) j(id)
tsset time
// we will process each country and pair of country ids as below:
local countries 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30
// remove trend using HP filter:
foreach var of local countries{
replace gdp`var'=log(gdp`var')
tsfilter hp hpgdp`var' = gdp`var', smooth(1600)
replace gdp`var'=hpgdp`var' 
drop hpgdp`var'
}
//compute pairwise GDP correlation (requires ssc install egenmore)
foreach var1 of local countries{
foreach var2 of local countries{
egen cor_gdp`var1'`var2'=corr(gdp`var1' gdp`var2')
}
}
//reshape correlations from wide to long form:
keep if _n == 1
drop year quarter
gen temporary_variable = 80 //just an auxilliary variable to simplify data manipulation:
reshape long cor_gdp11 cor_gdp12 cor_gdp13 cor_gdp14 cor_gdp15 cor_gdp16 ///
cor_gdp17 cor_gdp18 cor_gdp19 cor_gdp20 cor_gdp21 cor_gdp22 cor_gdp23 cor_gdp24 /// 
cor_gdp25 cor_gdp26 cor_gdp27 cor_gdp28 cor_gdp29 cor_gdp30 , i(temporary_variable) j(id_h)
reshape long cor_gdp , i(id_h) j(id_f)
rename cor_gdp corrgdp
keep id_h id_f corrgdp
// change country ids back to their original values:
replace id_h=id_h-10
replace id_f=id_f-10
keep if id_h!=id_f
save "pairwise_gdp_correlations.dta", replace
