set more off
use "volatility_ratio_data_inputs.dta", clear

// Step-1: Compute import to domestic absorption quantity ratio:
// Compute domestic absorption "dab" as gdp minus export:
gen dab_quantity = gdp_chp - exp_chp
// Compute the Log of quatity ratio:
gen import_to_dab_quantity = log(imp_chp / dab_quantity)

// Step-2: Compute domestic absorption to import price ratio:
gen dab_cup = gdp_cup - exp_cup
// Compute price deflator of domestic absorption:
gen dab_price = dab_cup / dab_quantity
// Compute price deflator of import:
gen import_price = imp_cup / imp_chp
// Compute the Log of the price ratio:
gen dab_to_import_price = log(dab_price / import_price)

// Step-3: Obtain deviations from linear trends:
// Compute linear trends:
gen time=year*4+quarter
reg import_to_dab_quantity c.time#i.id i.id
predict import_to_dab_quantity_lin_hat
reg dab_to_import_price c.time#i.id i.id
predict dab_to_import_price_lin_hat
// Compute percentage (as we use logs) deviations from the linear trend: 
gen import_to_dab_quantity_linear = ///
import_to_dab_quantity - import_to_dab_quantity_lin_hat
gen dab_to_import_price_linear = ///
dab_to_import_price - dab_to_import_price_lin_hat

// Step-4: Obtain deviations from HP trends:
// For HP-flitering, we will process countries one by one:
local countries 1 2 3 4 5 6 7 8  10 11 12 13 14 15 16 17 18 19 20
// For that, we will use time variables that differ between countries 
// so that we can set time variable once and it works for all countries:
replace time = time + id * 10000
tsset time
// Generate placeholder variables to store percentage deviations from trend:
gen import_to_dab_quantity_HP = .
gen dab_to_import_price_HP = .
// Populate placeholder variables country by country:
foreach var of local countries{
tsfilter hp import_to_dab_quantity_HP_`var' = import_to_dab_quantity ///
if id==`var', smooth(1600)
replace import_to_dab_quantity_HP = import_to_dab_quantity_HP_`var' if id==`var'
tsfilter hp dab_to_import_price_HP_`var' = dab_to_import_price ///
if id==`var', smooth(1600)
replace dab_to_import_price_HP = dab_to_import_price_HP_`var' if id==`var'
}

//Step-5: Compute standard deviations for each country:
collapse (sd) import_to_dab_quantity_linear dab_to_import_price_linear ///
import_to_dab_quantity_HP dab_to_import_price_HP, by(id country)

//Step-6: Compute volatility ratios "VR" for linear and HP detrended data: 
gen VR_linear = import_to_dab_quantity_linear / dab_to_import_price_linear
gen VR_HP = import_to_dab_quantity_HP  / dab_to_import_price_HP

//Step-7: Report volatility ratios by showing them on the screen: 
*merge 1:1 id using "country.dta"
format VR_HP VR_linear %8.2f
sort id
list country VR_HP VR_linear, separator(20)
