set more off

//STEP-1: Download pre-processed/cleaned data:
// Download data with pre-computed gdp correlations:
use "explanatory_and_instrumental_variables.dta" , clear
// Merge with explanatory and instrumental variables:
merge 1:1 id_h id_f using "pairwise_gdp_correlations.dta", nogen
// Avoid dupplications of countries for our regression:
keep if id_h<id_f

//STEP-2: Generate bilateral trade measure and prepare variables:
// Create bilateral trade:
gen bilateral_trade_hf=max(import_hf/gdp_h,import_fh/gdp_f)*10^6
//Take logs of bilateral trade and distance:
gen log_distance = log(distance)
gen log_bilateral_trade_hf=log(bilateral_trade_hf)
label variable log_bilateral_trade_hf "trade_hf"
label variable both_in_eu "E_hf"

// Generate country dummies:
local countries 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20
foreach var of local countries{
gen d`var'=0
replace d`var'=1 if id_h==`var' | id_f==`var'
}

// STEP-3: Run regressions and save output:
eststo clear
// OLS:
eststo, t("OLS"): reg corrgdp log_bilateral_trade_hf d1-d20 both_in_eu, r
// IV:
eststo, t("IV"): ivreg corrgdp ///
(log_bilateral_trade_hf = common_language common_border log_distance) ///
d1-d20 both_in_eu, r
esttab , se r2 label  star(* 0.1 ** 0.05 *** 0.01) ///
k(log_bilateral_trade_hf both_in_eu) mtitles

erase pairwise_gdp_correlations.dta
